(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    125688,       2805]*)
(*NotebookOutlinePosition[    126767,       2839]*)
(*  CellTagsIndexPosition[    126723,       2835]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["GroupLoopTest.nb", "Title",
  PageWidth->WindowWidth],

Cell["Validation of GroupLoopHoop.m", "Subtitle",
  PageWidth->WindowWidth],

Cell[TextData[{
  "R.H.Beresford. 11/10/6. From ",
  StyleBox["GroupLoopPackage.nb",
    FontSlant->"Italic"],
  " 2004-5"
}], "Subsubtitle",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["1. Tests & Data Validation.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Summary. ",
    FontSlant->"Plain"],
  "A series of tests validate all the generation and prescription rules in \
the GroupLoopHoop database. Tables without generator rules or prescriptions \
are first identified and counted; every prescription and generator rule is \
then tested. Incorrect identification of the rules would be reported. \
Clifford, Grassmann, and Cayley-Dickson algebras are tested. All signed \
tables are listed. All the generator & matrix generator rules are tested. No \
significant errors were found in the current version; if any are found in \
copies, they must arise from transcription errors. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users should download, run (in your ExtraPackages file), save and close \
the GroupLoopHoop package from ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  " and then use:-"
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[BoxData[
    \(<< GroupLoopHoop`\)], "Input",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["1.1 Validation of prescription Rules.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tTest 1 counts the loops in the database, finding only two that are not \
created as a protoloop; those without prescriptions are then counted and \
listed.\
\>", "Text",
  PageWidth->WindowWidth],

Cell["Test 1. Report  Loops (< 64 elements) without Protoloops.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(np = 0; nos = 0; noc = 0; lp = Length[loop] - 1; 
    Do[Do[\(noc++\); 
        If[loop[\([m, n, 4]\)] === "\<ca[]\>" && loop[\([m, n, 5]\)] === {} && 
            loop[\([m, n, 7]\)] === {} && loop[\([m, n, 8]\)] === {} && 
            loop[\([m, n, 9]\)] === {} && 
            Length[loop[\([m, n]\)]] < 10, \(nos++\); 
          If[m < 64, 
            Print[{\(gd[m, n]\)[\([3, 1]\)], "\< has no protoloop\>"}]; 
            nos = 0], \(np++\)], {n, Length[loop[\([m]\)]]}], {m, 
        lp}]; {noc, "\<loops \>", np, "\< with protoloops\>"}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"g4828", " has no protoloop"}\)], "Print"],

Cell[BoxData[
    \({813, "loops ", 674, " with protoloops"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "139 loops have no protoloops. ",
  StyleBox["dico",
    FontSlant->"Italic"],
  " was found for them when they were created via GAP in external files."
}], "Text",
  PageWidth->WindowWidth],

Cell["Test 2. Unprescribed loops.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(unp = {}; noc = 0; 
    Do[If[loop[\([m]\)] \[NotEqual] {}, 
        Do[\(noc++\); 
          If[loop[\([m, n, 4]\)] === "\<ca[]\>", 
            AppendTo[unp, {{m, n}, loop[\([m, n, 1]\)]}]], {n, 
            Length[loop[\([m]\)]]}]], {m, 1, lp}]; 
    Print[{Length[unp], "\< tables without prescriptions\>"}];\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({236, " tables without prescriptions"}\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<Small Loops without prescriptions:-\>"]; 
    tbl = Table[{unp[\([i]\)], unp[\([i + 24]\)]}, {i, 24}]; 
    tbl // tf\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("Small Loops without prescriptions:-"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\({{10, 3}, "Q20c"}\), \({{36, 3}, "g3603"}\)},
              {\({{12, 3}, "A4"}\), \({{36, 9}, "g3609"}\)},
              {\({{12, 26}, "A4C2r"}\), \({{39, 1}, "C39n"}\)},
              {\({{16, 26}, "PD16"}\), \({{40, 3}, "C40d"}\)},
              {\({{16, 31}, "D4Kr"}\), \({{40, 12}, "C40b"}\)},
              {\({{20, 3}, "g2003"}\), \({{42, 5}, "C42a"}\)},
              {\({{24, 3}, "SL23"}\), \({{48, 3}, "g4803"}\)},
              {\({{27, 3}, "P27"}\), \({{48, 5}, "g4805"}\)},
              {\({{27, 4}, "g2704"}\), \({{48, 18}, "g4818"}\)},
              {\({{32, 2}, "g3202"}\), \({{48, 28}, "g4828"}\)},
              {\({{32, 6}, "g3206"}\), \({{48, 29}, "g4829"}\)},
              {\({{32, 7}, "g3207"}\), \({{48, 30}, "g4830"}\)},
              {\({{32, 8}, "g3208"}\), \({{48, 33}, "g4833"}\)},
              {\({{32, 11}, "g3211"}\), \({{48, 50}, "g4850"}\)},
              {\({{32, 15}, "g3215"}\), \({{52, 5}, "C52a"}\)},
              {\({{32, 17}, "g3217"}\), \({{54, 5}, "D9C3a"}\)},
              {\({{32, 30}, "g3230"}\), \({{54, 6}, "g5406"}\)},
              {\({{32, 31}, "g3231"}\), \({{54, 8}, "P54"}\)},
              {\({{32, 32}, "Q8C4a"}\), \({{54, 11}, "g2704C2"}\)},
              {\({{32, 33}, "g3233"}\), \({{54, 14}, "D27b"}\)},
              {\({{32, 38}, "g3238"}\), \({{55, 2}, "g5502"}\)},
              {\({{32, 42}, "g3242"}\), \({{56, 11}, "g5611"}\)},
              {\({{32, 43}, "g3243"}\), \({{57, 1}, "g5701"}\)},
              {\({{32, 44}, "g3244"}\), \({{60, 5}, "A5"}\)}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{10, 3}, "Q20c"}, {{36, 3}, "g3603"}}, {{{12, 3}, 
          "A4"}, {{36, 9}, "g3609"}}, {{{12, 26}, "A4C2r"}, {{39, 1}, 
          "C39n"}}, {{{16, 26}, "PD16"}, {{40, 3}, "C40d"}}, {{{16, 31}, 
          "D4Kr"}, {{40, 12}, "C40b"}}, {{{20, 3}, "g2003"}, {{42, 5}, 
          "C42a"}}, {{{24, 3}, "SL23"}, {{48, 3}, "g4803"}}, {{{27, 3}, 
          "P27"}, {{48, 5}, "g4805"}}, {{{27, 4}, "g2704"}, {{48, 18}, 
          "g4818"}}, {{{32, 2}, "g3202"}, {{48, 28}, "g4828"}}, {{{32, 6}, 
          "g3206"}, {{48, 29}, "g4829"}}, {{{32, 7}, "g3207"}, {{48, 30}, 
          "g4830"}}, {{{32, 8}, "g3208"}, {{48, 33}, "g4833"}}, {{{32, 11}, 
          "g3211"}, {{48, 50}, "g4850"}}, {{{32, 15}, "g3215"}, {{52, 5}, 
          "C52a"}}, {{{32, 17}, "g3217"}, {{54, 5}, "D9C3a"}}, {{{32, 30}, 
          "g3230"}, {{54, 6}, "g5406"}}, {{{32, 31}, "g3231"}, {{54, 8}, 
          "P54"}}, {{{32, 32}, "Q8C4a"}, {{54, 11}, "g2704C2"}}, {{{32, 33}, 
          "g3233"}, {{54, 14}, "D27b"}}, {{{32, 38}, "g3238"}, {{55, 2}, 
          "g5502"}}, {{{32, 42}, "g3242"}, {{56, 11}, "g5611"}}, {{{32, 43}, 
          "g3243"}, {{57, 1}, "g5701"}}, {{{32, 44}, "g3244"}, {{60, 5}, 
          "A5"}}}, TableDepth -> 2]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Test 3. Correctness of first available prescriptions.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tmp",
  StyleBox[" uses the first available prescription to create a table. An \
error is reported if this does not have the correct ",
    FontSlant->"Plain"],
  "id",
  StyleBox[". set ",
    FontSlant->"Plain"],
  "pr=1",
  StyleBox[" to track progress. (As Clifford(3) is an isomorph of \
Clifford(1,2) it is shown as an error.)",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pr = 0; presco = 0; 
    tt = AbsoluteTime[]; \(Do[
          Do[If[pr > 0, Print[{m, n}]]; \[IndentingNewLine]If[
              Position[unp, {m, n}] \[Equal] {}, 
              id[test = 
                  mp[{m, n}]]; \[IndentingNewLine]If[{mm, nn} \[Equal] {m, 
                    n}, \(presco++\); mn = {mm, nn}, 
                Print[gd[], "\< \>", dico[test], "\< \>", 
                  loop[\([m, n, 1]\)]]]], {n, Length[loop[\([m]\)]]}], {m, 2, 
            lp - 1}];\) // Timing\), "\[IndentingNewLine]", 
    \(Print[{AbsoluteTime[] - tt, "\<actual seconds\n\>", 
        presco, "\< correct prescriptions.\nLast mm,nn=\>", mn}]\)}], "Input",\

  PageWidth->WindowWidth],

Cell[BoxData[
    InterpretationBox[\({8, 
          19, {"CL3", {\(-4\), 4, 24}, 0, 
            "cl[3]", {}, {}, {}, {}, {4, 29, 30}, 
            "ts[P16i]"}}\[InvisibleSpace]" "\[InvisibleSpace]{\(-4\), 4, 
          24}\[InvisibleSpace]" "\[InvisibleSpace]"CL12"\),
      SequenceForm[ {8, 19, {"CL3", {-4, 4, 24}, 0, "cl[3]", {}, {}, {}, {}, {
        4, 29, 30}, "ts[P16i]"}}, " ", {-4, 4, 24}, " ", "CL12"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\({257, 
          1, {"Unrecognised", {}, 0, 
            "Unrecognised", {}, {}, {}, {}, {}}}\[InvisibleSpace]" "\
\[InvisibleSpace]{20, 12, 39}\[InvisibleSpace]" "\[InvisibleSpace]"CL31C2"\),
      SequenceForm[ {257, 1, {"Unrecognised", {}, 0, 
        "Unrecognised", {}, {}, {}, {}, {}}}, " ", {20, 12, 39}, " ", 
        "CL31C2"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({2853.1`\ Second, Null}\)], "Output"],

Cell[BoxData[
    \({2853.`9.1749, "actual seconds\n", 571, 
      " correct prescriptions.\nLast mm,nn=", {120, 2}}\)], "Print"]
}, Open  ]],

Cell["Test 4. Cayley-Dickson validation & listing.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cdcases = 0; cdd = {}; 
    Do[Do[If[Take[Characters[loop[\([m, n, 4]\)]], 
              2] == {"\<c\>", "\<d\>"}, \(cdcases++\); 
          AppendTo[cdd, {loop[\([m, n, 1]\)], loop[\([m, n, 4]\)]}]]; 
        If[idc[] \[NotEqual] loop[\([m, n, 1]\)], Print[{m, n}]], {n, 
          Length[loop[\([m]\)]]}], {m, 
        33}]; {cdcases, "\< have cd prescriptions\>"}\)], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Courier New"],

Cell[BoxData[
    \({43, " have cd prescriptions"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AppendTo[cdd, {}]; AppendTo[cdd, {}]; AppendTo[cdd, {}]; 
    AppendTo[cdd, {}]; AppendTo[cdd, {}]; 
    tbl = Table[{cdd[\([i]\)], cdd[\([i + 15]\)], cdd[\([i + 30]\)]}, {i, 
          15}]; tbl // tf\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({"C4c", "cd[{-1}]"}\), \({"Cl3r", 
                "cd[{3.,-1.}]"}\), \({"C6Kr", "cd[{-3,1,1}]"}\)},
            {\({"C3C2c", "cd[{3.}]"}\), \({"C4C4c", 
                "cd[{2,1.,-1.}]"}\), \({"C24r", "cd[{-3,-1.,1}]"}\)},
            {\({"C3C2r", "cd[{-3}]"}\), \({"O4", 
                "cd[{1,1,-1.}]"}\), \({"C24ra", "cd[{3.,-1.,1}]"}\)},
            {\({"Qr", "cd[{-1,-1}]"}\), \({"O4a", 
                "cd[{-1,1.,-1.}]"}\), \({"Cm311", "cd[{-3,-1.,-1.}]"}\)},
            {\({"Kr", "cd[{4.}]"}\), \({"O4b", 
                "cd[{-1,-1.,-1.}]"}\), \({"C24rb", "cd[{3.,-1.,-1.}]"}\)},
            {\({"O2", "cd[{-1,1}]"}\), \({"KKr", "cd[{4.,1}]"}\), \({"C12n", 
                "cd[{-3,1.,-1}]"}\)},
            {\({"Dav", "cd[{-1,-1.}]"}\), \({"Octr", 
                "cd[{-1,-1,-1}]"}\), \({"Sed", "cd[{-1,-1,-1,-1}]"}\)},
            {\({"CL2", "cd[{1,-1}]"}\), \({"C4C4r", 
                "cd[{-2,1,-1.}]"}\), \({"O8", "cd[{1,1,1,-1.}]"}\)},
            {\({"C4C2r", "cd[{-4}]"}\), \({"Octi", 
                "cd[{1,-1,-1}]"}\), \({"\!\(C2\^5\)r", "cd[{4.,1,1}]"}\)},
            {\({"C3C4j", "cd[{-2,1}]"}\), \({"O4k", 
                "cd[{-2,1,1}]"}\), \({"C4KC2r", "cd[{4.,1,-1.}]"}\)},
            {\({"C8c", "cd[{-4.}]"}\), \({"C8n", 
                "cd[{2,-1.,-1}]"}\), \({"C8Kr", "cd[{-4.,1,1}]"}\)},
            {\({"KC3c", "cd[{3.,1}]"}\), \({"Alt12n", 
                "cd[{-1,-1,{3}}]"}\), \({"O8a", "cd[{4,1,-1.}]"}\)},
            {\({"C3Kr", "cd[{-3,1}]"}\), \({"C3Dav", 
                "cd[{3,-1.,-1.}]"}\), \({"O16", "cd[{-1,1,1,1,1}]"}\)},
            {\({"C3C4c", "cd[{3,-1.}]"}\), \({"C3r8", 
                "cd[{3,-1.,1}]"}\), \({}\)},
            {\({"Clm3r", "cd[{-3,-1.}]"}\), \({"C6Kc", 
                "cd[{3.,1,1}]"}\), \({}\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tFour of these (C8n, C12n, Alt12n, and Sed) are not conservative. \
Candidates for inclusion in the database should be checked by the following \
routine. ",
  "The first  case is neither conservative nor Moufang, though it has the \
same ",
  StyleBox["dico",
    FontSlant->"Italic"],
  " as Q8C2M:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(id[
        tst = co[cd[{1, \(-1\), \(-1\), 1}], 
            C2]];\)\), "\[IndentingNewLine]", 
    \(If[indexTableQ[tst], {idc[tst], associativeQ[tst], alternativeQ[tst], 
        MoufangQ[tst], dico[tst]}]\), "\[IndentingNewLine]", 
    \(\(id[tst = mp["\<Q8C2M\>"]];\)\), "\n", 
    \(If[indexTableQ[tst], {idc[tst], associativeQ[tst], alternativeQ[tst], 
        MoufangQ[tst], dico[tst]}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"Not conservative.", False, False, False, {20, 12, 31}}\)], "Output"],

Cell[BoxData[
    \({"Q8C2M", False, True, True, {20, 12, 31}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Other Clifford-like algebras are created by the ",
  StyleBox["cl",
    FontSlant->"Italic"],
  " routine, but their protoloops are generated by other routines:-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Test 5. Generalized Clifford Algebra validation & listing.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(clcases = 0; cld = {}; 
    Do[Do[If[Take[Characters[loop[\([m, n, 4]\)]], 
              2] == {"\<c\>", "\<l\>"}, \(clcases++\); 
          If[idc[] \[NotEqual] loop[\([m, n, 1]\)], Print[{m, n}]]; 
          AppendTo[cld, {loop[\([m, n, 1]\)], loop[\([m, n, 4]\)]}]], {n, 
          Length[loop[\([m]\)]]}], {m, 
        33}]; {clcases, "\< have cl prescriptions\>"}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({16, " have cl prescriptions"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl = Table[{cld[\([i]\)], cld[\([i + 8]\)]}, {i, 8}]; 
    tbl // tf\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\({"CL3", "cl[3]"}\), \({"CL4", "cl[4]"}\)},
              {\({"CL12", "cl[1,2]"}\), \({"CL31", "cl[3,1]"}\)},
              {\({"CL21", "cl[2,1]"}\), \({"CL22", "cl[2,2]"}\)},
              {\({"CL03", "cl[0,3]"}\), \({"CL13", "cl[1,3]"}\)},
              {\({"r31r", "cl[4,{2}]"}\), \({"CL04", "cl[0,4]"}\)},
              {\({"r31s", "cl[4,{2,3}]"}\), \({"CL5?", "cl[5]"}\)},
              {\({"r31t", "cl[4,{2,4}]"}\), \({"CL32", "cl[3,2]"}\)},
              {\({"r31u", "cl[4,{1,3}]"}\), \({"CL41?", "cl[4,1]"}\)}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{"CL3", "cl[3]"}, {"CL4", "cl[4]"}}, {{"CL12", 
          "cl[1,2]"}, {"CL31", "cl[3,1]"}}, {{"CL21", "cl[2,1]"}, {"CL22", 
          "cl[2,2]"}}, {{"CL03", "cl[0,3]"}, {"CL13", "cl[1,3]"}}, {{"r31r", 
          "cl[4,{2}]"}, {"CL04", "cl[0,4]"}}, {{"r31s", "cl[4,{2,3}]"}, {
          "CL5?", "cl[5]"}}, {{"r31t", "cl[4,{2,4}]"}, {"CL32", 
          "cl[3,2]"}}, {{"r31u", "cl[4,{1,3}]"}, {"CL41?", "cl[4,1]"}}}, 
          TableDepth -> 2]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Test 6. Signed Table Generation.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tscases = 0; tsd = {}; 
    Do[Do[If[Take[Characters[loop[\([m, n, 4]\)]], 
              2] == {"\<t\>", "\<s\>"}, \(tscases++\); 
          If[idc[] \[NotEqual] loop[\([m, n, 1]\)], Print[{m, n}]]; 
          AppendTo[tsd, {loop[\([m, n, 1]\)], loop[\([m, n, 4]\)]}]], {n, 
          Length[loop[\([m]\)]]}], {m, 
        24}]; {tscases, "\< have ts prescriptions\>"}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({37, " have ts prescriptions"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Validation of Relator Rules.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["Test 7. Relator rules validation.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ung = {}; totl = 1; relco = 0;\), "\n", 
    \(Do[Do[\(totl++\); 
        If[loop[\([m, n, 5]\)] === {}, 
          AppendTo[ung, {{m, n}, loop[\([m, n, 1]\)]}], \(relco++\)], {n, 
          Length[loop[\([m]\)]]}], {m, 2, lp}]; 
    Print[totl, "\< loops, \>", \ relco, "\< relators.\>"]; 
    Print[Length[ung]\ "\< tables without generation rules.\>"];\), "\n", 
    \(Print[
      Length[unpg = 
            Intersection[unp, 
              ung]]\ "\< tables without prescription or generation rules.\>"]\
\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    InterpretationBox[\(813\[InvisibleSpace]" loops, "\[InvisibleSpace]465\
\[InvisibleSpace]" relators."\),
      SequenceForm[ 813, " loops, ", 465, " relators."],
      Editable->False]], "Print"],

Cell[BoxData[
    \(347\ " tables without generation rules."\)], "Print"],

Cell[BoxData[
    \(153\ " tables without prescription or generation rules."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pr = 0; genco = 0; tt = AbsoluteTime[]; 
    Do[Do[If[pr == 1, Print[gd[m, n]]]; 
          If[\[InvisibleSpace]Position[ung, {m, n}] === {}, 
            If[\((gi = 
                    id[mp[{m, n}, 
                        1]])\) \[NotEqual] \((gj = \(gd[{m, n}]\)[\([3, 
                        1]\)])\), Print[{gi, gj, m, n}], \(genco++\); 
              mn = {m, n}]], {n, 1, Length[loop[\([m]\)]]}], {m, 3, lp - 1}] // 
      Timing\), "\[IndentingNewLine]", 
    \({genco, "\< Loops tested\>"}\), "\[IndentingNewLine]", 
    \(Print[{AbsoluteTime[] - tt, "\<actual seconds.\nLast mm,nn=\>", 
        mn}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({2657.24`\ Second, Null}\)], "Output"],

Cell[BoxData[
    \({463, " Loops tested"}\)], "Output"],

Cell[BoxData[
    \({2657.`9.144, "actual seconds.\nLast mm,nn=", {104, 1}}\)], "Print"]
}, Open  ]],

Cell["Many 64-element group descriptions are incomplete.", "Text",
  PageWidth->WindowWidth],

Cell["\<\
Error report occasionally appear for valid cases. Repeat the specific test to \
check these.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "1.4 ",
  StyleBox["hoopTest",
    FontSlant->"Italic"],
  " for Hoop Algebras."
}], "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t",
  StyleBox["hoopTest[loop_identifier]",
    FontSlant->"Italic"],
  " looks in the database for a ",
  StyleBox["shape",
    FontSlant->"Italic"],
  " for the loop, and attempts to create it if it is not there. It aborts if \
the conservation test fails. Division using  ",
  StyleBox["genInverse",
    FontSlant->"Italic"],
  " is tested. Then polar-vector transformations are tested. Polar algebras \
are tested for +ve powers and roots, and (if abelian) for a valid solution of \
a random real quadratic equation. Finally, negative powers are tested (as \
non-abelian loops fail this test it is only applied to abelian tables, and is \
repeated until a vec with the correct shape is found, for up to 10 times.) \
The output identifies the loop (if it is in the database) and reports which \
tests have been passed. Test 10 tests the loops with known shapes (and the \
first non-hoop with known shape, Q4n):-"
}], "Text",
  PageWidth->WindowWidth],

Cell["Test 8. hoopTest for small Loops.", "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[hoopTest[hoopList[\([ijk]\)]]], {ijk, 
        Length[hoopList] - 3}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("Conservative C2, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers, hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4c, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C2c, division, polar-vector, +ve Powers, quadratic \
eqn., -ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C12c, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3i, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C3c, division, polar-vector, +ve Powers test(s) passed"\
\)], "Print"],

Cell[BoxData[
    \("Conservative C3C3j, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C9j, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C9J, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4, division, polar-vector, +ve Powers, -ve Powers, \
hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative K, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers, hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Qr, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative P4, division, polar-vector, +ve Powers, hyPolar test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Dav, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative O2, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C8r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C4j, division, polar-vector, +ve Powers, quadratic \
eqn., -ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL2, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C2r, division, polar-vector, +ve Powers, -ve Powers, \
hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative P16c, division, polar-vector test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C8c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C5, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C2, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers, hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D3, division, polar-vector, +ve Powers, -ve Powers, \
hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C4c, division, polar-vector, +ve Powers, quadratic \
eqn., -ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q12c, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q12r, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q12r, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative g2401c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D6r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D3C2c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KC3c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3Kr, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Cl3r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Clm3r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C8, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KC2, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C2, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D4, division, polar-vector, +ve Powers, -ve Powers, \
hyPolar test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q8, division, polar-vector, +ve Powers, hyPolar test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Octr, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KiC4c, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative O4, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative O4a, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative O4b, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C4c, division, polar-vector, +ve Powers, quadratic \
eqn., -ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C4r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q8C2r, division, polar-vector, +ve Powers test(s) passed"\
\)], "Print"],

Cell[BoxData[
    \("Conservative C2D4r, division, polar-vector, +ve Powers test(s) passed"\
\)], "Print"],

Cell[BoxData[
    \("Conservative P8, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL3, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4iC4c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative QC2r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KiC4r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL21, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL03, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Octi, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C3, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C9, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C6C3c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C4, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3K, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q12, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D3C2, division, polar-vector, +ve Powers test(s) \
passed"\)], "Print"],

Cell[BoxData[
    \("Conservative A4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3Qr, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3P4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C6Kr, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3KC2r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q12C2c, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D8, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q16, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative D4C2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4C4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q8C2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KK, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4K, division, polar-vector, +ve Powers, -ve Powers \
test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative KiC4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C4iC4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative P16, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Oct, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative Q8M2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL4, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL13, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL22, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL31, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative r31r, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL04, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative O8, division, polar-vector, +ve Powers, quadratic eqn., \
-ve Powers test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative C3C4C2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL31C2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Conservative CL4C2, division test(s) passed"\)], "Print"],

Cell[BoxData[
    \("Q4n Isomorph. Protoloop factors NOT conserved"\)], "Print"],

Cell[BoxData[
    \("Q4n No other test(s) passed"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Plex-conjugates.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Test\ 9. \ Plexes\ *) \)\(mcount = 0; 
    pl = {};\[IndentingNewLine]
    \(Do[\[IndentingNewLine]Do[plex =. ; id[mp[m1, n1]]; 
          If[\((Head[sh[gmn]] \[Equal] List)\) && 
              ListQ[plex], \[IndentingNewLine]AppendTo[pl, 
              gmn]; \(mcount++\);], \[IndentingNewLine]{n1, 
            Length[loop[\([m1]\)]]}], \[IndentingNewLine]{m1, 2, 
          16}];\)\[IndentingNewLine]
    Print[{mcount, "\< plex-conjugates\>", pl}]\)\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({51, 
      " plex-conjugates", {"C2", "C4c", "C3", "C3C2c", "K", "C4", "Qr", "O2", 
        "Dav", "CL2", "P4", "C4C2r", "C3C4j", "C8r", "P16c", "C3C2", "Q12c", 
        "Q12r", "KC3c", "C3C4c", "D3C2c", "Clm3r", "Cl3r", "g2401c", "C8", 
        "C4C2", "Q8", "KC2", "C4C4c", "C4iC4c", "QC2r", "Q8C2r", "O4", "O4a", 
        "O4b", "P8", "C2D4r", "CL3", "CL3", "Octr", "KiC4r", "CL21", "CL03", 
        "C4C4r", "Octi", "C3C3", "C3C4", "C3K", "C3KC2r", "C6Kr", 
        "r31r"}}\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6 Remainders.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tMultiplication (and division) using hoops with disparate zero sizes is not \
conservative unless the appropriate sizes of the multiplicands are \
\"ejected\" as remainders. The product is \"projected\" onto a sub-algebra \
with zeroed sizes. This is tested by the following procedure, which \
identifies the hoop, pads short vectors with zeroes, multiplies them, saves \
the result as R1, AB, R2, shows the results and their shapes, and confirms \
that AB/B+Rl=A & AB/A+Rr=B.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(muldiv[Ao_, Bo_, H_] := 
        Module[{s = Length[sh[H]], z = Table[0, {i, 32}]}, gmn = H; 
          glo = mp[H]; mm = Length[glo]; 
          s = Take[Flatten[{"\<shape\>", Range[s]}]]; 
          A = Take[Flatten[Append[Ao, z]], mm]; 
          B = Take[Flatten[Append[Bo, z]], mm]; 
          Print[{Flatten[Append[{"\<A  =\>"}, A]], 
                Flatten[Append[{"\<B  =\>"}, B]], \[IndentingNewLine]Flatten[
                  Append[{"\<AB =\>"}, 
                    AB = hoopTimes[A, B]]], \[IndentingNewLine]Flatten[
                  Append[{"\<Rl =\>"}, R1 = Rl]], \[IndentingNewLine]Flatten[
                  Append[{"\<Rr =\>"}, R2 = Rr]]} // tf]; \n
          Print[Chop[{s, Flatten[Append[{"\<shA  =\>"}, shape[A]]], 
                  Flatten[Append[{"\<shB  =\>"}, shape[B]]], 
                  Flatten[Append[{"\<shAB =\>"}, shape[AB]]], 
                  Flatten[Append[{"\<shRl =\>"}, shape[Rl]]], 
                  Flatten[Append[{"\<shRr =\>"}, shape[Rr]]]}] // tf]; 
          Print[Chop[{"\<AB/B+Rl=A  \>", 
                hoopTimes[AB, hoopInverse[B]] + R1, "\<\nAB/A+Rr=B  \>", 
                hoopTimes[hoopInverse[A], AB] + R2}]]];\)\)], "Input",
  PageWidth->WindowWidth],

Cell["\<\
The remainders have been checked for all the members of hoopList. Examples, \
with some zero sizes, are:- \
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(muldiv[{3. , 4. , 1. , 0. , 1. , 1. , 2. , \(-2. \), 3. , 
          4. , \(-2. \), 3. , \(-1. \), 0. , 3. , 2. }, {2. , 1. , 
          2. , \(-4. \), 3. , \(-4. \), 3. , 1. , 0. , 0. , \(-3. \), 2. , 
          2. , 4. , 
          1. , \(-2. \)}, \[IndentingNewLine]"\<C3C4\>"];\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`", 
                "2.`", \(-2.`\), "3.`", "4.`", \(-2.`\), "3.`"},
              {"\<\"B  =\"\>", "2.`", "1.`", "2.`", \(-4.`\), "3.`", \(-4.`\),
                 "3.`", "1.`", "0.`", "0.`", \(-3.`\), "2.`"},
              {"\<\"AB =\"\>", "24.`", "19.`", \(-18.`\), \(-20.`\), \(-9.`\),
                 "16.`", \(-1.`\), "5.`", "28.`", "22.`", "4.`", \(-16.`\)},
              {"\<\"Rl =\"\>", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                "0", "0", "0"},
              {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape\"\>", "1", "2", "3", "4", "5", "6", "7"},
              {"\<\"shA  =\"\>", "18.`", "4.`", "34.`", "57.`", "7.`", 
                "141.6935750346352`", "34.3064249653648`"},
              {"\<\"shB  =\"\>", "3.`", "15.`", "17.`", "3.`", "39.`", 
                "75.57437415779592`", "186.42562584220406`"},
              {"\<\"shAB =\"\>", "54.`", "60.`", "578.`", "171.`", "273.`", 
                "10708.403255423253`", "6395.596744576747`"},
              {"\<\"shRl =\"\>", "0", "0", "0", "0", "0", "0", "0"},
              {"\<\"shRr =\"\>", "0", "0", "0", "0", "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"AB/B+Rl=A  ", {2.9999999999999987`, 4.`, 0.9999999999999998`, 0, 
        1.000000000000001`, 0.999999999999999`, 
        1.9999999999999996`, \(-2.000000000000001`\), 2.9999999999999996`, 
        4.000000000000001`, \(-2.000000000000001`\), 3.000000000000001`}, 
      "\nAB/A+Rr=B  ", {2.`, 1.0000000000000007`, 
        2.0000000000000004`, \(-4.`\), 
        2.9999999999999982`, \(-3.9999999999999987`\), 3.`, 
        0.9999999999999996`, 0, 0, \(-2.999999999999999`\), 2.`}}\)], "Print",\

  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(muldiv[{3, 4, 1, 0, 1, 1, 2, \(-2\), 3, 4, \(-2\), 3, \(-1\), 0, 3, 
            2} // N, {2, 1, 2, \(-4\), 4, 2, \(-1\), 2, 0, 0, \(-3\), 2, 2, 
            4, 1, \(-2\)} // N, \[IndentingNewLine]"\<CL03\>"];\)\)], "Input",\

  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`", 
                "2.`", \(-2.`\)},
              {"\<\"B  =\"\>", "2.`", "1.`", "2.`", \(-4.`\), "4.`", 
                "2.`", \(-1.`\), "2.`"},
              {"\<\"AB =\"\>", \(-8.`\), \(-1.`\), "13.`", \(-4.`\), "4.`", 
                "13.`", "1.`", \(-8.`\)},
              {"\<\"Rl =\"\>", "2.5`", "3.`", "0", "0.5`", "0.5`", "0", 
                "3.`", \(-2.5`\)},
              {"\<\"Rr =\"\>", "0", "0", "0", "0", "0", "0", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape\"\>", "1", "2"},
              {"\<\"shA  =\"\>", "62.`", "10.`"},
              {"\<\"shB  =\"\>", "0", "100.`"},
              {"\<\"shAB =\"\>", "0", "1000.`"},
              {"\<\"shRl =\"\>", "62.`", "0"},
              {"\<\"shRr =\"\>", "0", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"AB/B+Rl=A  ", {3.`, 4.`, 1.`, 0, 1.`, 1.`, 
        1.9999999999999998`, \(-2.`\)}, 
      "\nAB/A+Rr=B  ", {1.9999999999999998`, 0.9999999999999999`, 
        2.0000000000000004`, \(-3.9999999999999996`\), 3.9999999999999996`, 
        2.0000000000000004`, \(-0.9999999999999999`\), 
        1.9999999999999998`}}\)], "Print",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(muldiv[{3, 4, 1, 0, 1, 1, 2, \(-2\), 3, 4, \(-2\), 3, \(-1\), 0, 3, 
            2} // N, {2, 1, 2, \(-4\), 3, \(-4\), 3, 1, 0, 0, \(-3\), 2, 2, 
            4, 1, \(-2\)} // N, \[IndentingNewLine]"\<D3\>"];\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"A  =\"\>", "3.`", "4.`", "1.`", "0.`", "1.`", "1.`"},
              {"\<\"B  =\"\>", "2.`", "1.`", "2.`", \(-4.`\), 
                "3.`", \(-4.`\)},
              {"\<\"AB =\"\>", "11.`", 
                "6.`", \(-9.`\), \(-1.`\), \(-2.`\), \(-5.`\)},
              {"\<\"Rl =\"\>", "1.6666666666666667`", "1.6666666666666674`", 
                "1.6666666666666667`", "1.6666666666666667`", 
                "1.6666666666666665`", "1.6666666666666667`"},
              {"\<\"Rr =\"\>", "2.3333333333333335`", \(-2.333333333333333`\),
                 "2.3333333333333335`", \(-2.3333333333333335`\), 
                "2.3333333333333335`", \(-2.333333333333333`\)}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    TagBox[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"shape\"\>", "1", "2", "3"},
              {"\<\"shA  =\"\>", "10.`", "0", \(-9.`\)},
              {"\<\"shB  =\"\>", "0", "14.`", \(-24.`\)},
              {"\<\"shAB =\"\>", "0", "0", "216.`"},
              {"\<\"shRl =\"\>", "10.`", "0", "0"},
              {"\<\"shRr =\"\>", "0", "14.`", "0"}
              }], "\[NoBreak]", ")"}],
        "TraditionalForm"],
      TraditionalForm,
      Editable->True]], "Print",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"AB/B+Rl=A  ", {3.`, 4.`, 1.`, 0, 0.9999999999999999`, 1.`}, 
      "\nAB/A+Rr=B  ", {2.`, 1.`, 2.`, \(-4.`\), 3.`, \(-4.`\)}}\)], "Print",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Octonion and Dozal conservation.", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Summary. ",
  StyleBox["Conservation is investigated for Octonion and Dozal algebras.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["2.1 Conservation of Octonion Compositions.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\thoopTimes[A,B,tst,1]",
    FontSlant->"Italic"],
  " uses a minimal multiplication routine, developed to test conservation of \
large tables that may not be in the databank. The table is conservative if at \
least one result is 0. Repeat the test if both are zero, as this means that \
the product has a zero size."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = co[Oct, tst1 = mp[8, 2]]; id[tst1]\), "\[IndentingNewLine]", 
    \(A = Table[Random[Integer, {\(-9\), 9}], {i, Length[tst]}]; 
    B = Table[
        Random[Integer, {\(-9\), 9}], {i, 
          Length[tst]}];\), "\[IndentingNewLine]", 
    \(\(AB = hoopTimes[A, B, tst, 1];\)\), "\[IndentingNewLine]", 
    \(sA = Det[gmap[tst, A]]; 
    sB = Det[gmap[tst, B]];\), "\[IndentingNewLine]", 
    \(sAB = 
      Det[gmap[tst, 
          AB]]; {Chop[\((sA\ sB + sAB)\)/\((sA + 
              sB)\)], \[IndentingNewLine]Chop[\((sA\ sB - sAB)\)/\((sA + 
              sB)\)]}\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("C4C2"\)], "Output",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({0, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Direct compositions of Oct and the followng tables gave the following \
results:-
Conservative.\t\t\t\t\tNon-conservative.
C2,C3,C4,K,C5,C3C2,C8,C4C2,\tC5n,D3,C6n,D4,Q8,D5,Q12,A4,
KC2,C9,C3C3,C10,C11,C3C4,C3K,\tD3C2,Alt12n,KiC4,C4iC4,C8pC2,
C16,C4C4,C8C2,C4K,KK\t\tD8,Q8iC2,Q16,D4C2,Q8C2,P16,Oct
In this test, all abelain groups, and no non-abelian tables, give \
conservative octonions on direct composition with Oct.
Indirect compositions (where the result differed from the direct composition) \
gave no conservative tables, as in the following test:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(tst = co[Oct, tst1 = mp[6, 2]]; {Length[tst], 
      id[tst], \[IndentingNewLine]dico[tst], \[IndentingNewLine]alternativeQ[
        tst], \[IndentingNewLine]A = 
        Table[Random[Integer, {\(-9\), 9}], {i, Length[tst]}]; 
      B = Table[
          Random[Integer, {\(-9\), 9}], {i, 
            Length[tst]}]; \[IndentingNewLine]AB = 
        hoopTimes[A, B, tst]; \[IndentingNewLine]sA = Det[gmap[tst, A]]; 
      sB = Det[gmap[tst, B]]; \[IndentingNewLine]sAB = 
        Det[gmap[tst, 
            AB]]; \[IndentingNewLine]Chop[\((sA\ sB - sAB)\)/\((sA + 
              sB)\)]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({96, "Unrecognised", {4, 4\_2, 28\_3}, True, 0}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Conservation of Dozal functions.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
This section attempts to tabulate the conservation rules for Dozal, to help \
relate them to physics.
Test cases for A, polar forms (orbits) that are converted to vectors:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(testA = { (*1\ \
\[Alpha]\[Beta]\[Epsilon]\[Zeta]\[Lambda]\[Eta]\[Kappa]*) {1. , 
            1. ,  .34,  .4,  .51,  .22,  .71,  .3,  .82, 
            0.32,  .9,  .66}, \[IndentingNewLine] (*2\ \[Alpha]*) {1, 
            0. ,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0}, \
\[IndentingNewLine] (*3\ \[Beta]*) {0. , 
            1,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0}, \
\[IndentingNewLine] (*4\ \[Epsilon]\ or\ \[Gamma]*) {0. ,  .0, 
            1,  .1,  .0,  .0,  .0,  .0,  .0,  .0,  .0,  .0}, \
\[IndentingNewLine] (*5\ \[Zeta]*) {0. ,  .0, 0. ,  .0, 
            1,  .1,  .0,  .0,  .0,  .0,  .0,  .0}, \[IndentingNewLine] (*6\ \
\[Lambda]*) {0. ,  .0,  .0,  .0,  .0,  .0, 
            1,  .2,  .0,  .0,  .0,  .0}, \[IndentingNewLine] (*7\ \[Eta]*) \
{0. ,  .0,  .0,  .0,  .0,  .0, 0. , 0. , 
            1,  .3,  .0,  .0}, \[IndentingNewLine] (*8\ \[Kappa]*) {0. ,  .0, \
 .0,  .0,  .0,  .0,  .0,  .0,  .0, 0. , 
            1. ,  .4}, \[IndentingNewLine] (*9\ \[Epsilon]\[Zeta]*) {0. ,  \
.0, 1,  .1, 
            1. ,  .1,  .0,  .0,  .0,  .0,  .0,  .0}, \[IndentingNewLine] (*10\
\ \[Epsilon]\[Lambda]*) {0. ,  .0, 1,  .1,  .0,  .0, 
            1. ,  .1,  .0,  .0,  .0,  .0}, \[IndentingNewLine] (*11\ \
\[Epsilon]\[Eta]*) {0. ,  .0, 1,  .1,  .0,  .0,  .0,  .0, 
            1. ,  .1,  .0,  .0}, \[IndentingNewLine] (*12\ \[Epsilon]\[Kappa]*) \
{0. ,  .0, 1,  .1,  .0,  .0,  .0,  .0,  .0,  .0, 
            1. ,  .1}, \[IndentingNewLine] (*13\ \[Zeta]\[Eta]*) {0. ,  .0,  \
.0,  .0, 1. ,  .2, 0. , 0. , 
            1. ,  .3,  .0,  .0}, \[IndentingNewLine] (*14\ \[Zeta]\[Kappa]*) \
{0. ,  .0,  .0,  .0, 1. ,  .2, 0. , 0. , 0. , 0. , 
            1. ,  .3}, \[IndentingNewLine] (*15\ \[Lambda]\[Eta]\[Kappa]*) \
{0. ,  .0, 0,  .0,  .0,  .0, 1. ,  .1, 1. ,  .3, 
            1.0,  .2}, \[IndentingNewLine] (*\(16\ \
\[Lambda]\[Eta]\[Kappa]\)\(=\)*) {0. ,  .0, 0,  .0,  .0,  .0, 1. ,  .1, 
            1. ,  .1, 
            1. ,  .1}, \[IndentingNewLine] (*17\ \[Beta]\[Lambda]\[Eta]\
\[Kappa]*) {0. , 1. , 0,  .0,  .0,  .0, 1. ,  .1, 1. ,  .1, 
            1. ,  .1}, \[IndentingNewLine] (*18\ \[Eta]\[Kappa]*) {0. ,  .0,  \
.0,  .0, 0. ,  .0, 0. , 0. , 1. ,  .3, 
            1.0,  .7}, \[IndentingNewLine] (*\(19\ \[Eta]\[Kappa]\)\(=\)*) \
{0. ,  .0,  .0,  .0, 0. ,  .0, 0. , 0. , 1. ,  .3, 
            1. ,  .3}, \[IndentingNewLine] (*20\ \[Lambda]\[Eta]\[Kappa]r*) \
{0. , 0, 0, 0, 0, 0, 1. ,  .3,  .1,  .3, 10. ,  .3}};\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tSingle sizes, pairs and triples (omitting the linear sizes) and 4 sets of \
unit sizes are squared in turn, with different angles unless the name has a \
trailing \"=\". The last case has three sizes  .1, 1, 10; this is the \"Three \
Scales\" model.
\tOther cases can be added to investigate different hypotheses. Each loop is \
used in tern below;  the conserved functions are indicated by \"C\", \"K\", \
\"Q\", \"D\",  \"c\" , \"1\" if the function value is 1, \"0\" if it is zero, \
and those that are not conserved by \"n\". \
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = "\<C3C4\>"; id[tst]; dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", 
    \(Do[cs = {}; A = \[IndentingNewLine]testA[\([j]\)]; 
      A = Chop[toVector[A]]; AA = \ hoopTimes[A, A]; 
      res = {sa = sh12[A], saa = sh12[AA], sasa = sa\ sa, 
          Chop[saa - sasa, 10^\(-8\)], Range[Length[sa]]}; 
      AppendTo[colname, tst]; AppendTo[cs, Length[colname]]; 
      Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
          If[res[\([4, i]\)] \[Equal] 0, 
            AppendTo[cs, If[res[\([3, i]\)] \[Equal] 1, "\<1\>", "\<C\>"]], 
            AppendTo[cs, "\<n\>"]]], {i, Length[sa]}]; 
      AppendTo[dozalconserve, cs], {j, Length[testA]}]; 
    Transpose[dozalconserve] // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"C3C4\"\>", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
              "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
              "20"},
            {"\<\"o1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "0", "\<\"C\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", 
              "0", "\<\"C\"\>"},
            {"\<\"o2\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>",
               "0", "\<\"C\"\>", "\<\"C\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", 
              "0", "\<\"C\"\>"},
            {"\<\"o3\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>",
               "0", "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"o4\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>",
               "0", "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"l22a\"\>", "\<\"C\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>"},
            {"\<\"l22b\"\>", "\<\"C\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>"},
            {"\<\"p22\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "0", 
              
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "0", 
              "0", "\<\"C\"\>"},
            {"\<\"q22\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"1\"\>", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"r22\"\>", "\<\"C\"\>", "0", "0", "0", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "0", "0", "0", "\<\"C\"\>"},
            {"\<\"s22\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"p23\"\>", "\<\"C\"\>", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>"},
            {"\<\"q23\"\>", "\<\"C\"\>", "0", "0", "0", 
              "0", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>"},
            {"\<\"r23\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"s23\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"q24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"s24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"n\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"p26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
            {"\<\"q26\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"r26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"n\"\>"},
            {"\<\"s26\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"l3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "0", "\<\"C\"\>"},
            {"\<\"l4p\"\>", "\<\"C\"\>", "0", "0", 
              
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
            {"\<\"l4q\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"l4r\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"n\"\>"},
            {"\<\"l4s\"\>", "\<\"C\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"L4Q\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4\[Sigma]\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", \
"\<\"n\"\>"},
            {"\<\"L4a3\"\>", "\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>"},
            {"\<\"L4b3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"1\"\>"},
            {"\<\"L4c3\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"L4d3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"L4a6\"\>", "\<\"C\"\>", "0", "0", 
              "0", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"C\"\>"},
            {"\<\"L4b6\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"L4c6\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"L4d6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"n\"\>"},
            {"\<\"L49\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49a\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"C\"\>", \
"\<\"n\"\>"},
            {"\<\"L49b\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L49c\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"C\"\>", "\<\"n\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = "\<C3K\>"; id[tst]; dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", 
    \(Do[cs = {}; A = \[IndentingNewLine]testA[\([j]\)]; 
      A = Chop[toVector[A]]; AA = \ hoopTimes[A, A]; 
      res = {sa = sh12[A], saa = sh12[AA], sasa = sa\ sa, 
          Chop[saa - sasa, 10^\(-8\)], Range[Length[sa]]}; 
      AppendTo[colname, tst]; AppendTo[cs, Length[colname]]; 
      Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
          If[res[\([4, i]\)] \[Equal] 0, 
            AppendTo[cs, If[res[\([3, i]\)] \[Equal] 1, "\<1\>", "\<K\>"]], 
            AppendTo[cs, "\<n\>"]]], {i, Length[sa]}]; 
      AppendTo[dozalconserve, cs], {j, Length[testA]}]; 
    Transpose[dozalconserve] // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"C3K\"\>", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
               "11", "12", "13", "14", "15", "16", "17", "18", "19", "20"},
            {"\<\"o1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "0", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"o2\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>",
               "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"o3\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>",
               "0", "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"o4\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>",
               "0", "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"l22a\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"l22b\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"p22\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"q22\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"n\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"r22\"\>", "\<\"1\"\>", "0", "0", "\<\"K\"\>", "0", "0", "0",
               "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>"},
            {"\<\"s22\"\>", "\<\"K\"\>", "0", "0", "\<\"K\"\>", "0", "0", "0",
               "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>"},
            {"\<\"p23\"\>", "\<\"K\"\>", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"K\"\>", 
              "0", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"q23\"\>", "\<\"K\"\>", "0", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "0", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"1\"\>"},
            {"\<\"r23\"\>", "\<\"K\"\>", "0", "0", "0", "0", "0", "\<\"1\"\>",
               "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>", \
"\<\"1\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"K\"\>"},
            {"\<\"s23\"\>", "\<\"K\"\>", "0", "0", "0", "0", "\<\"K\"\>", 
              "0", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\
\"\>", "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"K\"\>"},
            {"\<\"q24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"s24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"n\"\>", "\<\"K\"\>", "0", "\<\"K\"\>"},
            {"\<\"p26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"q26\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"r26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"n\"\>"},
            {"\<\"s26\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"l3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"K\
\"\>", "0", "\<\"K\"\>"},
            {"\<\"l4p\"\>", "\<\"K\"\>", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"l4q\"\>", "\<\"K\"\>", "0", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"l4r\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"n\"\>"},
            {"\<\"l4s\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>"},
            {"\<\"L4Q\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4\[Sigma]\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", \
"\<\"n\"\>"},
            {"\<\"L4a3\"\>", "\<\"n\"\>", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"K\"\>", 
              "0", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"L4b3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "\<\"1\"\>", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "0", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"1\"\>"},
            {"\<\"L4c3\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"1\"\>", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"K\"\>", "\<\"1\
\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"K\"\>"},
            {"\<\"L4d3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "\<\"K\"\>", 
              "0", "\<\"1\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\
\"\>", "0", "\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"1\"\>", "\<\"K\"\>"},
            {"\<\"L4a6\"\>", "\<\"K\"\>", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"K\"\>", "\<\"K\"\>"},
            {"\<\"L4b6\"\>", "\<\"K\"\>", "0", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"L4c6\"\>", "\<\"n\"\>", "0", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"1\"\>"},
            {"\<\"L4d6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"n\"\>"},
            {"\<\"L49\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49a\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"K\"\>", \
"\<\"n\"\>"},
            {"\<\"L49b\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L49c\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"K\"\>", "\<\"n\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = "\<Q12\>"; id[tst]; dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", 
    \(Do[cs = {}; A = \[IndentingNewLine]testA[\([j]\)]; 
      A = Chop[toVector[A]]; AA = \ hoopTimes[A, A]; 
      res = {sa = sh12[A], saa = sh12[AA], sasa = sa\ sa, 
          Chop[saa - sasa, 10^\(-8\)], Range[Length[sa]]}; 
      AppendTo[colname, tst]; AppendTo[cs, Length[colname]]; 
      Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
          If[res[\([4, i]\)] \[Equal] 0, 
            AppendTo[cs, If[res[\([3, i]\)] \[Equal] 1, "\<1\>", "\<Q\>"]], 
            AppendTo[cs, "\<n\>"]]], {i, Length[sa]}]; 
      AppendTo[dozalconserve, cs], {j, Length[testA]}]; 
    Transpose[dozalconserve] // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Q12\"\>", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
               "11", "12", "13", "14", "15", "16", "17", "18", "19", "20"},
            {"\<\"o1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"o2\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"1\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"o3\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>",
               "0", "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"o4\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>",
               "0", "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"l22a\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l22b\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"p22\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", 
              "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>"},
            {"\<\"q22\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>", "0", 
              "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"r22\"\>", "\<\"1\"\>", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", "\<\"Q\"\>"},
            {"\<\"s22\"\>", "\<\"n\"\>", "0", "0", "\<\"n\"\>", "0", 
              "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", 
              "0", "\<\"Q\"\>", "0", "\<\"Q\"\>"},
            {"\<\"p23\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>"},
            {"\<\"q23\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "0", "\<\"1\"\>"},
            {"\<\"r23\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"s23\"\>", "\<\"n\"\>", "0", "0", "0", 
              
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
            {"\<\"q24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"s24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"Q\"\>", 
              "0", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"p26\"\>", "\<\"Q\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "0", "\<\"1\"\>"},
            {"\<\"q26\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"r26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>"},
            {"\<\"s26\"\>", "\<\"Q\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", \
"\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>"},
            {"\<\"l3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
              
              "0", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "0", "\<\"n\"\>", "0", "0", "\<\"Q\"\>"},
            {"\<\"l4p\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "0", "\<\"1\"\>"},
            {"\<\"l4q\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l4r\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>"},
            {"\<\"l4s\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4Q\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4\[Sigma]\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"Q\
\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4a3\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>"},
            {"\<\"L4b3\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "0", "\<\"1\"\>"},
            {"\<\"L4c3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4d3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
            {"\<\"L4a6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "0", "\<\"1\"\>"},
            {"\<\"L4b6\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4c6\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4d6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"1\"\>"},
            {"\<\"L49\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49a\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"Q\"\>", \
"\<\"n\"\>"},
            {"\<\"L49b\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49c\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = "\<D3C2\>"; id[tst]; dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", 
    \(Do[cs = {}; A = testA[\([jj]\)]; A = Chop[toVector[A]]; 
      AA = \ hoopTimes[A, A]; 
      res = {sa = sh12[A], saa = sh12[AA], sasa = sa\ sa, 
          Chop[saa - sasa, 10^\(-8\)], Range[Length[sa]]}; 
      AppendTo[colname, tst]; AppendTo[cs, Length[colname]]; 
      Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
          If[res[\([4, i]\)] \[Equal] 0, 
            AppendTo[cs, If[res[\([3, i]\)] \[Equal] 1, "\<1\>", "\<D\>"]], 
            AppendTo[cs, "\<n\>"]]], {i, Length[sa]}]; 
      AppendTo[dozalconserve, cs], {jj, Length[testA]}]; 
    Transpose[dozalconserve] // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"D3C2\"\>", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
              "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
              "20"},
            {"\<\"o1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"o2\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"1\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"o3\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>",
               "0", "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"o4\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>",
               "0", "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"l22a\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"l22b\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"p22\"\>", "\<\"1\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"q22\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"n\"\>", "0", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"r22\"\>", "\<\"1\"\>", "0", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\
\"\>", "\<\"D\"\>", "0", "\<\"D\"\>"},
            {"\<\"s22\"\>", "\<\"D\"\>", "0", "0", "\<\"D\"\>", "0", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "0", "\<\"D\"\>"},
            {"\<\"p23\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "\<\"1\"\>"},
            {"\<\"q23\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"1\"\>"},
            {"\<\"r23\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
            {"\<\"s23\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"q24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"s24\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", \
"\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>"},
            {"\<\"p26\"\>", "\<\"D\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "\<\"1\"\>"},
            {"\<\"q26\"\>", "\<\"D\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"D\"\>"},
            {"\<\"r26\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"1\"\>"},
            {"\<\"s26\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"l3\"\>", "\<\"n\"\>", "0", "0", "0", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "\<\"D\"\>", 
              "0", "\<\"D\"\>", "\<\"D\"\>", "0", "\<\"D\"\>"},
            {"\<\"l4p\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "\<\"1\"\>"},
            {"\<\"l4q\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", \
"\<\"n\"\>"},
            {"\<\"l4r\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"1\"\>"},
            {"\<\"l4s\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4Q\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4\[Sigma]\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"1\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4a3\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "\<\"1\"\>"},
            {"\<\"L4b3\"\>", "\<\"n\"\>", "0", "0", 
              
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"1\"\>"},
            {"\<\"L4c3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "0", "\<\"n\"\>"},
            {"\<\"L4d3\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L4a6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "0", "\<\"1\"\>"},
            {"\<\"L4b6\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", \
"\<\"n\"\>"},
            {"\<\"L4c6\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", 
              "0", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"1\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"D\"\>", \
"\<\"n\"\>"},
            {"\<\"L4d6\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\
\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"1\"\>", "\<\"1\"\>", \
"\<\"1\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"1\"\>"},
            {"\<\"L49\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", 
              "0", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L49a\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"D\"\>", \
"\<\"n\"\>"},
            {"\<\"L49b\"\>", "\<\"n\"\>", "0", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>"},
            {"\<\"L49c\"\>", "\<\"n\"\>", "0", "0", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"D\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tst = "\<C3C4\>"; id[tst]; dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", 
    \(Do[cs = {}; 
      A = 1.1\ testA[\([j]\)];  (*eliminates\ spurious\ 1' 
          s*)  (*\(OMIT\ toVector\ A = 
            Chop[toVector[A]];\)*) \[IndentingNewLine]AA = \ hoopTimes[A, A]; 
      res = {sa = sh12[A], saa = sh12[AA], sasa = sa\ sa, 
          Chop[saa - sasa, 10^\(-8\)], Range[Length[sa]]}; 
      AppendTo[colname, tst]; AppendTo[cs, Length[colname]]; 
      Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
          If[res[\([4, i]\)] \[Equal] 0, 
            AppendTo[cs, If[res[\([3, i]\)] \[Equal] 1, "\<1\>", "\<c\>"]], 
            AppendTo[cs, "\<n\>"]]], {i, Length[sa]}]; 
      AppendTo[dozalconserve, cs], {j, Length[testA]}]; 
    Transpose[dozalconserve] // tf\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"C3C4\"\>", "1", "2", "3", "4", "5", "6", "7", "8", "9", 
              "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", 
              "20"},
            {"\<\"o1\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"o2\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"o3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"o4\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l22a\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"l22b\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"p22\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"q22\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"r22\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"s22\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "0", 
              "0", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"p23\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"q23\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>"},
            {"\<\"r23\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"s23\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"q24\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"s24\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"p26\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"q26\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"r26\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"s26\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l4p\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
            {"\<\"l4q\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l4r\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"l4s\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\
\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
            {"\<\"L4Q\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4\[Sigma]\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\
\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4a3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4b3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4c3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4d3\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4a6\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", 
              "0", "\<\"c\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>"},
            {"\<\"L4b6\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4c6\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L4d6\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", \
"\<\"n\"\>", "\<\"c\"\>", "\<\"c\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", 
              "0", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\
\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49a\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49b\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"},
            {"\<\"L49c\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", \
"\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>", "\<\"n\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  PageWidth->WindowWidth,
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tThe following procedure tests conservation of the ",
  StyleBox["sh12",
    FontSlant->"Italic"],
  " functions for multiplication of two vectors A & B. If the last parameter \
",
  StyleBox["n",
    FontSlant->"Italic"],
  " is negative, ",
  StyleBox["toVector[A]",
    FontSlant->"Italic"],
  " & ",
  StyleBox["toVector[B]",
    FontSlant->"Italic"],
  " are used. NB ",
  StyleBox["n",
    FontSlant->"Italic"],
  "\[GreaterEqual]-",
  "4, as A4 lacks ",
  StyleBox["toVector",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(Clear[dozaltest]; 
    dozaltest[A0_, B0_, n_:  5] := 
      Module[{A = A0, B = B0, alg, 
          tstname = 
            Take[{"\<C\>", "\<K\>", "\<Q\>", "\<D\>", "\<A\>", "\<P\>", \
"\<q\>", "\<k\>", "\<c\>"}, Abs[n]], 
          tst = Take[{"\<C3C4\>", "\<C3K\>", "\<Q12\>", "\<D3C2\>", "\<A4\>", \
"\<C3P4\>", "\<C3Qr\>", "\<C3KC2r\>", "\<Q12C2c\>"}, Abs[n]], dozalconserve, 
          sa, sb, sasb, sab, AB, cs}, 
        dozalconserve = {Range[39]}; \[IndentingNewLine]Do[cs = {}; 
          alg = tst[\([ii]\)]; 
          If[n < 0, A = Chop[toVector[A, alg]]; 
            B = Chop[toVector[B, alg]]]; \[IndentingNewLine]AB = \ 
            hoopTimes[A, B, alg]; sa = sh12[A]; sb = sh12[B]; sasb = sa\ sb; 
          sab = sh12[AB]; 
          res = Chop[{sa, sb, sab, sasb, sab - sasb, Range[Length[sa]]}]; 
          Do[If[res[\([3, i]\)] \[Equal] 0, AppendTo[cs, 0], 
              If[res[\([5, i]\)] \[Equal] 0, 
                AppendTo[cs, 
                  If[res[\([3, i]\)] \[Equal] 1, "\<1\>", 
                    tstname[\([ii]\)]]], AppendTo[cs, "\<n\>"]]], {i, 
              Length[sa]}]; 
          AppendTo[dozalconserve, cs], {ii, 
            Abs[n]}]; \[IndentingNewLine]{Transpose[
              Take[Transpose[dozalconserve], 21]] // tf, 
          Transpose[Drop[Transpose[dozalconserve], 21]] // tf}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(dozaltest[
      A = {1. , 1. , 1. , 1, 2. ,  .1, 1/2. ,  .1, 1. ,  .11, 1. ,  .12}, 
      B = {2. , 1/2. , 1. ,  .2, 3. , 0.3, 1/3. , 0.1, 1. , 0.1, 1. , 0.1}, 
      9]\)], "Input",
  PageWidth->WindowWidth],

Cell["\<\
\tNote that C3KC2r & Q12C2c do not conserve any of these functions, whilst \
C3P4 & C3Qr only conserve 15 & 26, 16 & 27, which are not conserved by any \
other hoops.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(dozaltest[testA[\([7]\)], testA[\([17]\)], \(-4\)]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\(testA[\([11]\)]\)\( (*\ 
      gives\ l22a = \(l22b = l4s \[Equal] 0\)*) \)\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[{\(tst = "\<C3C4\>"; id[tst]; 
    dozalconserve = {Flatten[{tst, ds}]}; 
    colname = {};\), "\n", \(cs = {};\), "\[IndentingNewLine]", 
    RowBox[{"A", "=", 
      RowBox[{"Simplify", "[", 
        RowBox[{"toVector", "[", 
          RowBox[{"{", 
            RowBox[{
            "\[Alpha]", ",", "\[Beta]", ",", "\[Epsilon]", ",", "\[Sigma]", 
              ",", "\[Zeta]", 
              StyleBox[",",
                FontSize->9], "\[Tau]", ",", "\[Lambda]", ",", "\[Phi]", ",", 
              "\[Eta]", ",", "\[Chi]", ",", "\[Kappa]", ",", "\[Psi]"}], 
            "}"}], "]"}], "]"}]}], "\[IndentingNewLine]", \(FullSimplify[
      sh12[\([A]\)]]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(Chop[
      FullSimplify[
        sh12[toVector[{\[Alpha], \[Beta], \[Epsilon], \[Sigma], \[Zeta], \
\[Tau], \[Eta], \[Phi], \[Lambda], \[Phi], \[Kappa], \[Phi]}]] /. \@any_ \
\[Rule] any/2]]\)], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe following table shows (for the first 25 functions) those functions \
that are sizes (irreducible determinant factors) as \"i\", those that are \
conserved combinations of sizes by \"c\", those that are conserved on orbit \
multiplication by \"o\", and those that are only conserved when some \
\"radii\" are zero or negative by \"n\". (Negative radii can occur in ",
  StyleBox["Q12 & D3C2",
    FontSlant->"Italic"],
  " because they have sizes with 3 positive and 3 negative squared terms.)  \
The names indicate the type of function:- o",
  StyleBox["n",
    FontSlant->"Italic"],
  " are linear functions, offsets in orbits. p",
  StyleBox["ab",
    FontSlant->"Italic"],
  "-s",
  StyleBox["ab",
    FontSlant->"Italic"],
  " have ",
  StyleBox["b",
    FontSlant->"Italic"],
  " terms each of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ". l3 is the cubic A4 size. l4",
  StyleBox["p",
    FontSlant->"Italic"],
  "-l4",
  StyleBox["s",
    FontSlant->"Italic"],
  " are quartic sizes. The last column gives the polar form for toVec[{\
\[Alpha], \[Beta], \[Gamma], \[Delta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\
\[Lambda], \[Phi], \[Eta]\[Eta], \[Chi], \[Kappa]\[Kappa], \[Psi]}, \
\"C3C4\"], with \[Zeta] replacing ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  " (etc). Note that \[Gamma], \[Delta] are retained here, instead of \
\[CurlyEpsilon], \[Sigma]; a second term gives the corresponding form for \
C3K, where it differs from that for C3C4. Third and fourth terms are for Q12 \
& D3C2. Long terms are simplified by making all angles equal to \[Tau]. \
(Functions 26 onward are not categorised wrt. the four groups.)\nI am \
attempting to correlate these relationships with the properties of \
fundamental particles."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "No. Name C3C4 Q12 C3K D3C2 A4 C3C4,C4K,Q12,D3C2\n1   o1   i    i   i   i   \
 i  \[Alpha]\n2   o2   i    i   i   i       \[Beta]\n3   o3            i   i  \
     \[Gamma](Cos[\[Delta]]+Sin[\[Delta]]),\[Gamma],\n                        \
      \[Gamma](Cos[\[Delta]]+Sin[\[Delta]]),\[Gamma],\n4   o4            i   \
i       \[Gamma](Cos[\[Delta]]-Sin[\[Delta]]),\[Gamma],\n                     \
         \[Gamma](Cos[\[Delta]]-Sin[\[Delta]]),\[Delta],\n5   l22a i\n6   \
l22b i\n7   p22  o    o   o   o       (",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\^2\)]],
  ")/2\n8   q22  i    i   o   o       ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^2\)]],
  ",(",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\^2\)]],
  ")/2,",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^2\)]],
  ",(",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\^2\)]],
  ")/2\n9   r22  c    c   c   c       \[Alpha] \[Beta]\n10  s22           c   \
c    i  ",
  Cell[BoxData[
      \(\[Gamma]\^2\ Cos[2\ \[Delta]]\)]],
  ",\[Gamma] \[Delta],",
  Cell[BoxData[
      \(\[Gamma]\^2\ Cos[2\ \[Delta]]\)]],
  ",\[Gamma] \[Delta]\n11  p23  i    n   i   n       ",
  Cell[BoxData[
      \(\[Zeta]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Zeta]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Zeta]\^2 + \[Lambda]\^2 + 
        2\ \[Zeta]\ \[Lambda]\ Cos[\[Tau] - \[Phi]]\)]],
  ",\n                                    ",
  Cell[BoxData[
      \(\[Zeta]\^2 + \[Lambda]\^2 - 
        2\ \[Zeta]\ \[Lambda]\ Cos[\[Tau] - \[Phi]]\)]],
  " \n12  q23  i    n   i   n       ",
  Cell[BoxData[
      \(\[Lambda]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Lambda]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Zeta]\^2 + \[Lambda]\^2 + 
        2\ \[Zeta]\ \[Lambda]\ Cos[\[Tau] - \[Phi]]\)]],
  ",\n                                    ",
  Cell[BoxData[
      \(\[Zeta]\^2 + \[Lambda]\^2 - 
        2\ \[Zeta]\ \[Lambda]\ Cos[\[Tau] - \[Phi]]\)]],
  "\n13  r23  o    n   i   n       ",
  Cell[BoxData[
      \(\[Eta]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Eta]\^2\)]],
  ",",
  Cell[BoxData[
      \(\(\(\[Eta]\^2 + \[Kappa]\^2 + 
        2\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]]\)\(,\)\)\)]],
  "\n                                    ",
  Cell[BoxData[
      \(\[Eta]\^2 + \[Kappa]\^2 - 
        2\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]]\)]],
  "\n14  s23  o    n   i   n       ",
  Cell[BoxData[
      \(\[Kappa]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Kappa]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Eta]\^2 + \[Kappa]\^2 - 
        2\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]]\)]],
  ",\n                                    ",
  Cell[BoxData[
      \(\[Eta]\^2 + \[Kappa]\^2 + 
        2\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]]\)]],
  "\n15  q24  o    o   o   o      ",
  Cell[BoxData[
      \(\((\[Alpha]\^2 + \[Beta]\^2 + 2\ \[Gamma]\^2)\)/4\)]],
  ",",
  Cell[BoxData[
      \(\((\[Alpha]\^2 + \[Beta]\^2 + \[Gamma]\^2 + \[Delta]\^2)\)/4\)]],
  ",\n                             ",
  Cell[BoxData[
      \(\((\[Alpha]\^2 + \[Beta]\^2 + 2\ \[Gamma]\^2)\)/4\)]],
  ",",
  Cell[BoxData[
      \(\(\(\[Alpha]\^2 + \[Beta]\^2 + \[Gamma]\^2 + \[Delta]\^2\)\()\)\)/
        4\)]],
  "\n16  s24           o   o\n           ",
  Cell[BoxData[
      \(\((\(-\((\[Alpha] - \[Beta])\)\^2\) - 2\ \[Gamma]\^2 + 
          4\ \((\[Alpha] + \[Beta])\)\ \[Gamma]\ Cos[\[Delta]] + 
          2\ \[Gamma]\^2\ Cos[2\ \[Delta]])\)\)]],
  "/8,\n           ",
  Cell[BoxData[
      \(\((\(-\[Alpha]\^2\) - \[Beta]\^2 - \((\[Gamma] - \[Delta])\)\^2 + 
          2\ \[Beta]\ \((\[Gamma] + \[Delta])\) + 
          2\ \[Alpha]\ \((\[Beta] + \[Gamma] + \[Delta])\))\)\)]],
  "/8,\n           ",
  Cell[BoxData[
      \(\((\(-\((\[Alpha] - \[Beta])\)\^2\) - 2\ \[Gamma]\^2 + 
          4\ \((\[Alpha] + \[Beta])\)\ \[Gamma]\ Cos[\[Delta]] + 
          2\ \[Gamma]\^2\ Cos[2\ \[Delta]])\)\)]],
  "/8,                  \n           ",
  Cell[BoxData[
      \(\((\(-\[Alpha]\^2\) - \[Beta]\^2 - \((\[Gamma] - \[Delta])\)\^2 + 
          2\ \[Beta]\ \((\[Gamma] + \[Delta])\) + 
          2\ \[Alpha]\ \((\[Beta] + \[Gamma] + \[Delta])\))\)\)]],
  "/8\n17  p26       i       f   \[Zeta] \[Lambda] Cos[\[Tau]-\[Phi]],\[Zeta] \
\[Lambda] Cos[\[Tau]-\[Phi]],",
  Cell[BoxData[
      \(\(\(\[Zeta]\^2 - \[Lambda]\^2\)\(,\)\)\)]],
  Cell[BoxData[
      \(\[Zeta]\^2 - \[Lambda]\^2\)]],
  "\n18  q26  o    o   n   i   \[Eta] \[Kappa] Cos[\[Chi]-\[Psi]],\[Eta] \
\[Kappa] Cos[\[Chi]-\[Psi]],",
  Cell[BoxData[
      \(\(\(\[Eta]\^2 - \[Kappa]\^2\)\(,\)\)\)]],
  Cell[BoxData[
      \(\[Eta]\^2 - \[Kappa]\^2\)]],
  "\n19  r26  o    n   o   o   ",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Lambda]\^2)\)\)]],
  "/2,",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Lambda]\^2)\)\)]],
  "/2,",
  Cell[BoxData[
      \(\(\(\[Zeta]\^2 + \[Lambda]\^2\)\(,\)\)\)]],
  Cell[BoxData[
      \(\[Zeta]\^2 + \[Lambda]\^2\)]],
  "\n20  s26  o    i   o   o   ",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\)]],
  "/2,",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\)]],
  "/2,",
  Cell[BoxData[
      \(\[Eta]\^2 + \[Kappa]\^2\)]],
  ",",
  Cell[BoxData[
      \(\[Eta]\^2 + \[Kappa]\^2\)]],
  "\n21  l3(\[Delta]->0)               i ",
  Cell[BoxData[
      \(\((\[Beta]\ \[Eta]\ \[Kappa] + \ \[Lambda]\[Delta]\ \[Eta] + \
\[Lambda]\[Gamma]\ \[Kappa])\)/3\)]],
  ",,\n",
  Cell[BoxData[
      \(\((\[Beta]\ \((\[Eta]\^2 - \[Kappa]\^2)\) + 
          2\ \[Gamma]\ \[Eta]\ \((\[Zeta] - \[Lambda])\))\)\)]],
  ",(\[Gamma](\[Eta]+\[Kappa])(\[Zeta]+\[Lambda])+(\[Eta]-\[Kappa])(\[Beta](\
\[Eta]+\[Kappa])+\[Delta](\[Zeta]+\[Lambda])))\n22  l4p  c    n   c   n       \
",
  Cell[BoxData[
      \(\[Zeta]\^2\ \[Lambda]\^2\)]],
  ",,",
  Cell[BoxData[
      \(\[Zeta]\^4 + \[Lambda]\^4 - 
        2\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[2\ \((\[Tau] - \[Phi])\)]\)]],
  ",\n23  l4q  o    n   c   n       ",
  Cell[BoxData[
      \(\[Eta]\^2\ \[Kappa]\^2\)]],
  ",,",
  Cell[BoxData[
      \(\[Eta]\^4 + \[Kappa]\^4 - 
        2\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  ",\n24  l4r       n       n       ",
  Cell[BoxData[
      StyleBox[\(\((\[Zeta]\^4 - 4\ \[Zeta]\^2\ \[Lambda]\^2 + \[Lambda]\^4 + 
              6\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[2\ \((\[Tau] - \[Phi])\)])\)/
          4\),
        FontSize->9]]],
  "\n25  l4s  c    n   o   n ",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\((\[Eta]\^4 + \[Kappa]\^4 + 
          2\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)])\)\)\)]],
  "/4\n26  L4Q                 ",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Eta]\^2 + \[Kappa]\^2 + \[Lambda]\^2)\)\^2\)]],
  "/16,",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Eta]\^2 + \[Kappa]\^2 + \[Lambda]\^2)\)\^2\)]],
  "/16,\n                        ",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Eta]\^2 + \[Kappa]\^2 + \[Lambda]\^2)\)\^2\)]],
  "/4, (",
  Cell[BoxData[
      \(\(\(\[Zeta]\^2 + \[Eta]\^2 + \[Kappa]\^2 + \
\[Lambda]\^2\)\()\)\)\^2\)]],
  "/4\n27  L4\[Sigma]  ",
  Cell[BoxData[
      \(\((\[Zeta]\^2 + \[Eta]\^2 + \((\[Kappa] - \[Lambda])\)\^2 - 2\ \[Eta]\
\ \((\[Kappa] + \[Lambda])\) - 2\ \[Zeta]\ \((\[Eta] + \[Kappa] + \
\[Lambda])\))\)\^2\)]],
  "/64,,\n         ",
  Cell[BoxData[
      \(\((\(-2\)\ \[Zeta]\ \[Eta] + \[Kappa]\^2 + \[Lambda]\^2)\)\^2/4\)]],
  ",\n28  L4a3  ",
  Cell[BoxData[
      \(\[Zeta]\^2\ \((2\ \[Zeta]\^2 + \[Lambda]\^2 - \[Lambda]\^2\ Cos[
                2\ \((\[Tau] - \[Phi])\)])\)\)]],
  "/2,,\n          ",
  Cell[BoxData[
      \(\[Zeta]\^4 + 6\ \[Zeta]\^2\ \[Lambda]\^2 + \[Lambda]\^4 - 
        4\ \[Zeta]\ \[Lambda]\ \((\[Zeta]\^2 + \[Lambda]\^2)\)\ Cos[\[Tau] - \
\[Phi]]\)]],
  ",\n29  L4b3   ",
  Cell[BoxData[
      \(\[Lambda]\^2\ \((2\ \[Lambda]\^2 + \[Zeta]\^2 - \[Zeta]\^2\ Cos[
                2\ \((\[Tau] - \[Phi])\)])\)\)]],
  "/2,,\n           ",
  Cell[BoxData[
      \(\[Zeta]\^4 + 6\ \[Zeta]\^2\ \[Lambda]\^2 + \[Lambda]\^4 + 
        4\ \[Zeta]\ \[Lambda]\ \((\[Zeta]\^2 + \[Lambda]\^2)\)\ Cos[\[Tau] - \
\[Phi]]\)]],
  ",\n30  L4c3   ",
  Cell[BoxData[
      \(\[Eta]\^2\ \((2\ \[Eta]\^2 - \[Kappa]\^2 + \[Kappa]\^2\ Cos[
                2\ \((\[Chi] - \[Psi])\)])\)\)]],
  "/2,\n           ",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\ \((\[Eta]\^2 + \[Kappa]\^2 - 
              4\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]])\) + 
        4\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  ",\n           ",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\ \((\[Eta]\^2 + \[Kappa]\^2 + 
              4\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]])\) + 
        4\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  "\n31  L4d3   ",
  Cell[BoxData[
      \(\[Kappa]\^2\ \((2\ \[Kappa]\^2 - \[Eta]\^2 + \[Eta]\^2\ Cos[
                2\ \((\[Chi] - \[Psi])\)])\)\)]],
  "/2,\n           ",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\ \((\[Eta]\^2 + \[Kappa]\^2 - 
              4\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]])\) + 
        4\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  ",\n           ",
  Cell[BoxData[
      \(\((\[Eta]\^2 + \[Kappa]\^2)\)\ \((\[Eta]\^2 + \[Kappa]\^2 + 
              4\ \[Eta]\ \[Kappa]\ Cos[\[Chi] - \[Psi]])\) + 
        4\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  "\n32  L4a6   ",
  Cell[BoxData[
      \(\[Zeta]\^2\ \[Lambda]\^2\)]],
  ", ",
  Cell[BoxData[
      \(\[Zeta]\^2\ \[Lambda]\^2\)]],
  ", ",
  Cell[BoxData[
      \(\(\(\[Zeta]\^4 + \[Lambda]\^4 - 
        2\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[
            2\ \((\[Tau] - \[Phi])\)]\)\(,\)\)\)]],
  "\n33  L4b6   ",
  Cell[BoxData[
      \(\[Eta]\^2\ \[Kappa]\^2\)]],
  ", ",
  Cell[BoxData[
      \(\[Eta]\^2\ \[Kappa]\^2\)]],
  ", ",
  Cell[BoxData[
      \(\(\(\[Eta]\^4 + \[Kappa]\^4 - 
        2\ \[Eta]\^2\ \[Kappa]\^2\ Cos[
            2\ \((\[Chi] - \[Psi])\)]\)\(,\)\)\)]],
  "\n34  L4c6   ",
  Cell[BoxData[
      \(\(\(\[Eta]\^2\ \[Kappa]\^2\ Cos[
          2\ \((\[Chi] - \[Psi])\)]\)\(,\)\)\)]],
  ",",
  Cell[BoxData[
      \(\[Eta]\^4 - 4\ \[Eta]\^2\ \[Kappa]\^2 + \[Kappa]\^4 + 
        2\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)]\)]],
  ",\n35  L4d6  ",
  Cell[BoxData[
      \(\((\[Zeta]\^4 + \[Lambda]\^4 + 
            2\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[2\ \((\[Tau] - \[Phi])\)])\)/
        4\)]],
  ",\n           ",
  Cell[BoxData[
      \(\[Zeta]\^4 + \[Lambda]\^4 + 
        2\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[2\ \((\[Tau] - \[Phi])\)]\)]],
  ",  \n36  L49  ",
  Cell[BoxData[
      \(\((\[Eta]\^4 + 12\ \[Eta]\^2\ \[Kappa]\^2 + \[Kappa]\^4 + 
          10\ \[Eta]\^2\ \[Kappa]\^2\ Cos[2\ \((\[Chi] - \[Psi])\)])\)\)]],
  "/4,,\n         ",
  Cell[BoxData[
      \(6\ \[Eta]\^4 - 8\ \[Eta]\^2\ \[Kappa]\^2 + 6\ \[Kappa]\^4\)]],
  ",\n37  L49a ",
  Cell[BoxData[
      \(\((\[Zeta]\^4 + 12\ \[Zeta]\^2\ \[Lambda]\^2 + \[Lambda]\^4 + 
          10\ \[Zeta]\^2\ \[Lambda]\^2\ Cos[2\ \((\[Tau] - \[Phi])\)])\)\)]],
  "/4,,\n         ",
  Cell[BoxData[
      \(6\ \[Zeta]\^4 - 8\ \[Zeta]\^2\ \[Lambda]\^2 + 6\ \[Lambda]\^4\)]],
  ",\n38  L49b  long,,",
  Cell[BoxData[
      \(6\ \[Eta]\^4 - 8\ \[Eta]\^2\ \[Lambda]\^2 + 6\ \[Lambda]\^4\)]],
  ",\n39  L49c  long,,",
  Cell[BoxData[
      \(6\ \[Zeta]\^4 - 8\ \[Zeta]\^2\ \[Kappa]\^2 + 6\ \[Kappa]\^4\)]]
}], "Text",
  PageWidth->WindowWidth,
  FontFamily->"Courier New",
  FontSize->10]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{763, 590},
WindowMargins->{{69, Automatic}, {Automatic, 16}},
PrintingCopies->1,
PrintingPageRange->{1, 2},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "11/10/6"]], Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 171, "Title"],
Cell[1838, 56, 75, 1, 95, "Subtitle"],
Cell[1916, 59, 167, 6, 78, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2108, 69, 105, 2, 86, "Section"],
Cell[2216, 73, 1092, 22, 255, "Text"],
Cell[3311, 97, 76, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[3412, 103, 88, 1, 61, "Subsubsection"],
Cell[3503, 106, 207, 5, 73, "Text"],
Cell[3713, 113, 121, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[3859, 119, 605, 11, 302, "Input"],
Cell[4467, 132, 63, 1, 35, "Print"],
Cell[4533, 135, 74, 1, 41, "Output"]
}, Open  ]],
Cell[4622, 139, 208, 6, 73, "Text"],
Cell[4833, 147, 91, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[4949, 153, 371, 8, 172, "Input"],
Cell[5323, 163, 71, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5431, 169, 185, 4, 94, "Input"],
Cell[5619, 175, 70, 1, 35, "Print"],
Cell[5692, 178, 2936, 45, 633, "Output"]
}, Open  ]],
Cell[8643, 226, 117, 2, 47, "Text"],
Cell[8763, 230, 439, 14, 99, "Text"],

Cell[CellGroupData[{
Cell[9227, 248, 705, 14, 224, "Input"],
Cell[9935, 264, 449, 8, 60, "Print"],
Cell[10387, 274, 408, 8, 60, "Print"],
Cell[10798, 284, 57, 1, 41, "Output"],
Cell[10858, 287, 129, 2, 85, "Print"]
}, Open  ]],
Cell[11002, 292, 108, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[11135, 298, 455, 9, 224, "Input"],
Cell[11593, 309, 64, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11694, 315, 260, 5, 120, "Input"],
Cell[11957, 322, 1924, 33, 411, "Output"]
}, Open  ]],
Cell[13896, 358, 360, 10, 99, "Text"],

Cell[CellGroupData[{
Cell[14281, 372, 457, 9, 224, "Input"],
Cell[14741, 383, 90, 1, 41, "Output"],
Cell[14834, 386, 76, 1, 41, "Output"]
}, Open  ]],
Cell[14925, 390, 219, 6, 73, "Text"],
Cell[15147, 398, 122, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[15294, 404, 428, 8, 172, "Input"],
Cell[15725, 414, 64, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15826, 420, 128, 3, 68, "Input"],
Cell[15957, 425, 1164, 19, 214, "Output"]
}, Open  ]],
Cell[17136, 447, 96, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[17257, 453, 428, 8, 172, "Input"],
Cell[17688, 463, 64, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17801, 470, 83, 1, 61, "Subsubsection"],
Cell[17887, 473, 97, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[18009, 479, 571, 13, 224, "Input"],
Cell[18583, 494, 213, 4, 35, "Print"],
Cell[18799, 500, 73, 1, 35, "Print"],
Cell[18875, 503, 89, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19001, 509, 673, 13, 250, "Input"],
Cell[19677, 524, 58, 1, 41, "Output"],
Cell[19738, 527, 56, 1, 41, "Output"],
Cell[19797, 530, 88, 1, 60, "Print"]
}, Open  ]],
Cell[19900, 534, 92, 1, 47, "Text"],
Cell[19995, 537, 142, 4, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20174, 546, 145, 6, 62, "Subsubsection"],
Cell[20322, 554, 973, 20, 229, "Text"],
Cell[21298, 576, 97, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[21420, 582, 137, 3, 68, "Input"],
Cell[21560, 587, 140, 2, 60, "Print"],
Cell[21703, 591, 132, 2, 60, "Print"],
Cell[21838, 595, 131, 2, 60, "Print"],
Cell[21972, 599, 134, 2, 60, "Print"],
Cell[22109, 603, 117, 2, 60, "Print"],
Cell[22229, 607, 116, 2, 60, "Print"],
Cell[22348, 611, 106, 2, 60, "Print"],
Cell[22457, 615, 78, 1, 35, "Print"],
Cell[22538, 618, 76, 1, 35, "Print"],
Cell[22617, 621, 76, 1, 35, "Print"],
Cell[22696, 624, 124, 2, 60, "Print"],
Cell[22823, 628, 139, 2, 60, "Print"],
Cell[22965, 632, 115, 2, 60, "Print"],
Cell[23083, 636, 112, 2, 60, "Print"],
Cell[23198, 640, 132, 2, 60, "Print"],
Cell[23333, 644, 131, 2, 60, "Print"],
Cell[23467, 648, 76, 1, 35, "Print"],
Cell[23546, 651, 134, 2, 60, "Print"],
Cell[23683, 655, 116, 2, 60, "Print"],
Cell[23802, 659, 127, 2, 60, "Print"],
Cell[23932, 663, 91, 1, 35, "Print"],
Cell[24026, 666, 76, 1, 35, "Print"],
Cell[24105, 669, 75, 1, 35, "Print"],
Cell[24183, 672, 142, 2, 60, "Print"],
Cell[24328, 676, 124, 2, 60, "Print"],
Cell[24455, 680, 134, 2, 60, "Print"],
Cell[24592, 684, 117, 2, 60, "Print"],
Cell[24712, 688, 117, 2, 60, "Print"],
Cell[24832, 692, 117, 2, 60, "Print"],
Cell[24952, 696, 79, 1, 35, "Print"],
Cell[25034, 699, 76, 1, 35, "Print"],
Cell[25113, 702, 78, 1, 35, "Print"],
Cell[25194, 705, 77, 1, 35, "Print"],
Cell[25274, 708, 77, 1, 35, "Print"],
Cell[25354, 711, 77, 1, 35, "Print"],
Cell[25434, 714, 78, 1, 35, "Print"],
Cell[25515, 717, 75, 1, 35, "Print"],
Cell[25593, 720, 132, 2, 60, "Print"],
Cell[25728, 724, 117, 2, 60, "Print"],
Cell[25848, 728, 124, 2, 60, "Print"],
Cell[25975, 732, 112, 2, 60, "Print"],
Cell[26090, 736, 117, 2, 60, "Print"],
Cell[26210, 740, 118, 2, 60, "Print"],
Cell[26331, 744, 131, 2, 60, "Print"],
Cell[26465, 748, 76, 1, 35, "Print"],
Cell[26544, 751, 76, 1, 35, "Print"],
Cell[26623, 754, 134, 2, 60, "Print"],
Cell[26760, 758, 78, 1, 35, "Print"],
Cell[26841, 761, 106, 2, 60, "Print"],
Cell[26950, 765, 106, 2, 60, "Print"],
Cell[27059, 769, 103, 2, 60, "Print"],
Cell[27165, 773, 76, 1, 35, "Print"],
Cell[27244, 776, 79, 1, 35, "Print"],
Cell[27326, 779, 77, 1, 35, "Print"],
Cell[27406, 782, 78, 1, 35, "Print"],
Cell[27487, 785, 105, 2, 60, "Print"],
Cell[27595, 789, 105, 2, 60, "Print"],
Cell[27703, 793, 105, 2, 60, "Print"],
Cell[27811, 797, 117, 2, 60, "Print"],
Cell[27931, 801, 75, 1, 35, "Print"],
Cell[28009, 804, 78, 1, 35, "Print"],
Cell[28090, 807, 117, 2, 60, "Print"],
Cell[28210, 811, 132, 2, 60, "Print"],
Cell[28345, 815, 104, 2, 60, "Print"],
Cell[28452, 819, 105, 2, 60, "Print"],
Cell[28560, 823, 75, 1, 35, "Print"],
Cell[28638, 826, 77, 1, 35, "Print"],
Cell[28718, 829, 77, 1, 35, "Print"],
Cell[28798, 832, 77, 1, 35, "Print"],
Cell[28878, 835, 79, 1, 35, "Print"],
Cell[28960, 838, 79, 1, 35, "Print"],
Cell[29042, 841, 75, 1, 35, "Print"],
Cell[29120, 844, 76, 1, 35, "Print"],
Cell[29199, 847, 77, 1, 35, "Print"],
Cell[29279, 850, 77, 1, 35, "Print"],
Cell[29359, 853, 77, 1, 35, "Print"],
Cell[29439, 856, 115, 2, 60, "Print"],
Cell[29557, 860, 116, 2, 60, "Print"],
Cell[29676, 864, 77, 1, 35, "Print"],
Cell[29756, 867, 78, 1, 35, "Print"],
Cell[29837, 870, 76, 1, 35, "Print"],
Cell[29916, 873, 76, 1, 35, "Print"],
Cell[29995, 876, 77, 1, 35, "Print"],
Cell[30075, 879, 76, 1, 35, "Print"],
Cell[30154, 882, 77, 1, 35, "Print"],
Cell[30234, 885, 77, 1, 35, "Print"],
Cell[30314, 888, 77, 1, 35, "Print"],
Cell[30394, 891, 77, 1, 35, "Print"],
Cell[30474, 894, 77, 1, 35, "Print"],
Cell[30554, 897, 131, 2, 60, "Print"],
Cell[30688, 901, 79, 1, 35, "Print"],
Cell[30770, 904, 79, 1, 35, "Print"],
Cell[30852, 907, 78, 1, 35, "Print"],
Cell[30933, 910, 80, 1, 35, "Print"],
Cell[31016, 913, 62, 1, 35, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31127, 920, 71, 1, 61, "Subsubsection"],

Cell[CellGroupData[{
Cell[31223, 925, 521, 10, 224, "Input"],
Cell[31747, 937, 512, 8, 185, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32308, 951, 66, 1, 61, "Subsubsection"],
Cell[32377, 954, 527, 9, 177, "Text"],
Cell[32907, 965, 1233, 21, 562, "Input"],
Cell[34143, 988, 156, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[34324, 996, 344, 6, 120, "Input"],
Cell[34671, 1004, 888, 18, 118, "Print"],
Cell[35562, 1024, 844, 17, 140, "Print"],
Cell[36409, 1043, 546, 10, 110, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36992, 1058, 274, 5, 94, "Input"],
Cell[37269, 1065, 751, 17, 118, "Print"],
Cell[38023, 1084, 514, 14, 140, "Print"],
Cell[38540, 1100, 375, 7, 60, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38952, 1112, 270, 4, 94, "Input"],
Cell[39225, 1118, 923, 19, 118, "Print"],
Cell[40151, 1139, 553, 14, 140, "Print"],
Cell[40707, 1155, 186, 3, 60, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40954, 1165, 113, 2, 86, "Section"],
Cell[41070, 1169, 169, 5, 47, "Text"],

Cell[CellGroupData[{
Cell[41264, 1178, 93, 1, 61, "Subsubsection"],
Cell[41360, 1181, 383, 8, 99, "Text"],

Cell[CellGroupData[{
Cell[41768, 1193, 637, 14, 224, "Input"],
Cell[42408, 1209, 66, 2, 41, "Output"],
Cell[42477, 1213, 66, 2, 41, "Output"]
}, Open  ]],
Cell[42558, 1218, 604, 12, 255, "Text"],

Cell[CellGroupData[{
Cell[43187, 1234, 644, 13, 276, "Input"],
Cell[43834, 1249, 107, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43990, 1257, 87, 1, 61, "Subsubsection"],
Cell[44080, 1260, 222, 5, 99, "Text"],
Cell[44305, 1267, 2530, 43, 417, "Input"],
Cell[46838, 1312, 582, 10, 177, "Text"],

Cell[CellGroupData[{
Cell[47445, 1326, 772, 14, 354, "Input"],
Cell[48220, 1342, 11257, 179, 814, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59514, 1526, 771, 14, 354, "Input"],
Cell[60288, 1542, 11177, 178, 814, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71502, 1725, 771, 14, 354, "Input"],
Cell[72276, 1741, 11301, 175, 814, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83614, 1921, 755, 14, 354, "Input"],
Cell[84372, 1937, 11454, 190, 814, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95863, 2132, 858, 16, 406, "Input"],
Cell[96724, 2150, 11940, 174, 814, "Output"]
}, Open  ]],
Cell[108679, 2327, 573, 23, 99, "Text"],
Cell[109255, 2352, 1394, 27, 640, "Input"],
Cell[110652, 2381, 230, 5, 94, "Input"],
Cell[110885, 2388, 216, 5, 73, "Text"],
Cell[111104, 2395, 109, 2, 42, "Input"],
Cell[111216, 2399, 140, 3, 42, "Input"],
Cell[111359, 2404, 709, 15, 146, "Input"],
Cell[112071, 2421, 250, 6, 139, "Input"],
Cell[112324, 2429, 1823, 44, 359, "Text"],
Cell[114150, 2475, 11498, 325, 1470, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

