(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    362913,       8713]*)
(*NotebookOutlinePosition[    389630,       9658]*)
(*  CellTagsIndexPosition[    389586,       9654]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoops, Primal Maths, Compatible Coordinates, Glossary.", "Subtitle",
  PageWidth->PaperWidth],

Cell["\<\
R.H.Beresford. 11th. October 2006.
\"Make things as simple as possible, but no simpler.\" (Albert Einstein.)\
\>", "Subsubtitle",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["1. Introduction.", "Section",
  PageWidth->PaperWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "This is a glossary for the concepts developed in ",
  StyleBox["GroupLoopHoop'",
    FontSlant->"Italic"],
  ", and demonstrated in ",
  StyleBox["GroupLoopdemo, Hoopdemo, ",
    FontSlant->"Italic"],
  "(in ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  ".)",
  StyleBox[" ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["Hoops ",
    FontSlant->"Italic"],
  "(in ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/6198/"], None},
    ButtonStyle->"Hyperlink"],
  ")  i.e. \"Primal\" (non-negative) numbers, \"generalized signs\", \
\"conservative\" Moufang Loops, and \"Hoops\" - generalized \
\"partial-fraction division algebras\" with \"multiplicative remainders\" and \
conserved symmetries or \"sizes\". Some Hoops have \"orbit-generating\" polar \
forms leading to powers and roots. \"Orbits\" are multiphase sinusoids; their \
mathematics involves generalized signs. Noether's theorem suggests \
relationships between them and fundamental particles. Generalized signs lead \
to \"compatible coordinates\" (Section 3) which unify and simplify coordinate \
geometry. Section 4 is a conjecture about \"mixed metrics\" and Section 5 \
discusses Equation Synthesis, which is used to find non-linear differential \
equations with travelling pulse solutions.\nPlease send any comments to me at \
",
  StyleBox["rhberesford@btinternet.com",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Glossary. ", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["a,b,..or",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\_1, a\_2, \)]],
  " ",
  StyleBox["Elements representing Primal (non-negative) numbers, coefficients \
in a director.",
    FontWeight->"Plain"],
  StyleBox["\nA",
    FontSlant->"Italic"],
  "\t        ",
  StyleBox["A Director, an indexed set {",
    FontWeight->"Plain"],
  StyleBox["a,b",
    FontSlant->"Italic"],
  StyleBox["\[Ellipsis]} of ",
    FontWeight->"Plain"],
  StyleBox["m",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" primal elements; also written ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%m\), 
          StyleBox[\(\(a\_i\) d\_i\),
            FontWeight->"Bold"]}], TraditionalForm]], "Input",
    FontWeight->"Plain"],
  StyleBox[".\n",
    FontWeight->"Plain"],
  "A\t        ",
  StyleBox["A Vec, an indexed set {a,b\[Ellipsis]} of ",
    FontWeight->"Plain"],
  StyleBox["m/n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" signed elements; also written ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%\(m/n\)\(a\_i\) x\_i\)], "Input",
    FontWeight->"Plain"],
  StyleBox[". (Only takes\n\t             on the properties of a vector in \
some algebras).",
    FontWeight->"Plain"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[DoubleStruckCapitalA] = 
        0 \[Union] \(\[DoubleStruckCapitalR]\^+\)\)\)\)]],
  " ",
  StyleBox["The Primal (unsigned continuous, Absolute) numbers, the union of \
zero and the half line.",
    FontWeight->"Plain"],
  "\nAdditive elimination. ",
  StyleBox["The generalization of subtraction ",
    FontWeight->"Plain"],
  StyleBox["A",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["+(-",
    FontWeight->"Plain"],
  StyleBox["A",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")=0 to ",
    FontWeight->"Plain"],
  StyleBox["A",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["+",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)]],
  StyleBox["+",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`A\_j\)]],
  "+",
  StyleBox["...=0. ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)]],
  " ",
  StyleBox["etc are negations.",
    FontWeight->"Plain"],
  "\nAi= ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+j\((\[Sum]\+i\( \[Eta]\_i\) \[PartialD]\_\(a\
\_\(\(i\)\(\ \)\)\)f\_\(\(j\)\(\ \)\))\)\)]],
  " /",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\)]],
  ". ",
  StyleBox["The multiplicative inverse of A. Calculated by ",
    FontWeight->"Plain"],
  StyleBox["genInverse",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". Ai.A={1,0,..}\n",
    FontWeight->"Plain"],
  "Annihilator.",
  StyleBox["\tA non-trivial vector with all sizes zero. E.g.{1,1,1,1,-2,-2} \
in D3.\n",
    FontWeight->"Plain"],
  "arcTanh[a,o] ",
  StyleBox["A generalization of",
    FontWeight->"Plain"],
  " ",
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["'s ArcTanh[a/o] that gives a complex hyperangle depending\n\t     \
      on the a,o (adjacent,opposite) octant.\n",
    FontWeight->"Plain"],
  "binegation.  ",
  StyleBox["Ordinary (unary) negation -A, with -(-A)=A, resulting from \
negation by C2 equivalencing. \n\t         Often incorrectly conflated with \
subtraction, which is a binary operation B-A. (cf. ternegation)",
    FontWeight->"Plain"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`C\_3\)]],
  " etc.,  ",
  StyleBox["The cyclic groups (associative loops) of 2,3, etc. primal \
elements. Do not confuse with Rings ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalZ]\_2\)]],
  StyleBox["\n   ",
    FontWeight->"Plain"],
  "or C2, C3.",
  StyleBox["   etc, for which negation is defined. Negation is undefined for \
loops or groups. ",
    FontWeight->"Plain"],
  "\n",
  StyleBox["C3C2",
    FontSlant->"Italic"],
  " etc.    ",
  StyleBox["The direct composition of ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`C\_3\)],
    FontWeight->"Plain"],
  StyleBox[" with ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)],
    FontWeight->"Plain"],
  " ",
  StyleBox["etc. Indirect composition is shown as e.g. ",
    FontWeight->"Plain"],
  StyleBox["KiC4, C8pC2",
    FontSlant->"Italic"],
  StyleBox[".",
    FontWeight->"Plain"],
  "\nC3\t       ",
  StyleBox["\"Ternal\", \"Terplex\"; the algebra of three elements, \
equivalence relationships on ",
    FontWeight->"Plain"],
  StyleBox["C3C2",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Plain"],
  StyleBox["C3C4 ",
    FontSlant->"Italic"],
  StyleBox["etc.\n",
    FontWeight->"Plain"],
  "Cartesian-",
  StyleBox["  A director or vec as an indexed set of coefficients with \
related directions or dimensions.\n    ",
    FontWeight->"Plain"],
  "Form.   ",
  StyleBox["Many algebras have dual ",
    FontWeight->"Plain"],
  "Polar Forms ",
  StyleBox["(q.v.) with offsets, radii, and angles. See toPolar, toVector.\n",
    
    FontWeight->"Plain"],
  "Collapse.",
  StyleBox["  Used in earlier versions, now replaced by ",
    FontWeight->"Plain"],
  "Fold.",
  StyleBox["\n",
    FontWeight->"Plain"],
  "Compatible-",
  StyleBox["  The uniform nomenclature produced by putting A (\[Congruent]",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(a\_i\) d\_i\)],
    FontWeight->"Plain"],
  ") = ",
  StyleBox["f[",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)],
    FontWeight->"Plain"],
  StyleBox["] where ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)],
    FontWeight->"Plain"],
  StyleBox[" is an angle\n   ",
    FontWeight->"Plain"],
  "Coordinates",
  StyleBox[" measured ",
    FontWeight->"Plain"],
  "towards",
  StyleBox[" the direction ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)],
    FontWeight->"Plain"],
  StyleBox[", from the hyperplane ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)],
    FontWeight->"Plain"],
  StyleBox["=0. f[",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\[Phi]",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], "i"], TraditionalForm]]],
  StyleBox["] = Sin[",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Phi]\_i\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  StyleBox["] gives a \n    ",
    FontWeight->"Plain"],
  "Direction-  ",
  StyleBox[" generalised spherical \"direction Sines\" algebra with an \
euclidean metric; f[",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\[Phi]",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], "i"], TraditionalForm]]],
  StyleBox["] = ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"Sin", "[", 
            FormBox[
              StyleBox[\(\[Phi]\_i\),
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False}],
              "TraditionalForm"], "]"}], "2"], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[" gives\n    ",
    FontWeight->"Plain"],
  "Sines.",
  StyleBox["\ta city block metric. The i'th component vanishes when ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)],
    FontWeight->"Plain"],
  "=",
  StyleBox["0. (Direction Cosines lack this\n    \t\t automatic elimination.)\
\n",
    FontWeight->"Plain"],
  "Conservative",
  StyleBox[".The property (discovered by Frobenius for group inverse tables) \
of some multiplication tables\n\t         to conserve the determinant on \
multiplication. Possessed by \"Hoop Division algebras\" - many\n\t         \
signed tables, all groups, and some non-associative Moufang loops including \
Octonions. I found\n\t         (empirically) that direct table conjugate \
factors are conserved.\n",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "                ",
  StyleBox["A basis direction for a loop. ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)],
    FontWeight->"Plain"],
  StyleBox[" is a basis dimension, folded from 2 or more directions.\n\t      \
 Directions can only be associated with operators or primal coefficients.\n",
    FontWeight->"Plain"],
  "Director. ",
  StyleBox["  See ",
    FontWeight->"Plain"],
  StyleBox["A.",
    FontSlant->"Italic"],
  StyleBox[" Directors are the objects multiplied by loops. If",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["the loop has ",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["-fold symmetry, a director\n\t     may fold to give a vec with ",
    FontWeight->"Plain"],
  StyleBox["m",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["/",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" signed elements & dimensions, operated on by a hoop algebra.\n",
    FontWeight->"Plain"],
  "Dozal, Doz. ",
  StyleBox["The algebra of 12-element directors and vecs, and the unital \
algebra derived from it.\n",
    FontWeight->"Plain"],
  "Dual.\t        ",
  StyleBox["Polar description (if one exists) for a vec as a set of offsets, \
squared radii or ulnae, and angles.",
    FontWeight->"Plain"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`D\_4\)]],
  ", etc.  ",
  StyleBox["Dihedral groups, symmetries of the triangle, square, etc. Written \
D3, D4 when used as hoops.\n",
    FontWeight->"Plain"],
  "Element.",
  StyleBox["  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_1\),
          FontWeight->"Bold"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[\(d\_1\),
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox[",",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)],
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  StyleBox["c",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" etc. A constituent part of a director or vec, consisting of a \
coefficient (",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(a\_1\),
            FontWeight->"Bold"], ","}], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)],
    FontWeight->"Plain"],
  StyleBox[") and a\n\t     direction or dimension (",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  StyleBox[",",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)],
    FontWeight->"Plain"],
  StyleBox[") (often implied by the index or the position of the element in \
the set).",
    FontWeight->"Plain"],
  "\nEquation Synthesis. ",
  StyleBox["A method of finding non-linear differential equations with \
specific solutions by setting\n\t      up a conservative DE with free \
parameters, and an expression (typically for a compact travelling\n\t      \
wave) with undetermined coefficients. Substituting the expression & its \
derivatives into the\n\t      equation leads to constraints between the \
coefficients and parameters, thereby defining a specific\n\t      function \
that satisfies the specific equation. See Section 5. for examples.",
    FontWeight->"Plain"],
  "\nEquivalencing.  ",
  StyleBox["The creation of a signed hoop (or of a vector) by \"folding\", an \
equivalence relationship\n\t     between sets (pairs, triples, quads etc) of \
primal elements ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r\_i~\((a\_i - a\_\(i + m/r\))\) x\_i\)],
    FontWeight->"Plain"],
  StyleBox[". Impossible for\n  \t     some loops, such as ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`C\_3\)],
    FontWeight->"Plain"],
  " ",
  StyleBox["&",
    FontWeight->"Plain"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)],
    FontWeight->"Plain"],
  StyleBox[", which may, however, be folded after first composing with ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)],
    FontWeight->"Plain"],
  StyleBox[".\n\t     Complex hoops and vectors are folded from quads of \
primal elements, i.e. ",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["=4. Generalized or \n\t     extended signs are created by \
folding. (See ",
    FontWeight->"Plain"],
  "Fold",
  StyleBox[".)",
    FontWeight->"Plain"],
  "\nExtended Signs. ",
  StyleBox["Generalizations of +,-,+\[ImaginaryI],-\[ImaginaryI];",
    FontWeight->"Plain"],
  " ",
  StyleBox["E.g. ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^\[DoubleStruckR]\)],
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckD]\^12\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[DoubleStruckN]",
          FontWeight->"Plain"], "9"]],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckO]\^8\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckG]\^7\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckH]\^6\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckP]\^5\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[DoubleStruckCapitalI]",
          FontWeight->"Plain"], "4"]],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckCapitalY]\^3\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[DoubleStruckCapitalJ]",
          FontWeight->"Plain"], "3"]],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckK]\^2\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckL]\^2\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(\[DoubleStruckM]\^2\)],
    PageWidth->PaperWidth,
    CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
    InitializationCell->True,
    FontWeight->"Plain"],
  StyleBox["=+1",
    FontWeight->"Plain"],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\)]],
  "\t  ",
  StyleBox["The j'th distinct factor of the determinant of ",
    FontWeight->"Plain"],
  StyleBox["G",
    FontSlant->"Italic"],
  StyleBox[". It is conserved, if ",
    FontWeight->"Plain"],
  StyleBox["G",
    FontSlant->"Italic"],
  StyleBox[" is a hoop, on multiplication;\n\t      if it is linear (L1) it \
is also conserved on addition. Every factor is a \"size\" for the hoop \
algebra.\n",
    FontWeight->"Plain"],
  "Fold.  ",
  StyleBox["See Equivalencing, signed table. The conversion of a loop with ",
    FontWeight->"Plain"],
  StyleBox["m",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" unsigned elements to a hoop with\n\t    ",
    FontWeight->"Plain"],
  StyleBox["m/r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" signed elements, often generating a signed multiplication table. \
Groups can operate as algebras\n\t    over fields because any group X can be \
considered to be folded from XF, where F is a field\n\t    group such as C2 \
(real) or C4 (complex). Vecs (generalized vectors) are folded from unsigned \
sets. ",
    FontWeight->"Plain"],
  "\nFragment. ",
  StyleBox["A linear term in a compact size expression e.g. ",
    FontWeight->"Plain"],
  StyleBox["(a-b)",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" in (",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\((a - b)\)\^2\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{"+", 
          FormBox[\(\((b - c)\)\^2\),
            "TraditionalForm"]}], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox["+",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\((c - a)\)\^2\)],
    FontWeight->"Plain"],
  StyleBox[")/2; also the\n\t     quadratic terms in compact expressions for \
quartic sizes.\n",
    FontWeight->"Plain"],
  "Frobenius conservation. ",
  StyleBox["The propery that Det[A] Det[B]=\[PlusMinus]Det[AB] when vectors \
are multiplied using a\n\t   Cayley Table. Det is the conjugate of that of \
the Cayley table, mapped with the vector elements.\n\t   Frobenius proved \
that all associative tables (groups) are conservative. I found that Octonions \
and\n\t   some other non-associative Moufang loops are conservative, and the \
property survives on\n\t   folding to a signed table.\n",
    FontWeight->"Plain"],
  "Gaussian Pulse.  ",
  StyleBox["Exp[go + \[ImaginaryI] \[Omega] T+ ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontWeight->"Plain"],
  StyleBox["[\[ImaginaryI] kx X - jx\.b2(X+xi-vx T)\.b2]. See Section 5.",
    FontWeight->"Plain"],
  "\nG",
  Cell[BoxData[
      FormBox[
        RowBox[{":", 
          RowBox[{\(d\_i\[Times]d\_j\), "\[RightArrow]", " ", 
            SubscriptBox["d", 
              StyleBox["ij",
                FontWeight->"Plain",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  " ",
  StyleBox["A finite loop, group, hoop or groupoid giving the direction or \
basis dimension ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox["d", 
          StyleBox["ij",
            FontWeight->"Plain",
            FontSlant->"Italic"]], TraditionalForm]]],
  StyleBox[" resulting\n\t   from the multiplication of two directions ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_i, d\_j\)]],
  ".",
  StyleBox[" Det[G] is that of the symbolic Cayley Table.",
    FontWeight->"Plain"],
  "\nGeneralized Conjugate.",
  StyleBox[" An involute vec that gives the conserved determinant factors. \
Real vecs are their\n\town conjugate. The terplex conjugate of {a,b,c} is \
{a,c,b}. Th complex conjgate of {r,I} is {r,-i}.",
    FontWeight->"Plain"],
  "\nGeneralized Negation. ",
  StyleBox["Equivalence relations on sets of ",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" primal coefficients ",
    FontWeight->"Plain"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(e\_i\),
          FontWeight->"Plain"], 
        StyleBox["~",
          FontSlant->"Italic"], 
        RowBox[{
          StyleBox["{",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          
          StyleBox[\(a\_i, a\_\(i + m/r\),  ... , 
            a\_\(i + \((r - 1)\) m/r\)\),
            FontWeight->"Plain"], 
          StyleBox["}",
            FontWeight->"Plain"]}]}]], "Input"],
  StyleBox[".",
    FontWeight->"Plain"],
  "\nGeneralized Signs. ",
  StyleBox["Generalizations of +, -, +\[ImaginaryI], -\[ImaginaryI];",
    FontWeight->"Plain"],
  " ",
  StyleBox["with",
    FontWeight->"Plain"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckS]\^\[DoubleStruckR]\)],
    FontWeight->"Plain"],
  StyleBox["=+1. Extended Signs gives a proposed standard.\n",
    FontWeight->"Plain"],
  "hoopInverse[A,hoop] ",
  StyleBox["The hoop multiplicative inverse Ai, permitting division in the \
specified hoop",
    FontWeight->"Plain"],
  "; ",
  StyleBox["Ai\[CenterDot]AB=B.\n\t  Calculated as sums of derivatives of \
shapes wrt \"specific variables\" that are fixed by the location of\n\t  the \
1's in the index table. In signed tables, the terms have to be multiplied by \
the sign of each 1\n\t  The location and multiplier are supplied as ",
    FontWeight->"Plain"],
  StyleBox["gi",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" in the ",
    FontWeight->"Plain"],
  StyleBox["shape",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" of the hoop. This is a Cramer's rule\n\t  calculation, so the \
inverse has the determinant as a divisor. When this factorises, the inverse \
splits\n\t  into partial-fractions with each size becoming a denominator. \
Division is left multiplication by an\n\t  inverse. Multiplication and \
division both eliminate infinite partial-fractions (created by zero sizes)\n\t\
  by \"ejecting\" remainders, giving a renormalised result matching a \
pseudo-inverse. The result is\n\t  \"projected\" onto a constrained \
sub-algebra. \n",
    FontWeight->"Plain"],
  "hoopPower[A,power] ",
  StyleBox[" A procedure to convert a vec to a power or root. It raises \
offsets and radii to the\n\t   required power, and multiplies angles by the \
power. The target hoop polar form must be known.\n\t   If angles exceed \
2\[Pi] they \"wrap round\", and then ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(A\^p\),
              "TraditionalForm"], ")"}], \(1/p\)], TraditionalForm]]],
  StyleBox[" will be a rotated version of A.\n",
    FontWeight->"Plain"],
  "hoopTest[table]  ",
  StyleBox["A procedure that reports whether the table is conservative and \
has division, powers, etc. \n",
    FontWeight->"Plain"],
  "hoopTimes[A,B,hoop]   ",
  StyleBox["The hoop multiplication rule, multiplying vecs A & B according to \
the specified\n\t   hoop",
    FontWeight->"Plain"],
  ".",
  StyleBox[" If either multiplicand has sizes that become zeroe in the \
product, these are \"ejected\" into\n\t   \"remainders\" so that size \
conservation is maintained. The product is \"projected\" into a sub-algebra.",
    
    FontWeight->"Plain"],
  "\n",
  StyleBox["gi,gp     ",
    FontSlant->"Italic"],
  "  ",
  StyleBox["Lists created by ",
    FontWeight->"Plain"],
  StyleBox["sh",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[", used by ",
    FontWeight->"Plain"],
  StyleBox["genInverse & toPolar",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". \n",
    FontWeight->"Plain"],
  "g",
  StyleBox["mmnn   ",
    FontSlant->"Italic"],
  StyleBox["A mnemonic for groups given by GAP>SmallGroup(mm,nn), or loops in \
the extended GAP Atlas.\n",
    FontWeight->"Plain"],
  "Hoop Algebra",
  StyleBox[". Multiplication and Division of vecs using a hoop multiplication \
table, with addition and\n\t    generalized subtraction that may use \
generalized signs.\n",
    FontWeight->"Plain"],
  "Helix Identity.",
  StyleBox["  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%\(n = m\)\)],
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`Sin[t + 2  n\ \[Pi]/m]\^\(2  p\)\)],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["=m Binomial[2p,p]/",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`4\^p\)],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" (p<m/2 if m is even, else p<m)",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n\t   The generalisation of  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(Sin\^2\)[x] + \(Cos\^2\)[x] = 1. \)],
    FontWeight->"Plain"],
  " ",
  StyleBox["Derived by J.J.Thwaites (personal communication).\n",
    FontWeight->"Plain"],
  "Hexal, Hex. ",
  StyleBox["The algebra of 6-element directors and vecs, and the unitary \
algebra derived from it.",
    FontWeight->"Plain"],
  "\nHeyting Algebras ",
  StyleBox["use intuitionistic (not Boolean) logic. The middle is not \
excluded; \[Not]\[Not]A is the interior of A.",
    FontWeight->"Plain"],
  "\nHyperbolic,  ",
  StyleBox["The analog of \"polar\" where a size includes a difference of 2 \
squared fragments. The Klein\n    ",
    FontWeight->"Plain"],
  "Hypolar.    ",
  StyleBox[" group is",
    FontWeight->"Plain"],
  " ",
  StyleBox["the archetype, with squared ulnae (a\[PlusMinus]c)^2-(b\
\[PlusMinus]d)^2 and angles arcTanh[a\[PlusMinus]c,b\[PlusMinus]d].\n",
    FontWeight->"Plain"],
  "\[DoubleStruckH],\[DoubleStruckCapitalI],\[DoubleStruckCapitalJ],\
\[DoubleStruckK],\[DoubleStruckL] etc.",
  StyleBox["  Generalized signs, different roots of unity. Proposed usage in \
Extended Signs. 'h etc. in ASCII.",
    FontWeight->"Plain"],
  "\n\[ImaginaryI]\t        ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(+1\)\%4\)],
    FontWeight->"Plain"],
  StyleBox[", usually written ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\%2\)],
    FontWeight->"Plain"],
  StyleBox[", a complex unit element. Ambiguous in Dav & C4C4. etc.\n",
    FontWeight->"Plain"],
  "Incantation. ",
  StyleBox["My name for the expressions used to create a Cayley table using \
any of the procedures ",
    FontWeight->"Plain"],
  StyleBox["ca, cd,\n\t         cl, co, ge, ma, md, ms, pe,",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" or",
    FontWeight->"Plain"],
  StyleBox[" ts.",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["\n",
    FontWeight->"Plain"],
  "Isomorphs",
  StyleBox[", ",
    FontWeight->"Plain"],
  "Isotopes",
  StyleBox[" I define Isomorphs as loops with renamed elements whilst \
isotopes are loops\n\t    with some changed signs that conserve the \
structure, but not the details, of the shape.",
    FontWeight->"Plain"],
  "\nHoop.\t      ",
  StyleBox["An algebra (H,+,\[CenterDot],\\,/,1) with addition +, Moufang \
\[CenterDot], left \\ & right / division, 1,  generalized signs,\n\t       \
and the ",
    FontWeight->"Plain"],
  "Frobenius determinant conservation",
  StyleBox[" property. All groups, a few non-associative\n\t       Moufang \
Loops, and some signed tables folded from both, are Hoops. They are in the \
database\n\t       as \"Protoloop\" preferred Cayley table isomorphs. Loop \
names ending in ",
    FontWeight->"Plain"],
  StyleBox["n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" are not hoops.\n",
    FontWeight->"Plain"],
  "Involutions.",
  StyleBox[" See Plex-conjugates. Vecs with changed signs of some elements. \
[Lounesto p29]\n",
    FontWeight->"Plain"],
  "Indexed set",
  StyleBox[". A set in which an index identifies each element, so that \
permuted sets are set isomorphs.",
    FontWeight->"Plain"],
  "\nK\t       ",
  StyleBox["The Klein four-group, and the corresponding algebra, which has \
three square roots of +1, and\n\t         equivalences to a \"double \
algebra\" with two. See Hyperbolic, Study numbers.\n",
    FontWeight->"Plain"],
  "KdVB",
  StyleBox["\t     Korteweg-deVries broadened equation.",
    FontWeight->"Plain"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\([\ \(n(1 + n\ r)\) \(A\^\(1 + 2/n\)\) A\_x\)\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(+\((r - 1)\)\) A\_x\^2/A\),
          FontWeight->"Plain"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\(\ \)\(+A\_\(x\ x\)\)\(]\)\)\_x\),
          FontWeight->"Plain"], TraditionalForm]]],
  " +\n\t       ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          StyleBox[\(\([\(A\^\(1 + m\)\) \(\(n\^2\)(
                      r + m)\)]\)\_\(\(\ \)\(t\)\)\),
            FontWeight->"Plain"], " "}], TraditionalForm]]],
  StyleBox["=0",
    FontWeight->"Plain"],
  ".",
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["Some multi-dimensional cases have travelling pulse solutions. \
Section 5.2.\n",
    FontWeight->"Plain"],
  "Large number ",
  StyleBox[" The observation that several ratios in physics are \
(approximately) low powers of ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(10\^40\),
          FontWeight->"Plain"], TraditionalForm]]],
  ";",
  StyleBox[" ",
    FontWeight->"Plain"],
  "\n  hypothesis.      ",
  StyleBox["expressed",
    FontWeight->"Plain"],
  " ",
  StyleBox["by Dirac as",
    FontWeight->"Plain"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`e\^2\)],
    FontWeight->"Plain"],
  StyleBox["\[TildeEqual]",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`10\^40\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`G\_m\)],
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain"],
  "\nL1, L2, etc. ",
  StyleBox["Linear (L1), quadratic (L2) etc. sizes, conserved in an algebra, \
and given by ",
    FontWeight->"Plain"],
  StyleBox["shape",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[".  L26\[Zeta]\[Lambda]\[Phi] is\n\t       the quadratic (L2) size \
which splits into six squared fragments and contains \[Zeta], \[Lambda], & \
\[Phi] in its polar\n\t       form. L1 sizes are conserved on addition, all \
sizes are conserved on multiplication for hoops.\n\t       Originally \
misnamed \"lengths\"; the n'th root of Ln may be a length, and may provide a \
metric.\n",
    FontWeight->"Plain"],
  "Length.   ",
  StyleBox["  A constituent of a Polar, corresponding to either a scalar or, \
if the ",
    FontWeight->"Plain"],
  StyleBox["n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["'th root of Ln, to a radius or\n\t        ulna in polar or \
hypolar coordinates. (The other constituents are angles.)\n",
    FontWeight->"Plain"],
  "Limiting   ",
  StyleBox["The non-linear partial differential equation that has any \
fixed-shape fixed speed wave, travelling",
    FontWeight->"Plain"],
  "\n  Velocity    ",
  StyleBox["in any direction",
    FontWeight->"Plain"],
  " ",
  StyleBox["in d spatial and 1 time direction, as a solution. Massive and \
light-like particles arise",
    FontWeight->"Plain"],
  "\n  Equation.  ",
  StyleBox["if pairs or directions combine to give dimensions, or if some \
directions are \"rolled-up\" (Kaluza\n\t       -Klein). Gtt-\[Sum][Gxx]=0 \
(with Gxx=",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)],
    FontWeight->"Plain"],
  StyleBox["G/d",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`X\^2\)],
    FontWeight->"Plain"],
  StyleBox[" etc. and summation is over x1...xd). See Section 5.1\n",
    FontWeight->"Plain"],
  "Loop.\t   ",
  StyleBox["An ",
    FontWeight->"Plain"],
  StyleBox["m\[Times]m",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" quasigroup Cayley table with a 1, for a set with ",
    FontWeight->"Plain"],
  StyleBox["m ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["elements. See Moufang Loop.\n\t    Protoloops include signed \
tables as well as strict (unsigned) loops.",
    FontWeight->"Plain"],
  "\n",
  StyleBox["m",
    FontSlant->"Italic"],
  "\t   ",
  StyleBox["The number of primal elements in a loop, group or director. Hoops \
have ",
    FontWeight->"Plain"],
  StyleBox["m/r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" elements.\n",
    FontWeight->"Plain"],
  "Moufang Loop. ",
  StyleBox["An ",
    FontWeight->"Plain"],
  StyleBox["m\[Times]m ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["multiplication table for a set with ",
    FontWeight->"Plain"],
  StyleBox["m",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" elements with L & R inverses ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`L\_i\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`R\_i\)],
    FontWeight->"Plain"],
  StyleBox["=",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`R\_i\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`L\_i\)],
    FontWeight->"Plain"],
  StyleBox[" and\n\t      the Moufang properties, including ",
    FontWeight->"Plain"],
  StyleBox["zx.yz=(z.xy)z,",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" relaxed to \"up to a sign\" for signed tables. All\n\t      \
groups are Moufang Loops. A few non-associative Moufang Loops (e.g. \
octonions) are hoops. \n",
    FontWeight->"Plain"],
  "Multi-phase ",
  StyleBox["  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(n = 1\)\%m 
              c\ Cos[\[Omega]\[Tau] + 2  n\ k\ \[Pi]/m + \[Phi]] \[Zeta]\_n\),
           
          StyleBox["+",
            FontWeight->"Plain"], 
          StyleBox[\(f[t]\),
            FontWeight->"Plain"]}], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[", a solution to ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_n\)],
    FontWeight->"Plain"],
  StyleBox["\" = ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)],
    FontWeight->"Plain"],
  StyleBox["(",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n - 1\)\)],
    FontWeight->"Plain"],
  StyleBox["-2",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_n\)],
    FontWeight->"Plain"],
  StyleBox["+",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n + 1\)\)],
    FontWeight->"Plain"],
  StyleBox[")",
    FontWeight->"Plain"],
  "+",
  StyleBox["f\"[t]",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" or \n   ",
    FontWeight->"Plain"],
  "Sinusoid.",
  StyleBox["\t",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_n\)],
    FontWeight->"Plain"],
  StyleBox["'= ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`a\)],
    FontWeight->"Plain"],
  StyleBox["(",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n - 1\)\)],
    FontWeight->"Plain"],
  StyleBox["-",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n + 1\)\)],
    FontWeight->"Plain"],
  StyleBox[")",
    FontWeight->"Plain"],
  "+",
  StyleBox["f'[t]. ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`e\_r\^\(\[DoubleStruckS]\ x\)\)]],
  StyleBox["generalizes ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\[ImaginaryI]\ x\)\)]],
  StyleBox["to define them.\n",
    FontWeight->"Plain"],
  StyleBox["n",
    FontSlant->"Italic"],
  "-potent. ",
  StyleBox["A vec which is its own ",
    FontWeight->"Plain"],
  StyleBox["n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["'th power in a particular algebra, ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`A\^n\)],
    FontWeight->"Plain"],
  StyleBox["=",
    FontWeight->"Plain"],
  StyleBox["A",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". An Idempotent if ",
    FontWeight->"Plain"],
  StyleBox["n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["=2.",
    FontWeight->"Plain"],
  "\nOC311\t    ",
  StyleBox["A typical continuous orbit, being the C3 orbit with both sizes \
equal to 1.\n",
    FontWeight->"Plain"],
  "Offset.",
  StyleBox["     The L1 sizes after conversion to polar form. See Radius, \
Polar Form. Symbols \[Alpha], \[Beta], \[Gamma], \[Delta].",
    FontWeight->"Plain"],
  "\nOrbit.\t    ",
  StyleBox["A unital parametric representation of a director or vec, with \
multi-phase sinusoidal elements\n\t     depending on at least one free \
frequency parameter {\[Sigma],\[Tau]..}. Greek letters \[Alpha]\[Ellipsis]\
\[Kappa] are used as the\n\t     size parameters. An example is given under \
\"Size\". Putting \[Tau] = -(",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_p\ t\)\(-\)\)\)],
    FontWeight->"Plain"],
  StyleBox["P.x)/\[HBar]  gives the orbit the\n\t     properties of a \
multi-phase deBroglie wave. (Related to the \"discrete orbits\" in a group.)\n\
",
    FontWeight->"Plain"],
  "Pauli-\[Sigma] Algebra.",
  StyleBox["The algebra defined by the Pauli-\[Sigma] 2\[Times]2 matrix \
multiplication table, conserving ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(t\^2\),
          FontWeight->"Plain"], TraditionalForm]]],
  "-",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\^2\),
          FontWeight->"Plain"], TraditionalForm]]],
  "-",
  Cell[BoxData[
      FormBox[
        StyleBox[\(y\^2\),
          FontWeight->"Plain"], TraditionalForm]]],
  "-",
  Cell[BoxData[
      FormBox[
        StyleBox[\(z\^2\),
          FontWeight->"Plain"], TraditionalForm]]],
  StyleBox["\n",
    FontWeight->"Plain"],
  "Phase.",
  StyleBox["\t   One or more cyclically varying element in an orbit. Each \
phase has a phase angle and a radius or ulna.\n",
    FontWeight->"Plain"],
  "Plex-Conjugate. ",
  StyleBox["The generalization of complex-conjugate to some hoops, a vec with \
some elements negated or\n\t     (in ternary algebras) with \
\[DoubleStruckCapitalJ]\[LeftRightArrow]",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\[DoubleStruckCapitalJ]",
            FontWeight->"Plain"], "2"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["exchanges. Elements of the product of the vec and the conjugates \
\n\t     (which are involutions) are related to the sizes of the vec, often \
as signed sums of squared elements.\n\t    The hoop generalised \
complex-conjugate ",
    FontWeight->"Plain"],
  StyleBox["plex",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" is supplied (if known) in ",
    FontWeight->"Plain"],
  StyleBox["shape",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[".  \n",
    FontWeight->"Plain"],
  "Polar Form.  ",
  StyleBox["A Dual representation of a vec as scalars, radii and angles, \
generalising ordinary polar coordinates.\n",
    FontWeight->"Plain"],
  "Polar Angle.",
  StyleBox[" An angle parameter in a polar form or orbit. Symbols \[Sigma], \
\[Tau], \[Phi], \[CurlyPhi], \[Chi], \[Psi].\n",
    FontWeight->"Plain"],
  "Polymorphs. ",
  StyleBox["Quartic size with several fragmentations and plex (involution) \
formulations.\n",
    FontWeight->"Plain"],
  "PolyHelix Identity.",
  StyleBox["  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(i = 0\)\%\(i = m - 1\)\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\((Sin[t + 2  i\[Pi]/m])\)\^\(2  p\)\)],
    FontWeight->"Plain"],
  StyleBox["= ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`4\^\(-p\)\)],
    FontWeight->"Plain"],
  StyleBox["m ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(2  p\)},
              {"p"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[", {p<m if m is even, else p<2m}.(John Thwaites,\n               \
private comminication).\n",
    FontWeight->"Plain"],
  "PowerSinusoid.   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain"], 
            FormBox[
              StyleBox[\(Sin[\[Omega]t + \[Phi]]\^p\),
                FontWeight->"Plain"],
              "TraditionalForm"]}]}], TraditionalForm]]],
  StyleBox[", which is a solution to ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(v\&\[DoubleDot]\), " ", "+", 
            RowBox[{\((1/p - 1)\), 
              RowBox[{
                FormBox[
                  RowBox[{" ", 
                    SuperscriptBox[
                      RowBox[{
                        FormBox[\(v\& . \),
                          "TraditionalForm"], " "}], "2"]}],
                  "TraditionalForm"], "/", "v"}]}], "+", 
            RowBox[{"p", " ", 
              FormBox[\(\[Omega]\^2\),
                "TraditionalForm"], "v"}]}], "=", "0"}], TraditionalForm]], 
    "Input",
    Evaluatable->False,
    FontWeight->"Plain"],
  ". ",
  StyleBox["The travelling\n\t        wave V=(a Sin[",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontWeight->"Plain"],
  StyleBox["kx*(x+xi-jx*t)]",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`)\^p\)],
    FontWeight->"Plain"],
  StyleBox[" is a solution to Vtt+(1/p-1) ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`Vt\^2\)],
    FontWeight->"Plain"],
  StyleBox["/V-pV",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\((jx\ kx)\)\^2\)],
    FontWeight->"Plain"],
  ".",
  StyleBox["\n",
    FontWeight->"Plain"],
  "Primal,  \[DoubleStruckCapitalA].  ",
  StyleBox["Non-negative continuous. Real and Complex numbers are \
equivalence-relationships on pairs or\n\t       quads of primal numbers. \
Other equivalence relations on ",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" primals give Terplex (",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["=3) etc.\n",
    FontWeight->"Plain"],
  "Protoloop.  ",
  StyleBox["A prefered isomorph of a table, showing any structure; shapes are \
defined for the protoloop. The \n\t    ",
    FontWeight->"Plain"],
  StyleBox["makeProtoloop (mp)",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" procedure generates the Cayley table (with options to create \
some isomorphs).\n",
    FontWeight->"Plain"],
  "Pseudo-root.  ",
  StyleBox["  Non-abelian polar duals involve non-conserved size parameters \
and angle that do not add on\n\t   multiplication, but which have valid \
reversions to the cartesian form. When they are used to calculate\n\t   roots \
and powers, arbitrary angles and uncertainty are introduced, giving rotated \
\"pseudo-roots\".\n",
    FontWeight->"Plain"],
  "Radius.   ",
  StyleBox["The length associated with an angle in a polar representation. \
Symbols ",
    FontWeight->"Plain"],
  "\[Epsilon], \[Zeta], \[Eta], \[Kappa], \[Lambda]",
  StyleBox[". See Ulna.\n",
    FontWeight->"Plain"],
  "Rational Pulse.",
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["=",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\((a/\((1 + \[Sum]\_\(x, y,  .. \)\(jx(xi + x - kx\ \
t)\)^2)\))\)\^n\)],
    FontWeight->"Plain"],
  StyleBox[" See Section 5.\n",
    FontWeight->"Plain"],
  "\[DoubleStruckS] \t ",
  StyleBox["The generalised sign or ",
    FontWeight->"Plain"],
  StyleBox["r",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["'th root of unity, ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[DoubleStruckS]", 
          StyleBox["r",
            FontSlant->"Italic"]], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox["=1, often incorrectly treated as a point on the complex\n\t     \
unit circle, but best considered as a \"direction\". I write it as  's in \
printable ASCII.\n",
    FontWeight->"Plain"],
  "Remainder. ",
  StyleBox["Multiplication (or division) by vectors with zero-sizes create \
left and right \"remainders\" with the\n\t   sizes that are present in the \
multiplicands but lost from the product, ensuring that hoops are\n\t   \
conservative and \"division by zero\" is eliminated.",
    FontWeight->"Plain"],
  "\nSize.",
  StyleBox["\tThe value of a single conserved property of a director or \
orbit, for a given hoop algebra. Thus the orbit\n\t   ",
    FontWeight->"Plain"],
  StyleBox["OC3\[Alpha]\[Gamma]={\[Alpha]+2\[Gamma] Cos[\[Tau]],\[Alpha]+2\
\[Gamma] Cos[\[Tau]+2\[Pi]/3 ],\[Alpha]+2\[Gamma] Cos[\[Tau]+4 \[Pi]/3]}/3 \
has individual sizes L1\[Alpha]=\[Alpha], \n\t   L23\[Zeta]2=",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Zeta]\^2\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  ", ",
  StyleBox["and so has a shape {",
    FontWeight->"Plain"],
  StyleBox["\[Alpha],",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Zeta]\^2\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  StyleBox["}, in the algebra C3; (hyper)complex-conjugate \"Eigenvector\n\t  \
 pairs\" ",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox["are sizes factorized into complex pairs (etc) but are not \
conserved. Sizes are always\n\t   symmetrical ideals.",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox["Shape.",
    FontFamily->"Times New Roman"],
  StyleBox["   All the sizes ",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox["of a director or orbit, found by ",
    FontWeight->"Plain"],
  StyleBox["shape[vec,mnemonic]",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["; needed by ",
    FontWeight->"Plain"],
  StyleBox["genInverse, toPol",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" etc.",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  "sh[mnemonic]  ",
  StyleBox["The symbolic factors of the named loop, with ",
    FontWeight->"Plain"],
  StyleBox["gi",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" for use with ",
    FontWeight->"Plain"],
  StyleBox["genInverse",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontWeight->"Plain"],
  StyleBox["gp",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" for use with\n\t  ",
    FontWeight->"Plain"],
  StyleBox["toPolar, toVector",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". It also defines ",
    FontWeight->"Plain"],
  StyleBox["plex",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" for many small algebras.",
    FontWeight->"Plain"],
  "\nshape[{a_,b_...}]  ",
  StyleBox["Factor (size) data for the target hoop, supplying the shape of \
{a,b,..} as a list of individual\n\t   sizes {",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)],
    FontWeight->"Plain"],
  StyleBox[",\[Ellipsis]",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`f\_k\)],
    FontWeight->"Plain"],
  StyleBox["} & setting ",
    FontWeight->"Plain"],
  StyleBox["gi, gp",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" for ",
    FontWeight->"Plain"],
  StyleBox["genInverse, toPolar",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[". It also sets ",
    FontWeight->"Plain"],
  StyleBox["plex",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" for many small algebras.",
    FontWeight->"Plain"],
  "\nSigned Table. ",
  StyleBox["A multiplication table for a set which forms a group or loop on \
appending its signed elements.\n\tThe multiplication table is the upper left \
quarter (ninth, sixteenth, etc.) of the full Cayley table with\n\t (possibly \
signed) elements folded, by equivalence relationships, from the full table \
elements.\n",
    FontWeight->"Plain"],
  "Spin. \t",
  StyleBox["A property of an orbit, which is reversed by reversing the \
sequence of the phases. Clockwise spin \n\t   (Cos, -Sin, -Cos, Sin) is taken \
to be positive or Up.\n",
    FontWeight->"Plain"],
  "Splitting.  ",
  StyleBox["The primal vector equivalent of subtraction, Split[A,B]=C if \
B+C=A.\n",
    FontWeight->"Plain"],
  "Study Numbers. ",
  StyleBox[" a+\[DoubleStruckK] b, ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\[DoubleStruckK]",
            FontWeight->"Plain"], "2"], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox["=1,",
    FontWeight->"Plain"],
  " ",
  StyleBox["folded K, the C2 algebra of the hyperbolic plane. Louenesto 2001 \
p24.\n",
    FontWeight->"Plain"],
  "SymDiff.",
  StyleBox["  Unsigned difference between numbers s=a\[LeftRightArrow]b : \
s+Min[a,b]=Max[a,b]. Primal \"additive inverse\".\n",
    FontWeight->"Plain"],
  "toPolar[v,h].    ",
  StyleBox["The procedures to convert cartesian representations ",
    FontWeight->"Plain"],
  StyleBox["v",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" into polar forms using hoop ",
    FontWeight->"Plain"],
  StyleBox["h",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[".\n",
    FontWeight->"Plain"],
  "toVector[p,h].\t",
  StyleBox["The procedures to convert polar representations ",
    FontWeight->"Plain"],
  StyleBox["p",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" into cartesian forms using hoop ",
    FontWeight->"Plain"],
  StyleBox["h",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[".\n",
    FontWeight->"Plain"],
  "Ternegation.\t",
  StyleBox["-(-(-A))=A in systems with ternary symmetry, instead of -(-A)=A \
in simple (bi)negation.\n",
    FontWeight->"Plain"],
  "Terplex.  ",
  StyleBox["The algebra of the C3 table over the real or complex field.\n",
    FontWeight->"Plain"],
  "Tetral.    ",
  StyleBox["The algebra of the C4 and K tables over the real or complex \
field.\n",
    FontWeight->"Plain"],
  "Triality",
  StyleBox[".  \"sends a simple rotation to a positive isoclinic rotation and \
a positive isoclinic rotation to a negative\n             isoclinic \
rotation\". The Moufang identity results in a special case of Cartan's \
triality. Louenesto p309.\n             See \"Loops\" in the GAP package.     \
         \n",
    FontWeight->"Plain"],
  "Ulna.\t",
  StyleBox["The hyperbolic analogue of radius.",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`u\^2\)],
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["=",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)],
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["-",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)],
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ".\nUnity.  ",
  StyleBox["The object {1,0,\[Ellipsis],0}  in unitary algebras, which leaves \
any object unchanged after multiplication.\n\t Not to be confused with the \
identity matrix. The product of a vec and its inverse is unity.",
    FontWeight->"Plain"],
  "\nUnit.    ",
  StyleBox["An object (e.g. {2/3,-1/3,-1/3} in C3) having all sizes 0 or 1 in \
a particular algebra.\n",
    FontWeight->"Plain"],
  "Unital.\t",
  StyleBox["A vec with sizes that multiply to 1 in a specific algebra, \
ignoring zeroes, is unital. Orbits are unital.\n\t (Clashes with \"unital \
algebras\", which are monoids and include all hoops)\n",
    FontWeight->"Plain"],
  "Univector.",
  StyleBox[" My name for the generators of Cayley-Dickson & Clifford \
algebras. The unit is scalar, products\n\t   are bivectors, trivectors, etc. \
Commonly and confusingly called vectors or scalars.\n",
    FontWeight->"Plain"],
  "Vec.\t  ",
  StyleBox["An ordered list of m primal , m/2 real , m/3 ternary or m/4 \
complex elements, etc, a director or\n\t   ",
    FontWeight->"Plain"],
  "fold",
  StyleBox["ed director. Only a Vector in some algebras.\n",
    FontWeight->"Plain"],
  "\[Alpha],\[Beta],\[Ellipsis]\[Lambda]  ",
  StyleBox["Size parameters in an orbit, also the corresponding length \
parameters in a Polar Dual.\n",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  StyleBox["\t  The i'th basis dimension. Two or more directions may fold to \
a real dimension ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)],
    FontWeight->"Plain"],
  StyleBox["~{",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)],
    FontWeight->"Plain"],
  StyleBox[",",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`d\_\(i + m/2\)\)],
    FontWeight->"Plain"],
  StyleBox["}. \n",
    FontWeight->"Plain"],
  "\[Sigma],\[Tau],\[Ellipsis],\[Psi]",
  StyleBox["  A frequency parameter in an orbit. Additive in abelian \
multiplication.\n\t  Also an angle parameter in a Polar.",
    FontWeight->"Plain"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -107.938}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Compatible Coordinates.", "Section",
  PageWidth->WindowWidth],

Cell["\<\
\tComplex, Polar, Spherical, and Cylindrical coordinates are incompatible - \
they use different measures for different coordinates, and so are not \
naturally extensible to higher spaces. Also, they contain an implicit \
Euclidean Metric,  length=Sqrt[x^2+y^2+...]\
\>", "Text",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  "\tThe use of directors with non-negative co-ordinates \"",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "\" and orthonormal basis directors \"",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "\" provides a standard formalism for any type of co-ordinate system. In \
place of the unhelpful variety of",
  "\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              FrameBox[GridBox[{
                    {\(\(Real\)\(\ \)\), \(\(\ \)\(a\)\(\ \)\)}
                    }],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], 
              FrameBox[GridBox[{
                    {
                      "Complex", \(\(\ \)\(a\  + \ \(\(\[ImaginaryI]\)\(\ \
\)\(b\)\(\ \)\)\)\)}
                    }],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], 
              FrameBox[GridBox[{
                    {
                      "Polar", \(\({r\ Sin[Theta], \n\ \ r\ Cos[
                            Theta]}\)\(\ \)\)}
                    }],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}]},
            {
              FrameBox[GridBox[{
                    {
                      "Spherical", \(\({\ \ r\ Sin[Theta]\ Cos[
                            Phi], \ \ \[IndentingNewLine]r\ Sin[Theta]\ Sin[
                            Phi], \n\ \ \ \ \ r\ Cos[
                            Theta]}\)\(\ \ \ \ \ \)\)}
                    }],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], 
              FrameBox[GridBox[{
                    {
                      "Cylindrical", \(\({r\ Sin[Theta]\ Cos[
                            Phi], \n\ \ r\ Cos[Theta]\n\ \ \ h}\)\(\ \ \)\)}
                    }],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], " "}
            }], TraditionalForm]]],
  "\na director co-ordinate system is written (using the summation convention \
for repeated indices) in one of the one of the forms\n          ",
  Cell[BoxData[
      FormBox[
        FrameBox[
          RowBox[{
            RowBox[{
              RowBox[{"A", " ", "=", " ", 
                RowBox[{
                  SubscriptBox[
                    FormBox["d",
                      "TraditionalForm"], "i"], 
                  RowBox[{"f", "[", 
                    FormBox[\(a\_i\),
                      "TraditionalForm"], "]"}]}]}], ";"}], "   "}],
          BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], TraditionalForm]]],
  "      or       ",
  Cell[BoxData[
      FormBox[
        FrameBox[
          RowBox[{
            RowBox[{"A", " ", "=", " ", 
              RowBox[{
                FormBox[\(d\_i\),
                  "TraditionalForm"], 
                RowBox[{"f", "[", 
                  RowBox[{
                    FormBox[\(a\_i\),
                      "TraditionalForm"], "/", 
                    FormBox[\(A\_i\),
                      "TraditionalForm"]}], "]"}]}]}], ","}],
          BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], TraditionalForm]]],
  "\t ",
  Cell[BoxData[
      FormBox[
        FrameBox[\((i = \(1.  .. \) m)\),
          BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], TraditionalForm]]]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "where \"",
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)]],
  "\" is the maximum for an \"",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "\" with an upper bound. \"",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "\" have lower bounds of zero. Note that the subscript is modular ",
  StyleBox["m",
    FontSlant->"Italic"],
  "; subscript [",
  StyleBox["m+i",
    FontSlant->"Italic"],
  "] is identical to subscript [",
  StyleBox["i",
    FontSlant->"Italic"],
  "]. \n\tThe \"",
  StyleBox["a",
    FontSlant->"Italic"],
  "\"s are coefficients; they obey the rules of primal unsigned algebra, with \
addition, multiplication, and trichotomous order. Subtraction is \"zero \
lower-bounded\". They are measurements \"towards\" their direction, \
increasing as the point moves away from the hyperplane ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "=0, unlike the Cos terms in polar, spherical, and cylindrical coordinates \
- which decrease towards their direction and give rise to negative \
derivatives.\n\tThe ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "'s are \"directions\" or \"basis directors\"; they generalize such symbols \
as \"-\", \"\[ImaginaryI]\" and \"-\[ImaginaryI]\", and obey a hoop product \
rule ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(i\ j\)\)]],
  ". They are  implicitly present when numbers are written as indexed sets of \
coefficients. Thus {a1,a2} is another way of writing ",
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ". \"",
  StyleBox["A",
    FontSlant->"Italic"],
  "\" is a \"director\" and has \"sizes\" (related to factors of the hoop \
determinant) that are conserved on multiplication and (iff linear) on \
addition or subtraction. Division involves partial fractions with each size \
being a denominator. Multiplication or division by a director with a zero \
size makes that size zero in the result - it is projection onto the sub-space \
in which that size is constrained to be zero.\n\tThe ",
  StyleBox["f",
    FontSlant->"Italic"],
  "'s are functions that define the geometry The identity function give plane \
geometry, the Sin function gives spherical geometry, Fig 2:-"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06457 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.23268 0.675919 0.295714 0.675919 [
[.5 1.07707 -107 0 ]
[.5 1.07707 107 13.5 ]
[ 0 0 0 0 ]
[ 1 1.06457 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.07707 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 13.750 moveto
(.2) show
93.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
111.000 13.750 moveto
(D) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.750 moveto
(H) show
123.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hyper) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
153.000 13.750 moveto
(L) show
159.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Spherical) show
219.000 13.750 moveto
(Geometry) show
267.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
273.000 13.750 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.06457 L
0 1.06457 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
newpath
.23268 .29571 .67592 0 93.6 arc
s
newpath
matrix currentmatrix
0.675919 0.202776 scale
.34424 1.45831 1 -108 88.2 arc
setmatrix s
newpath
matrix currentmatrix
0.479902 0.135184 scale
.48485 5.73752 1 -113.4 95.4 arc
setmatrix s
newpath
matrix currentmatrix
0.479902 0.135184 scale
.48485 2.18747 1 -113.4 95.4 arc
setmatrix s
.19888 .29571 m
.94239 .29571 L
s
.23268 .29571 m
.43546 .17405 L
.43546 .65395 L
.23268 .29571 L
.23268 1.00543 L
s
.23268 .77562 m
.43546 .65395 L
.48277 .77562 L
.48277 .29571 L
.43546 .65395 L
s
.19888 .77562 m
.71258 .77562 L
s
.12453 .05914 m
.34083 .53229 L
s
.15833 .63367 m
.30703 .91756 L
s
.48277 .29571 m
.43546 .17405 L
.17185 .17405 L
.17185 .65395 L
.43546 .65395 L
s
gsave
.19212 .32951 -66 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4287 .68775 -66 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.17185 .81617 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Az) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.46925 .81617 -72 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ayz) show
81.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13129 .19433 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ax) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.53684 .32951 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ay) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.0975 .68775 -72 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Axz) show
81.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50305 .19433 -72 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Axy) show
81.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .29571 -66.1875 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\330) show
69.375 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11101 .02535 -66.7813 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\327) show
70.563 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.23268 1.03923 -65.7813 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\331) show
68.563 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32731 .56608 -69.7813 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\327) show
76.563 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{270.5, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006E0001[b000`400?l00000o`00003oo`3ooonF
0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF
0?ooo`00<03oool300070080oooo1@001`3o0?oooe`0oooo000a0?ooo`030007003oool0oooo0080
oooo0P001`3o0?oooeh0oooo000b0?ooo`8000L000<0oooo000700001`00o`3ooomO0?ooo`00=03o
ool200070?l0ooooH03oool003<0oooo00<000L00?ooo`001`00o`3ooomP0?ooo`00<P3oool01@00
1`00oooo0007003oool000L00?l0ooooG`3oool00340oooo00<000L00?ooo`001`000`3oool00`00
1`00oooo0?ooo`3o0?oooe`0oooo000`0?ooo`D000L000@0oooo000700001`0000L0o`3ooomM0?oo
o`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?oo
o`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00>`3oool00`001`00oooo0?ooo`3o
0?oooeP0oooo000k0?ooo`030007003oool0oooo0?l0ooooF03oool003`0oooo00<000L00?ooo`3o
ool0o`3ooomG0?ooo`00?03oool00`001`00oooo0?ooo`3o0?oooeL0oooo000m0?ooo`030007003o
ool0oooo0?l0ooooEP3oool003d0oooo00<000L00?ooo`3oool0o`3ooomF0?ooo`00?P3oool00`00
1`00oooo0?ooo`3o0?oooeD0oooo000n0?ooo`030007003oool0oooo0?l0ooooE@3oool003l0oooo
00<000L00?ooo`3oool0o`3ooomD0?ooo`00?`3oool00`001`00oooo0?ooo`3o0?oooe@0oooo0010
0?ooo`030007003oool0oooo0?l0ooooD`3oool00400oooo00<000L00?ooo`3oool0o`3ooomC0?oo
o`00@03oool00`001`00oooo0?ooo`3o0?oooe<0oooo00110?ooo`030007003oool0oooo00H0oooo
=0001`3o0?oooaP0oooo000c0?oooaL000L0=03ooolH00070?l0oooo000T0?ooo`l000L03`3oool0
0`001`00oooo0?ooo`1A0?ooo`l000L0l03oool001T0oooo2`001`0N0?ooo`030007003oool0oooo
0600oooo2`001`3U0?ooo`00503oool5000702X0oooo00<000L00?ooo`3oool0JP3oool:00070=/0
oooo00130?ooo`030007003oool0oooo07@0oooo2P001`3A0?ooo`00A03oool00`001`00oooo0?oo
o`1m0?ooo`P000L0b@3oool004@0oooo00<000L00?ooo`3oool0Q@3oool600070<<0oooo00150?oo
o`030007003oool0oooo08X0oooo20001`2k0?ooo`00A@3oool00`001`00oooo0?ooo`2B0?ooo`H0
00L0]@3oool004D0oooo00<000L00?ooo`3oool0V03oool500070;00oooo00160?ooo`030007003o
ool0oooo09`0oooo1P001`2Z0?ooo`00AP3oool00`001`00oooo0?ooo`2R0?ooo`H000L0Y03oool0
04L0oooo00<000L00?ooo`3oool0Y`3oool5000709l0oooo00170?ooo`030007003oool0oooo0:`0
oooo0`001`2L0?ooo`00B03oool00`001`00oooo0?ooo`2^0?ooo`H000L0UP3oool004P0oooo00<0
00L00?ooo`3oool0]03oool500070940oooo00190?ooo`030007003oool0oooo0;P0oooo0`001`2>
0?ooo`00B@3oool00`001`00oooo0?ooo`2k0?ooo`D000L0R@3oool004T0oooo00<000L00?ooo`3o
ool0`03oool3000708H0oooo001:0?ooo`030007003oool0oooo0<80oooo1@001`210?ooo`00BP3o
ool00`001`00oooo0?ooo`370?ooo`<000L0OP3oool004/0oooo00<000L00?ooo`3oool0b@3oool2
000707`0oooo001;0?ooo`030007003oool0oooo0</0oooo1@001`1g0?ooo`00C03oool00`001`00
oooo0?ooo`3?0?ooo`8000L0M@3oool004`0oooo00<000L00?ooo`3oool0d@3oool300070780oooo
00170?ooocX000L0XP3oool4000706h0oooo000h0?ooo`l000L01P3oool00`001`00oooo0?ooo`0a
0?oooa8000L0U03oool3000706/0oooo000[0?ooo`d000L05P3oool00`001`00oooo0?ooo`120?oo
o``000L0R`3oool2000706T0oooo000R0?ooo`T000L08`3oool00`001`00oooo0?ooo`1>0?ooo`X0
00L0P`3oool2000706L0oooo000K0?ooo`L000L0;03oool00`001`00oooo0?ooo`1H0?ooo`L000L0
OP3oool4000706<0oooo001=0?ooofX000L0N`3oool200070640oooo001=0?ooo`030007003oool0
00L005l0oooo0`001`050?ooo`L000L0503oool3000705l0oooo0`001`1N0?ooo`00C@3oool01000
1`00oooo0?ooo`001`1L0?ooo`8000L00P3oool2000700/0oooo1`001`0?0?ooo`030007003oool0
oooo0600oooo0P001`1L0?ooo`00C@3oool010001`00oooo0?ooo`001`1K0?ooo`030007003oool0
oooo0080oooo0P001`0B0?ooo`@000L02`3oool00`001`00oooo0?ooo`1R0?ooo`030007003oool0
oooo05T0oooo000d0?ooo`<000L00`3oool3000700040?ooo`001`0000L000070080oooo0`001`07
0?ooo`050007003oool0oooo0?ooo`001`00F03oool2000700D0oooo00<000L00?ooo`001`002P3o
ool3000700<0oooo0`001`000`3oool000L000070006000700@0oooo0P001`1T0?ooo`@000L0E`3o
ool003D0oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`020?ooo`040007003oool0
oooo000700T0oooo00D000L00?ooo`3oool0oooo0007001F0?ooo`8000L01`3oool00`001`00oooo
0007000;0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool00P3oool010001`00oooo
0?ooo`001`020?ooo`H000L0J03oool2000705D0oooo000f0?ooo`D000L01P3oool2000700X0oooo
00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`1B0?ooo`030007003oool0oooo00L0oooo
00<000L00?ooo`001`00303oool5000700H0oooo0P001`060?ooo`D000L0J03oool2000705<0oooo
000f0?ooo`050007003oool0oooo0?ooo`001`001P3oool2000700X0oooo00<000L00?ooo`3oool0
0P3oool00`001`00oooo0?ooo`1@0?ooo`8000L02P3oool010001`00oooo0?ooo`001`0;0?ooo`05
0007003oool0oooo0?ooo`001`001P3oool2000700H0oooo00D000L00?ooo`3oool000L00?ooo`04
000706H0oooo00<000L00?ooo`3oool0D03oool003L0oooo00<000L00?ooo`001`001P3oool01000
1`00oooo0?ooo`001`090?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0C@3oool2
000700`0oooo00@000L00?ooo`3oool000L0303oool00`001`00oooo000700060?ooo`040007003o
ool0oooo000700@0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`020?ooo`@000L0
H`3oool200070500oooo000g0?ooo`030007003oool000L000@0oooo0`001`020?ooo`<000L01`3o
ool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo04`0oooo00<000L00?ooo`3oool0303o
ool01@001`00oooo0?ooo`3oool000L000/0oooo00<000L00?ooo`001`00103oool300070080oooo
0`001`00103oool000L0000700001`020?ooo`<000L01`3oool400070640oooo0P001`1>0?ooo`00
>03oool00`001`00oooo0?ooo`0B0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0
BP3oool2000700l0oooo00D000L00?ooo`3oool0oooo0007000<0?ooo`030007003oool0oooo01l0
oooo0`001`1P0?ooo`030007003oool0oooo04/0oooo000g0?ooo`8000L0503oool00`001`00oooo
0?ooo`040?ooo`030007003oool0oooo04L0oooo0P001`0A0?ooo`050007003oool0oooo0?ooo`00
1`002`3oool2000702@0oooo10001`1M0?ooo`8000L0B`3oool004d0oooo00<000L00?ooo`3oool0
103oool00`001`00oooo0?ooo`160?ooo`030007003oool0oooo0140oooo00<000L00?ooo`3oool0
0P3oool00`001`00oooo0?ooo`0b0?ooo`<000L0G03oool2000704T0oooo001=0?ooo`030007003o
ool0oooo00D0oooo00<000L00?ooo`3oool0@`3oool2000701@0oooo00<000L00?ooo`3oool00P3o
ool00`001`00oooo0?ooo`0e0?ooo`@000L0FP3oool2000704L0oooo001=0?ooo`030007003oool0
oooo00D0oooo00<000L00?ooo`3oool0@@3oool2000701H0oooo00<000L00?ooo`3oool00P3oool0
0`001`00oooo0?ooo`0i0?ooo`<000L0F@3oool2000704D0oooo001=0?ooo`030007003oool0oooo
00H0oooo00<000L00?ooo`3oool0?`3oool00`001`00oooo0?ooo`0F0?ooo`030007003oool0oooo
00<0oooo00<000L00?ooo`3oool0>`3oool2000705T0oooo00<000L00?ooo`3oool0@P3oool004d0
oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`0m0?ooo`8000L06@3oool00`001`00
oooo0?ooo`030?ooo`030007003oool0oooo03d0oooo0`001`1G0?ooo`8000L0@P3oool004d0oooo
00<000L00?ooo`3oool01`3oool00`001`00oooo0?ooo`0j0?ooo`8000L06`3oool00`001`00oooo
0?ooo`040?ooo`030007003oool0oooo03l0oooo0P001`1G0?ooo`030007003oool0oooo03l0oooo
001=0?ooo`030007003oool0oooo00L0oooo00<000L00?ooo`3oool0>@3oool00`001`00oooo0?oo
o`0K0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0@@3oool3000705D0oooo00<0
00L00?ooo`3oool0?P3oool004d0oooo00<000L00?ooo`3oool0203oool00`001`00oooo0?ooo`0f
0?ooo`8000L07P3oool00`001`00oooo0?ooo`040?ooo`030007003oool0oooo04@0oooo0P001`1D
0?ooo`030007003oool0oooo03d0oooo001=0?ooo`030007003oool0oooo00P0oooo00<000L00?oo
o`3oool0=03oool200070200oooo00<000L00?ooo`3oool01@3oool00`001`00oooo0?ooo`150?oo
o`8000L0D`3oool00`001`00oooo0?ooo`0l0?ooo`00C@3oool00`001`00oooo0?ooo`080?ooo`03
0007003oool0oooo03<0oooo00<000L00?ooo`3oool0803oool00`001`00oooo0?ooo`050?ooo`03
0007003oool0oooo04L0oooo0P001`1B0?ooo`030007003oool0oooo03/0oooo001=0?ooo`030007
003oool0oooo00T0oooo00<000L00?ooo`3oool0<03oool2000702<0oooo00<000L00?ooo`3oool0
1P3oool00`001`00oooo0?ooo`180?ooo`8000L0D@3oool2000703/0oooo001=0?ooo`030007003o
ool0oooo00T0oooo00<000L00?ooo`3oool0;P3oool2000702D0oooo00<000L00?ooo`3oool01P3o
ool00`001`00oooo0?ooo`1:0?ooo`8000L0D@3oool00`001`00oooo0?ooo`0h0?ooo`00C@3oool0
0`001`00oooo0?ooo`0:0?ooo`030007003oool0oooo02/0oooo0P001`0W0?ooo`030007003oool0
oooo00H0oooo00<000L00?ooo`3oool0C03oool00`001`00oooo0?ooo`1?0?ooo`030007003oool0
oooo03L0oooo001=0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0:P3oool00`00
1`00oooo0?ooo`0W0?ooo`030007003oool0oooo00L0oooo00<000L00?ooo`3oool0C03oool20007
0500oooo00<000L00?ooo`3oool0=P3oool004d0oooo00<000L00?ooo`3oool02`3oool00`001`00
oooo0?ooo`0W0?ooo`8000L0:P3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo04h0
oooo0P001`1?0?ooo`030007003oool0oooo03D0oooo001=0?ooo`030007003oool0oooo00/0oooo
00<000L00?ooo`3oool09@3oool2000702`0oooo00<000L00?ooo`3oool0203oool00`001`00oooo
0?ooo`1?0?ooo`030007003oool0oooo04`0oooo00<000L00?ooo`3oool0=@3oool004d0oooo00<0
00L00?ooo`3oool0303oool00`001`00oooo0?ooo`0S0?ooo`030007003oool0oooo02`0oooo00<0
00L00?ooo`3oool0203oool00`001`00oooo0?ooo`1@0?ooo`030007003oool0oooo04`0oooo00<0
00L00?ooo`3oool0=03oool004d0oooo00<000L00?ooo`3oool0303oool00`001`00oooo0?ooo`0Q
0?ooo`8000L0;`3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo0540oooo00<000L0
0?ooo`3oool0C03oool00`001`00oooo0?ooo`0c0?ooo`00C@3oool00`001`00oooo0?ooo`0=0?oo
o`030007003oool0oooo01h0oooo0P001`0a0?ooo`030007003oool0oooo00T0oooo00<000L00?oo
o`3oool0D@3oool2000704d0oooo00<000L00?ooo`3oool0<P3oool004d0oooo00<000L00?ooo`3o
ool03@3oool00`001`00oooo0?ooo`0M0?ooo`030007003oool0oooo0340oooo00<000L00?ooo`3o
ool02@3oool00`001`00oooo0?ooo`1C0?ooo`030007003oool0oooo04/0oooo00<000L00?ooo`3o
ool0<@3oool004d0oooo00<000L00?ooo`3oool03@3oool00`001`00oooo0?ooo`0K0?ooo`8000L0
=03oool00`001`00oooo0?ooo`0:0?ooo`030007003oool0oooo05<0oooo00<000L00?ooo`3oool0
B`3oool00`001`00oooo0?ooo`0`0?ooo`00C@3oool00`001`00oooo0?ooo`0>0?ooo`030007003o
ool0oooo01P0oooo0P001`0f0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0D`3o
ool00`001`00oooo0?ooo`1;0?ooo`030007003oool0oooo0300oooo001=0?ooo`030007003oool0
oooo00h0oooo00<000L00?ooo`3oool05`3oool00`001`00oooo0?ooo`0f0?ooo`030007003oool0
oooo00X0oooo00<000L00?ooo`3oool0E03oool2000704`0oooo00<000L00?ooo`3oool0;`3oool0
04d0oooo00<000L00?ooo`3oool03`3oool00`001`00oooo0?ooo`0D0?ooo`8000L0>@3oool00`00
1`00oooo0?ooo`0;0?ooo`030007003oool0oooo05D0oooo00<000L00?ooo`3oool0B@3oool00`00
1`00oooo0?ooo`0_0?ooo`00C@3oool00`001`00oooo0?ooo`0?0?ooo`030007003oool0oooo0180
oooo0P001`0k0?ooo`030007003oool0oooo00/0oooo00<000L00?ooo`3oool0EP3oool00`001`00
oooo0?ooo`190?ooo`030007003oool0oooo02h0oooo001=0?ooo`030007003oool0oooo0100oooo
00<000L00?ooo`3oool0403oool00`001`00oooo0?ooo`0k0?ooo`030007003oool0oooo00/0oooo
00<000L00?ooo`3oool0EP3oool00`001`00oooo0?ooo`190?ooo`030007003oool0oooo02h0oooo
001=0?ooo`030007003oool0oooo0100oooo00<000L00?ooo`3oool03P3oool2000703h0oooo00<0
00L00?ooo`3oool0303oool00`001`00oooo0?ooo`1F0?ooo`030007003oool0oooo04T0oooo00<0
00L00?ooo`3oool0;@3oool004d0oooo00<000L00?ooo`3oool04@3oool00`001`00oooo0?ooo`0;
0?ooo`8000L0@03oool00`001`00oooo0?ooo`0<0?ooo`030007003oool0oooo05H0oooo00<000L0
0?ooo`3oool0B@3oool00`001`00oooo0?ooo`0]0?ooo`00C@3oool00`001`00oooo0?ooo`0A0?oo
o`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0@03oool00`001`00oooo0?ooo`0=0?oo
o`030007003oool0oooo05H0oooo00<000L00?ooo`3oool0B03oool00`001`00oooo0?ooo`0]0?oo
o`00C@3oool00`001`00oooo0?ooo`0B0?ooo`030007003oool0oooo00L0oooo0P001`130?ooo`03
0007003oool0oooo00d0oooo00<000L00?ooo`3oool0EP3oool00`001`00oooo0?ooo`180?ooo`03
0007003oool0oooo02d0oooo001=0?ooo`030007003oool0oooo0180oooo00<000L00?ooo`3oool0
1@3oool2000704D0oooo00<000L00?ooo`3oool03@3oool00`001`00oooo0?ooo`1F0?ooo`030007
003oool0oooo04P0oooo00<000L00?ooo`3oool0;@3oool004d0oooo00<000L00?ooo`3oool04P3o
ool00`001`00oooo0?ooo`040?ooo`030007003oool0oooo04D0oooo00<000L00?ooo`3oool03P3o
ool00`001`00oooo0?ooo`1F0?ooo`030007003oool0oooo04L0oooo00<000L00?ooo`3oool05P3o
ool4000701<0oooo001=0?ooo`030007003oool0oooo01<0oooo00@000L00?ooo`3oool0oooo0P00
1`180?ooo`030007003oool0oooo00h0oooo00<000L00?ooo`3oool0EP3oool00`001`00oooo0?oo
o`180?ooo`030007003oool0oooo01L0oooo00<000L00?ooo`3oool04P3oool004d0oooo00<000L0
0?ooo`3oool04`3oool010001`00oooo000700001`1:0?ooo`030007003oool0oooo00l0oooo00<0
00L00?ooo`3oool0E@3oool00`001`00oooo0?ooo`180?ooo`030007003oool0oooo01L0oooo00<0
00L00?ooo`3oool04P3oool004d0oooo00<000L00?ooo`3oool01`3ooooo000701h000L02`3oool2
000701@0oooo001=0?ooo`030007003oool0oooo01@0oooo0P001`1;0?ooo`030007003oool0oooo
00l0oooo00<000L00?ooo`3oool0E@3oool00`001`00oooo0?ooo`180?ooo`030007003oool0oooo
01D0oooo0P001`000`3oool000L00?ooo`0B0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`80
00L0B`3oool00`001`00oooo0?ooo`0?0?ooo`030007003oool0oooo05D0oooo00<000L00?ooo`3o
ool0B03oool00`001`00oooo0?ooo`0D0?ooo`8000L000<0oooo000700001`004`3oool004d0oooo
00<000L00?ooo`3oool0503oool3000704X0oooo00<000L00?ooo`3oool03`3oool00`001`00oooo
0?ooo`1D0?ooo`030007003oool0oooo04T0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
000700020?ooo`030007003oool0oooo0100oooo001=0?ooo`030007003oool0oooo01@0oooo00<0
00L00?ooo`001`00BP3oool00`001`00oooo0?ooo`0>0?ooo`8000L0EP3oool00`001`00oooo0?oo
o`180?ooo`8000L05@3oool900070100oooo001=0?ooo`030007003oool0oooo01@0oooo00@000L0
0?ooo`001`0000L0B@3oool00`001`00oooo0?ooo`0>0?ooo`8000L0EP3oool00`001`00oooo0?oo
o`180?ooo`8000L0;P3oool004d0oooo00<000L00?ooo`3oool0503oool010001`00oooo00070000
1`190?ooo`030007003oool0oooo00h0oooo0P001`1E0?ooo`030007003oool0oooo04T0oooo0P00
1`0^0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo008000L0B03oool0
0`001`00oooo0?ooo`0>0?ooo`8000L05P3oool3000703`0oooo00<000L00?ooo`3oool0B@3oool2
000702h0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool00P001`180?oo
o`030007003oool0oooo00h0oooo0P001`0H0?ooo`030007003oool0oooo03X0oooo00<000L00?oo
o`3oool0B03oool00`001`00oooo0007000^0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`04
0007003oool0oooo0?ooo`8000L0A`3oool00`001`00oooo0?ooo`0>0?ooo`8000L0603oool00`00
1`00oooo0?ooo`0i0?ooo`030007003oool0oooo04T0oooo0P001`0_0?ooo`00C@3oool00`001`00
oooo0?ooo`030?ooo`@000L03@3oool01`001`00oooo0?ooo`3oool000L00?ooo`001`00AP3oool0
0`001`00oooo0?ooo`0>0?ooo`8000L02`3oool3000700<0oooo0`001`040?ooo`8000L0>P3oool0
0`001`00oooo0?ooo`190?ooo`8000L0;`3oool004d0oooo00<000L00?ooo`3oool00P3oool00`00
1`00oooo0?ooo`020?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool00P3oool20007
04H0oooo00<000L00?ooo`3oool03P3oool2000700`0oooo00<000L00?ooo`3oool00`3oool00`00
1`00oooo0?ooo`030?ooo`8000L0>@3oool00`001`00oooo0?ooo`1:0?ooo`8000L0;`3oool004d0
oooo00D000L00?ooo`3oool0oooo000700060?ooo`030007003oool0oooo00T0oooo00<000L00?oo
o`3oool00P3oool00`001`00oooo000700150?ooo`030007003oool0oooo00d0oooo00<000L00?oo
o`001`003@3oool5000700D0oooo00@000L00?ooo`3oool000L0>03oool00`001`00oooo0?ooo`19
0?ooo`030007003oool000L002l0oooo001=0?ooo`050007003oool0oooo0?ooo`001`001P3oool0
0`001`00oooo0?ooo`090?ooo`030007003oool0oooo00<0oooo0P001`150?ooo`030007003oool0
oooo00d0oooo00<000L00?ooo`001`003@3oool01@001`00oooo0?ooo`3oool000L000D0oooo00@0
00L00?ooo`3oool000L0=`3oool00`001`00oooo0?ooo`1:0?ooo`030007003oool000L002l0oooo
001=0?ooo`050007003oool0oooo0?ooo`001`001P3oool00`001`00oooo0?ooo`090?ooo`030007
003oool0oooo00<0oooo00<000L00?ooo`001`00A03oool00`001`00oooo0?ooo`0=0?ooo`030007
003oool000L000h0oooo00<000L00?ooo`001`001@3oool00`001`00oooo0?ooo`020?ooo`030007
003oool0oooo03<0oooo00<000L00?ooo`3oool0BP3oool010001`00oooo0?ooo`001`0_0?ooo`00
C@3oool01@001`00oooo0?ooo`3oool000L000H0oooo00<000L00?ooo`3oool02@3oool00`001`00
oooo0?ooo`040?ooo`8000L0A03oool00`001`00oooo0?ooo`0=0?ooo`030007003oool000L000h0
oooo00<000L00?ooo`001`00103oool300070080oooo0`001`0c0?ooo`030007003oool0oooo04X0
oooo00D000L00?ooo`3oool0oooo0007000_0?ooo`00C@3oool00`001`00oooo0?ooo`020?ooo`03
0007003oool0oooo0080oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`040?ooo`03
0007003oool000L004<0oooo00<000L00?ooo`3oool03@3oool00`001`00oooo0007000?0?ooo`03
0007003oool0oooo03`0oooo0P001`1<0?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3o
ool0;@3oool004d0oooo00<000L00?ooo`3oool00`3oool4000700d0oooo00<000L00?ooo`3oool0
103oool010001`00oooo0?ooo`001`120?ooo`030007003oool0oooo00d0oooo00<000L00?ooo`00
1`003P3oool2000703`0oooo0P001`1>0?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3o
ool0;@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`050?ooo`030007
003oool000L00480oooo00<000L00?ooo`3oool03@3oool00`001`00oooo0007001;0?ooo`030007
003oool0oooo04d0oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`0]0?ooo`00C@3o
ool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo00D0oooo00@000L00?ooo`3oool000L0
@@3oool00`001`00oooo0?ooo`0=0?ooo`030007003oool000L004/0oooo00<000L00?ooo`3oool0
C03oool00`001`00oooo0?ooo`040?ooo`030007003oool0oooo02d0oooo001=0?ooo`030007003o
ool0oooo01@0oooo00<000L00?ooo`3oool01P3oool00`001`00oooo000700110?ooo`030007003o
ool0oooo00`0oooo00@000L00?ooo`3oool000L0B@3oool2000704h0oooo00<000L00?ooo`3oool0
1@3oool00`001`00oooo0?ooo`0]0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003o
ool0oooo00H0oooo00@000L00?ooo`3oool000L0@03oool00`001`00oooo0?ooo`0<0?ooo`040007
003oool0oooo000704L0oooo0P001`1?0?ooo`030007003oool0oooo00H0oooo00<000L00?ooo`3o
ool0;@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`070?ooo`030007
003oool000L00400oooo00<000L00?ooo`3oool0303oool010001`00oooo0?ooo`001`150?ooo`80
00L0D03oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo02d0oooo001=0?ooo`030007
003oool0oooo01@0oooo00<000L00?ooo`3oool01`3oool010001`00oooo0?ooo`001`0o0?ooo`03
0007003oool0oooo00`0oooo00@000L00?ooo`3oool000L0A03oool00`001`00oooo0?ooo`1?0?oo
o`030007003oool0oooo00P0oooo00<000L00?ooo`3oool0;@3oool004d0oooo00<000L00?ooo`3o
ool0503oool00`001`00oooo0?ooo`080?ooo`030007003oool000L003l0oooo00<000L00?ooo`3o
ool0303oool010001`00oooo0?ooo`001`120?ooo`8000L0D@3oool00`001`00oooo0?ooo`090?oo
o`030007003oool0oooo02d0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3o
ool0203oool010001`00oooo0?ooo`001`0n0?ooo`030007003oool0oooo00`0oooo00@000L00?oo
o`3oool000L0@03oool200070580oooo00<000L00?ooo`3oool02@3oool00`001`00oooo0?ooo`0^
0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo00T0oooo00@000L00?oo
o`3oool000L0?@3oool00`001`00oooo0?ooo`0<0?ooo`040007003oool0oooo000703h0oooo0P00
1`1C0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0;P3oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`090?ooo`040007003oool0oooo000703d0oooo00<0
00L00?ooo`3oool02`3oool01@001`00oooo0?ooo`3oool000L003`0oooo0P001`1D0?ooo`030007
003oool0oooo00/0oooo00<000L00?ooo`3oool0;P3oool004d0oooo00<000L00?ooo`3oool0503o
ool00`001`00oooo0?ooo`090?ooo`050007003oool0oooo0?ooo`001`00?03oool00`001`00oooo
0?ooo`0;0?ooo`050007003oool0oooo0?ooo`001`00>P3oool2000705D0oooo00<000L00?ooo`3o
ool0303oool00`001`00oooo0?ooo`0^0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007
003oool0oooo00X0oooo00@000L00?ooo`3oool000L0?03oool00`001`00oooo0?ooo`0;0?ooo`05
0007003oool0oooo0?ooo`001`00>03oool2000705D0oooo0P001`0?0?ooo`030007003oool0oooo
02h0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool02P3oool01@001`00
oooo0?ooo`3oool000L003/0oooo00<000L00?ooo`3oool02`3oool01@001`00oooo0?ooo`3oool0
00L003D0oooo0`001`1F0?ooo`030007003oool0oooo00l0oooo00<000L00?ooo`3oool0;P3oool0
04d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0;0?ooo`040007003oool0oooo
000703/0oooo00<000L00?ooo`3oool02`3oool01@001`00oooo0?ooo`3oool000L00380oooo0`00
1`1H0?ooo`030007003oool0oooo0100oooo00<000L00?ooo`3oool0;P3oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`0;0?ooo`050007003oool0oooo0?ooo`001`00>P3o
ool00`001`00oooo0?ooo`0;0?ooo`050007003oool0oooo0?ooo`001`00;`3oool3000705X0oooo
00<000L00?ooo`3oool04@3oool00`001`00oooo0?ooo`0^0?ooo`00C@3oool00`001`00oooo0?oo
o`0D0?ooo`030007003oool0oooo00`0oooo00D000L00?ooo`3oool0oooo0007000i0?ooo`030007
003oool0oooo00/0oooo00D000L00?ooo`3oool0oooo0007000/0?ooo`<000L0F`3oool2000701@0
oooo00<000L00?ooo`3oool0;P3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`0<0?ooo`050007003oool0oooo0?ooo`001`00>@3oool00`001`00oooo0?ooo`0;0?ooo`05
0007003oool0oooo0?ooo`001`00:P3oool2000705`0oooo0P001`0F0?ooo`030007003oool0oooo
02h0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool03@3oool01@001`00
oooo0?ooo`3oool000L003P0oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`020?oo
o`030007003oool0oooo02@0oooo10001`1K0?ooo`<000L05`3oool00`001`00oooo0?ooo`0_0?oo
o`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo00d0oooo00D000L00?ooo`3o
ool0oooo0007000h0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool00P3oool00`00
1`00oooo0?ooo`0Q0?ooo`<000L0GP3oool00`001`00oooo0?ooo`0H0?ooo`030007003oool0oooo
02l0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool03P3oool01@001`00
oooo0?ooo`3oool000L003L0oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`020?oo
o`030007003oool0oooo01d0oooo10001`1O0?ooo`8000L06`3oool00`001`00oooo0?ooo`0_0?oo
o`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo00h0oooo00D000L00?ooo`3o
ool0oooo0007000g0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool00P3oool00`00
1`00oooo0?ooo`0I0?ooo`@000L0H@3oool2000701d0oooo00<000L00?ooo`3oool0;`3oool004d0
oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0>0?ooo`030007003oool0oooo0080
oooo00<000L00?ooo`3oool0=03oool00`001`00oooo0?ooo`0:0?ooo`030007003oool0oooo0080
oooo00<000L00?ooo`3oool05@3oool4000706<0oooo0P001`0O0?ooo`030007003oool0oooo02l0
oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool03`3oool01@001`00oooo
0?ooo`3oool000L003H0oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`020?ooo`03
0007003oool0oooo0140oooo10001`1V0?ooo`030007003oool0oooo01l0oooo00<000L00?ooo`3o
ool0;`3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0?0?ooo`030007
003oool0oooo0080oooo00<000L00?ooo`3oool0<`3oool00`001`00oooo0?ooo`0:0?ooo`030007
003oool0oooo0080oooo00<000L00?ooo`3oool03@3oool4000706P0oooo0P001`0Q0?ooo`030007
003oool0oooo0300oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0403o
ool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo0380oooo00<000L00?ooo`3oool02@3o
ool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo00L0oooo1P001`1Z0?ooo`8000L08`3o
ool00`001`00oooo0?ooo`0`0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0
oooo0100oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`0b0?ooo`030007003oool0
oooo00T0oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`030?ooo`@000L0K03oool4
000702D0oooo00<000L00?ooo`3oool0<03oool004d0oooo00<000L00?ooo`3oool0503oool00`00
1`00oooo0?ooo`0A0?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3oool0<@3oool00`00
1`00oooo0?ooo`090?ooo`030007003oool0oooo0080oooo1`001`1^0?ooo`8000L0:@3oool00`00
1`00oooo0?ooo`0`0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0140
oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`0a0?ooo`030007003oool0oooo00T0
oooo1@001`000`3oool000L00?ooo`1`0?ooo`8000L0:`3oool00`001`00oooo0?ooo`0`0?ooo`00
C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0180oooo00<000L00?ooo`3oool0
0P3oool00`001`00oooo0?ooo`0`0?ooo`030007003oool0oooo00<0oooo1`001`050?ooo`030007
003oool0oooo06d0oooo0P001`0]0?ooo`030007003oool0oooo0300oooo001=0?ooo`030007003o
ool0oooo01@0oooo00<000L00?ooo`3oool04P3oool00`001`00oooo0?ooo`020?ooo`030007003o
ool0oooo02`0oooo2P001`060?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0J`3o
ool2000702l0oooo00<000L00?ooo`3oool0<03oool004d0oooo00<000L00?ooo`3oool0503oool0
0`001`00oooo0?ooo`0C0?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3oool0903oool7
000700@0oooo00<000L00?ooo`3oool02@3oool00`001`00oooo0?ooo`030?ooo`030007003oool0
oooo06L0oooo10001`0`0?ooo`030007003oool0oooo0340oooo001=0?ooo`030007003oool0oooo
01@0oooo00<000L00?ooo`3oool04`3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo
01T0oooo2P001`0;0?ooo`030007003oool0oooo00T0oooo00<000L00?ooo`3oool00`3oool00`00
1`00oooo0?ooo`1U0?ooo`8000L0=03oool00`001`00oooo0?ooo`0a0?ooo`00C@3oool00`001`00
oooo0?ooo`0D0?ooo`030007003oool0oooo01<0oooo00<000L00?ooo`3oool00`3oool00`001`00
oooo0?ooo`0=0?ooo``000L05@3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0
oooo00<000L00?ooo`3oool0H`3oool2000703H0oooo00<000L00?ooo`3oool0<@3oool004d0oooo
00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0D0?oooaD000L08@3oool00`001`00oooo
0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0H03oool3000703P0oooo
00<000L00?ooo`3oool0<@3oool004d0oooo00<000L00?ooo`3oool00`3ooolY000700D0oooo00<0
00L00?ooo`3oool0;@3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<0
00L00?ooo`3oool0G03oool4000703/0oooo00<000L00?ooo`3oool0<@3oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`0E0?ooo`030007003oool0oooo00<0oooo00<000L0
0?ooo`3oool0;03oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L0
0?ooo`3oool0F@3oool3000703h0oooo00<000L00?ooo`3oool0<P3oool004d0oooo00<000L00?oo
o`3oool0503oool00`001`00oooo0?ooo`0E0?ooo`030007003oool0oooo00<0oooo00<000L00?oo
o`3oool0;03oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L00?oo
o`3oool0E`3oool200070440oooo00<000L00?ooo`3oool0<P3oool004d0oooo00<000L00?ooo`3o
ool0503oool00`001`00oooo0?ooo`0F0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3o
ool0:`3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3o
ool0DP3oool5000704<0oooo00<000L00?ooo`3oool0<P3oool004d0oooo00<000L00?ooo`3oool0
503oool00`001`00oooo0?ooo`0F0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0
:`3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0
D03oool2000704P0oooo00<000L00?ooo`3oool0<P3oool004d0oooo00<000L00?ooo`3oool0503o
ool00`001`00oooo0?ooo`0G0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0:P3o
ool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0B`3o
ool5000704T0oooo00<000L00?ooo`3oool0<`3oool004d0oooo00<000L00?ooo`3oool0503oool0
0`001`00oooo0?ooo`0G0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0:@3oool0
0`001`00oooo0?ooo`070?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0B03oool3
000704h0oooo00<000L00?ooo`3oool0<`3oool004d0oooo00<000L00?ooo`3oool0503oool00`00
1`00oooo0?ooo`0H0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0:@3oool00`00
1`00oooo0?ooo`070?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0AP3oool20007
0540oooo00<000L00?ooo`3oool0<`3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00
oooo0?ooo`0H0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0:03oool00`001`00
oooo0?ooo`070?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0@03oool6000705<0
oooo00<000L00?ooo`3oool0<`3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`0H0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0:03oool00`001`00oooo
0?ooo`070?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0>`3oool5000705P0oooo
00<000L00?ooo`3oool0=03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?oo
o`0I0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool09`3oool00`001`00oooo0?oo
o`070?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0>03oool3000705d0oooo00<0
00L00?ooo`3oool0=03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0I
0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool09`3oool00`001`00oooo0?ooo`07
0?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0<`3oool500070600oooo00<000L0
0?ooo`3oool0=03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0J0?oo
o`030007003oool0oooo00@0oooo00<000L00?ooo`3oool09P3oool00`001`00oooo0?ooo`070?oo
o`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0;@3oool6000706D0oooo00<000L00?oo
o`3oool0=03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0J0?ooo`03
0007003oool0oooo00D0oooo00<000L00?ooo`3oool09@3oool00`001`00oooo0?ooo`060?ooo`03
0007003oool0oooo00H0oooo00<000L00?ooo`3oool0:P3oool3000706X0oooo00<000L00?ooo`3o
ool0=@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0K0?ooo`030007
003oool0oooo00@0oooo00<000L00?ooo`3oool09@3oool00`001`00oooo0?ooo`060?ooo`030007
003oool0oooo00H0oooo00<000L00?ooo`3oool0903oool6000706d0oooo00<000L00?ooo`3oool0
=@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0K0?ooo`030007003o
ool0oooo00D0oooo00<000L00?ooo`3oool0903oool00`001`00oooo0?ooo`060?ooo`030007003o
ool0oooo00H0oooo00<000L00?ooo`3oool07P3oool6000707<0oooo00<000L00?ooo`3oool0=@3o
ool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0L0?ooo`030007003oool0
oooo00@0oooo00<000L00?ooo`3oool0903oool00`001`00oooo0?ooo`060?ooo`030007003oool0
oooo00H0oooo00<000L00?ooo`3oool06@3oool5000707T0oooo00<000L00?ooo`3oool0=@3oool0
04d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0L0?ooo`030007003oool0oooo
00D0oooo00<000L00?ooo`3oool08`3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo
00H0oooo00<000L00?ooo`3oool04@3oool8000707d0oooo00<000L00?ooo`3oool0=P3oool004d0
oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0L0?ooo`030007003oool0oooo00D0
oooo00<000L00?ooo`3oool08`3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo00H0
oooo00<000L00?ooo`3oool02`3oool6000708D0oooo00<000L00?ooo`3oool0=P3oool004d0oooo
00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0M0?ooo`030007003oool0oooo00D0oooo
00<000L00?ooo`3oool08P3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo00H0oooo
00<000L00?ooo`3oool00`3oool8000708/0oooo00<000L00?ooo`3oool0=P3oool004d0oooo00<0
00L00?ooo`3oool0503oool00`001`00oooo0?ooo`0M0?ooo`030007003oool0oooo00D0oooo00<0
00L00?ooo`3oool08P3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo00@0oooo2000
1`2C0?ooo`030007003oool0oooo03H0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L0
0?ooo`3oool07P3oool00`001`00oooo0?ooo`050?ooo`030007003oool0oooo0240oooo00<000L0
0?ooo`3oool00`3oool:00070080oooo00<000L00?ooo`3oool0U@3oool00`001`00oooo0?ooo`0g
0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo01h0oooo00<000L00?oo
o`3oool01P3oool00`001`00oooo0?ooo`0M0?ooo`T000L00P3oool00`001`00oooo0?ooo`070?oo
o`030007003oool0oooo09D0oooo00<000L00?ooo`3oool0=`3oool004d0oooo00<000L00?ooo`3o
ool0503oool00`001`00oooo0?ooo`0O0?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3o
ool04@3oool<000700<0oooo00<000L00?ooo`3oool01@3oool00`001`00oooo0?ooo`070?ooo`03
0007003oool0oooo09D0oooo00<000L00?ooo`3oool0=`3oool004d0oooo00<000L00?ooo`3oool0
503oool00`001`00oooo0?ooo`0O0?ooo`030007003oool0oooo00H0oooo00<000L00?ooo`001`00
40001`0?0?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool01`3oool00`001`00oooo
0?ooo`2E0?ooo`030007003oool0oooo03L0oooo001=0?ooo`030007003oool0oooo01@0oooo00<0
00L00?ooo`3oool0403ooolJ00070200oooo00<000L00?ooo`3oool01@3oool00`001`00oooo0?oo
o`070?ooo`030007003oool0oooo09@0oooo00<000L00?ooo`3oool0>03oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`050?ooo`/000L0403oool00`001`00oooo0?ooo`06
0?ooo`030007003oool0oooo01h0oooo00<000L00?ooo`3oool01@3oool00`001`00oooo0?ooo`07
0?ooo`030007003oool0oooo09@0oooo00<000L00?ooo`3oool0>03oool004d0oooo00<000L00?oo
o`3oool0503oool00`001`00oooo0?ooo`0Q0?ooo`030007003oool0oooo00D0oooo00<000L00?oo
o`3oool07P3oool00`001`00oooo0?ooo`050?ooo`030007003oool0oooo00L0oooo00<000L00?oo
o`3oool0U03oool00`001`00oooo0?ooo`0h0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`03
0007003oool0oooo0240oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`0M0?ooo`03
0007003oool0oooo00@0oooo00<000L00?ooo`3oool0203oool00`001`00oooo0?ooo`2C0?ooo`03
0007003oool0oooo03T0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0
8@3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo01`0oooo00<000L00?ooo`3oool0
103oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo09<0oooo00<000L00?ooo`3oool0
>@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0R0?ooo`030007003o
ool0oooo00H0oooo00<000L00?ooo`3oool0703oool00`001`00oooo0?ooo`040?ooo`030007003o
ool0oooo00P0oooo00<000L00?ooo`3oool0T`3oool00`001`00oooo0?ooo`0i0?ooo`00C@3oool0
0`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0280oooo00<000L00?ooo`3oool01`3oool0
0`001`00oooo0?ooo`0K0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0203oool0
0`001`00oooo0?ooo`2B0?ooo`030007003oool0oooo03X0oooo001=0?ooo`030007003oool0oooo
01@0oooo00<000L00?ooo`3oool08`3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo
01/0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo
0980oooo00<000L00?ooo`3oool0>P3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00
oooo0?ooo`0S0?ooo`030007003oool0oooo00L0oooo00<000L00?ooo`3oool06P3oool00`001`00
oooo0?ooo`040?ooo`030007003oool0oooo00P0oooo00<000L00?ooo`3oool0TP3oool00`001`00
oooo0?ooo`0j0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo02@0oooo
00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`0J0?ooo`030007003oool0oooo00@0oooo
00<000L00?ooo`3oool0203oool00`001`00oooo0?ooo`2A0?ooo`030007003oool0oooo03/0oooo
001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0903oool00`001`00oooo0?oo
o`070?ooo`030007003oool0oooo01T0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?oo
o`080?ooo`030007003oool0oooo0900oooo00<000L00?ooo`3oool0?03oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`0U0?ooo`030007003oool0oooo00H0oooo00<000L0
0?ooo`3oool06@3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo00T0oooo00<000L0
0?ooo`3oool0T03oool00`001`00oooo0?ooo`0l0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?oo
o`030007003oool0oooo02D0oooo00<000L00?ooo`3oool01`3oool00`001`00oooo0?ooo`0H0?oo
o`030007003oool0oooo00<0oooo00<000L00?ooo`3oool02@3oool00`001`00oooo0?ooo`2@0?oo
o`030007003oool0oooo03`0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3o
ool09P3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo01L0oooo00<000L00?ooo`3o
ool00`3oool00`001`00oooo0?ooo`090?ooo`030007003oool0oooo0900oooo00<000L00?ooo`3o
ool0?03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0V0?ooo`030007
003oool0oooo00L0oooo00<000L00?ooo`3oool05`3oool00`001`00oooo0?ooo`030?ooo`030007
003oool0oooo00T0oooo00<000L00?ooo`3oool0S`3oool00`001`00oooo0?ooo`0m0?ooo`00C@3o
ool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0340oooo00<000L00?ooo`3oool05P3o
ool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo00T0oooo00<000L00?ooo`3oool0S`3o
ool00`001`00oooo0?ooo`0m0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0
oooo0340oooo00<000L00?ooo`3oool05P3oool00`001`00oooo0?ooo`030?ooo`030007003oool0
oooo00T0oooo00<000L00?ooo`3oool0S`3oool00`001`00oooo0?ooo`0m0?ooo`00C@3oool00`00
1`00oooo0?ooo`0D0?ooo`030007003oool0oooo0380oooo00<000L00?ooo`3oool05@3oool00`00
1`00oooo0?ooo`030?ooo`030007003oool0oooo00T0oooo00<000L00?ooo`3oool0SP3oool00`00
1`00oooo0?ooo`0n0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0380
oooo00<000L00?ooo`3oool05@3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo00T0
oooo00<000L00?ooo`3oool0SP3oool00`001`00oooo0?ooo`0n0?ooo`00C@3oool00`001`00oooo
0?ooo`0D0?ooo`030007003oool0oooo03<0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`020?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0SP3oool00`001`00oooo
0?ooo`0n0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo03@0oooo00<0
00L00?ooo`3oool04`3oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00X0oooo00<0
00L00?ooo`3oool0S@3oool00`001`00oooo0?ooo`0o0?ooo`00C@3oool00`001`00oooo0?ooo`0D
0?ooo`030007003oool0oooo03@0oooo00<000L00?ooo`3oool04`3oool00`001`00oooo0?ooo`02
0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0S@3oool00`001`00oooo0?ooo`0o
0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo03D0oooo00<000L00?oo
o`3oool04P3oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00X0oooo00<000L00?oo
o`3oool0S03oool00`001`00oooo0?ooo`100?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`03
0007003oool0oooo0200oooo0`001`020?ooo`D000L02`3oool00`001`00oooo0?ooo`0B0?ooo`03
0007003oool0oooo0080oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`2<0?ooo`03
0007003oool0oooo0400oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0
8@3oool00`001`00oooo0?ooo`020?ooo`8000L03P3oool00`001`00oooo0?ooo`0A0?ooo`030007
003oool0oooo0080oooo00<000L00?ooo`3oool02P3oool00`001`00oooo0?ooo`2;0?ooo`030007
003oool0oooo0440oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool08P3o
ool2000700030?ooo`001`0000L000l0oooo00<000L00?ooo`3oool04@3oool00`001`00oooo0?oo
o`020?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0R`3oool00`001`00oooo0?oo
o`110?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo01T0oooo1P001`05
0?ooo`8000L04@3oool00`001`00oooo0?ooo`0@0?ooo`050007003oool0oooo0?ooo`001`003@3o
ool00`001`00oooo0?ooo`2:0?ooo`030007003oool0oooo0480oooo001=0?ooo`030007003oool0
oooo01@0oooo00<000L00?ooo`3oool08`3oool00`001`00oooo0007000A0?ooo`030007003oool0
oooo0100oooo00D000L00?ooo`3oool0oooo0007000=0?ooo`030007003oool0oooo08X0oooo00<0
00L00?ooo`3oool0@P3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0R
0?ooo`050007003oool000L00?ooo`001`004@3oool00`001`00oooo0?ooo`0?0?ooo`050007003o
ool0oooo0?ooo`001`003@3oool00`001`00oooo0?ooo`290?ooo`030007003oool0oooo04<0oooo
001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool08@3oool00`001`00oooo0007
00030?ooo`030007003oool0oooo00l0oooo00<000L00?ooo`3oool03P3oool01@001`00oooo0?oo
o`3oool000L000d0oooo00<000L00?ooo`3oool0R@3oool00`001`00oooo0?ooo`130?ooo`00C@3o
ool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0200oooo1@001`00103oool000L00007
00001`0@0?ooo`030007003oool0oooo00h0oooo00D000L00?ooo`3oool0oooo0007000=0?ooo`03
0007003oool0oooo08T0oooo00<000L00?ooo`3oool0@`3oool004d0oooo00<000L00?ooo`3oool0
503oool00`001`00oooo0?ooo`0j0?ooo`030007003oool0oooo00d0oooo00D000L00?ooo`3oool0
oooo0007000=0?ooo`030007003oool0oooo08P0oooo00<000L00?ooo`3oool0A03oool004d0oooo
00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0j0?ooo`030007003oool0oooo00d0oooo
00D000L00?ooo`3oool0oooo0007000=0?ooo`030007003oool0oooo08P0oooo00<000L00?ooo`3o
ool0A03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0k0?ooo`030007
003oool0oooo00`0oooo00D000L00?ooo`3oool0oooo0007000=0?ooo`030007003oool0oooo08L0
oooo00<000L00?ooo`3oool0A@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`0k0?ooo`030007003oool0oooo00`0oooo00@000L00?ooo`3oool000L03P3oool00`001`00
oooo0?ooo`270?ooo`030007003oool0oooo04D0oooo001=0?ooo`030007003oool0oooo01@0oooo
00<000L00?ooo`3oool0?03oool00`001`00oooo0?ooo`0;0?ooo`040007003oool0oooo000700h0
oooo00<000L00?ooo`3oool0QP3oool00`001`00oooo0?ooo`160?ooo`00C@3oool00`001`00oooo
0?ooo`0D0?ooo`030007003oool0oooo03d0oooo00<000L00?ooo`3oool02P3oool010001`00oooo
0?ooo`001`0>0?ooo`030007003oool0oooo08H0oooo00<000L00?ooo`3oool0AP3oool004d0oooo
00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`0m0?ooo`030007003oool0oooo00X0oooo
00@000L00?ooo`3oool000L03P3oool00`001`00oooo0?ooo`250?ooo`030007003oool0oooo04L0
oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0?P3oool00`001`00oooo
0?ooo`090?ooo`040007003oool0oooo000700h0oooo00<000L00?ooo`3oool0Q@3oool00`001`00
oooo0?ooo`170?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo03h0oooo
00<000L00?ooo`3oool02@3oool010001`00oooo0?ooo`001`0>0?ooo`030007003oool0oooo08@0
oooo00<000L00?ooo`3oool0B03oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`0o0?ooo`030007003oool0oooo00P0oooo00@000L00?ooo`3oool000L03P3oool00`001`00
oooo0?ooo`240?ooo`030007003oool0oooo04P0oooo001=0?ooo`030007003oool0oooo01@0oooo
00<000L00?ooo`3oool0?`3oool00`001`00oooo0?ooo`080?ooo`030007003oool000L000l0oooo
00<000L00?ooo`3oool0P`3oool00`001`00oooo0?ooo`190?ooo`00C@3oool00`001`00oooo0?oo
o`0D0?ooo`030007003oool0oooo0400oooo00<000L00?ooo`3oool01`3oool00`001`00oooo0007
000?0?ooo`030007003oool0oooo08<0oooo00<000L00?ooo`3oool0B@3oool004d0oooo00<000L0
0?ooo`3oool0503oool00`001`00oooo0?ooo`100?ooo`030007003oool0oooo00L0oooo00<000L0
0?ooo`001`003`3oool00`001`00oooo0?ooo`220?ooo`030007003oool0oooo04X0oooo001=0?oo
o`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0@@3oool00`001`00oooo0?ooo`060?oo
o`030007003oool000L000l0oooo00<000L00?ooo`3oool0PP3oool00`001`00oooo0?ooo`1:0?oo
o`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0oooo0480oooo00<000L00?ooo`3o
ool01@3oool00`001`00oooo0007000?0?ooo`030007003oool0oooo0840oooo00<000L00?ooo`3o
ool0B`3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo0?ooo`120?ooo`030007
003oool0oooo00D0oooo00<000L00?ooo`001`003`3oool00`001`00oooo0?ooo`200?ooo`030007
003oool0oooo04`0oooo001=0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0@`3o
ool00`001`00oooo0?ooo`040?ooo`030007003oool000L000l0oooo00<000L00?ooo`3oool0P03o
ool00`001`00oooo0?ooo`1<0?ooo`00C@3oool00`001`00oooo0?ooo`0D0?ooo`030007003oool0
oooo04<0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0007000?0?ooo`030007003oool0
oooo07l0oooo00<000L00?ooo`3oool0C@3oool004d0oooo00<000L00?ooo`3oool0503oool00`00
1`00oooo0?ooo`140?ooo`030007003oool0oooo00<0oooo0P001`0@0?ooo`030007003oool0oooo
07l0oooo00<000L00?ooo`3oool0C@3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00
oooo0?ooo`140?ooo`030007003oool0oooo00<0oooo0P001`0@0?ooo`030007003oool0oooo07h0
oooo00<000L00?ooo`3oool0CP3oool004d0oooo00<000L00?ooo`3oool0503oool00`001`00oooo
0?ooo`150?ooo`030007003oool0oooo0080oooo0P001`0@0?ooo`030007003oool0oooo07h0oooo
00<000L00?ooo`3oool0CP3oool004P0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?oo
o`0D0?ooo`030007003oool0oooo04H0oooo00@000L00?ooo`3oool0oooo0P001`0@0?ooo`030007
003oool0oooo07d0oooo00<000L00?ooo`3oool0C`3oool004T0oooo00D000L00?ooo`3oool0oooo
0007000F0?ooo`030007003oool0oooo04H0oooo00@000L00?ooo`3oool0oooo0P001`0@0?ooo`03
0007003oool0oooo07`0oooo00<000L00?ooo`3oool0D03oool004T0oooo00D000L00?ooo`3oool0
oooo0007000F0?ooo`030007003oool0oooo04L0oooo00<000L00?ooo`3oool00P001`0@0?ooo`03
0007003oool0oooo07`0oooo00<000L00?ooo`3oool0D03oool004L0oooo?0001`0[0?ooo`030007
003oool0oooo008000L0403oool00`001`00oooo0?ooo`1k0?ooo`030007003oool0oooo0540oooo
000e0?oooa8000L00`3oool010001`00oooo0?ooo`001`0F0?ooo`030007003oool0oooo01`0oooo
40001`0L0?ooo`040007003oool000L000070100oooo00<000L00?ooo`3oool0N`3oool00`001`00
oooo0?ooo`1A0?ooo`00:@3oool<000701H0oooo00<000L00?ooo`001`005P3oool00`001`00oooo
0?ooo`0/0?ooo``000L0403oool00`001`00oooo0007000A0?ooo`030007003oool0oooo07X0oooo
00<000L00?ooo`3oool0DP3oool001l0oooo2P001`0R0?ooo`030007003oool000L001H0oooo00<0
00L00?ooo`3oool0>03oool:000700L0oooo0P001`0A0?ooo`030007003oool0oooo07X0oooo00<0
00L00?ooo`3oool0DP3oool001/0oooo10001`0]0?ooo`8000L05P3oool00`001`00oooo0?ooo`12
0?ooo`T000L04@3oool00`001`00oooo0?ooo`1i0?ooo`030007003oool0oooo05<0oooo001<0?oo
ofh000L02@3oool00`001`00oooo0?ooo`1i0?ooo`030007003oool0oooo05<0oooo001=0?ooo`03
0007003oool0oooo01@0oooo00<000L00?ooo`3oool0B03oool3000700P0oooo10001`050?ooo`03
0007003oool0oooo07P0oooo00<000L00?ooo`3oool0E03oool004d0oooo00<000L00?ooo`3oool0
503oool00`001`00oooo0?ooo`160?ooo`8000L00`3oool00`001`00oooo0?ooo`090?ooo`L000L0
N03oool00`001`00oooo0?ooo`1E0?ooo`00CP3oool00`001`00oooo0?ooo`0C0?ooo`030007003o
ool0oooo04D0oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`0>0?ooo`030007003o
ool000L000D000L0L@3oool00`001`00oooo0?ooo`1F0?ooo`00CP3oool00`001`00oooo0?ooo`0C
0?ooo`030007003oool0oooo04<0oooo0P001`070?ooo`030007003oool0oooo00d0oooo00<000L0
0?ooo`3oool01@3oool5000706/0oooo00<000L00?ooo`3oool0E`3oool004l0oooo00<000L00?oo
o`3oool04P3oool00`001`00oooo0?ooo`110?ooo`8000L02@3oool00`001`00oooo0?ooo`0=0?oo
o`030007003oool0oooo00X0oooo10001`1W0?ooo`030007003oool0oooo05L0oooo001?0?ooo`03
0007003oool0oooo0180oooo00<000L00?ooo`3oool0@03oool00`001`00oooo0?ooo`090?ooo`03
0007003oool0oooo00d0oooo00<000L00?ooo`3oool03P3oool400070680oooo00<000L00?ooo`3o
ool0F03oool00500oooo00<000L00?ooo`3oool04@3oool00`001`00oooo0?ooo`0n0?ooo`8000L0
3@3oool00`001`00oooo0?ooo`0<0?ooo`030007003oool0oooo0180oooo1P001`1L0?ooo`030007
003oool0oooo05P0oooo001@0?ooo`030007003oool0oooo0140oooo00<000L00?ooo`3oool0?03o
ool2000700l0oooo00<000L00?ooo`3oool0303oool00`001`00oooo0?ooo`0H0?ooo`@000L0E`3o
ool00`001`00oooo0?ooo`1I0?ooo`008`3oool3000700<0oooo0`001`00103oool000L000070000
1`020?ooo`<000L00P3oool6000701@0oooo00<000L00?ooo`3oool0403oool00`001`00oooo0?oo
o`0k0?ooo`030007003oool0oooo00D0oooo0`001`030?ooo`<000L00P3oool00`001`00oooo0?oo
o`0;0?ooo`030007003oool0oooo01`0oooo10001`1C0?ooo`030007003oool0oooo05T0oooo000T
0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool00P3oool010001`00oooo0?ooo`00
1`050?ooo`050007003oool0oooo0?ooo`001`00503oool00`001`00oooo0?ooo`0@0?ooo`030007
003oool0oooo03T0oooo0P001`090?ooo`030007003oool0oooo00<0oooo00D000L00?ooo`3oool0
oooo0007000=0?ooo`030007003oool0oooo0200oooo0`001`1?0?ooo`030007003oool0oooo05X0
oooo000U0?ooo`D000L01P3oool2000700L0oooo00<000L00?ooo`3oool05P3oool00`001`00oooo
0?ooo`0?0?ooo`030007003oool0oooo03L0oooo0P001`0<0?ooo`D000L0103oool00`001`00oooo
0?ooo`0;0?ooo`030007003oool0oooo02<0oooo0P001`1=0?ooo`030007003oool0oooo05X0oooo
000U0?ooo`050007003oool0oooo0?ooo`001`001P3oool2000700P0oooo00<000L00?ooo`3oool0
5@3oool00`001`00oooo0?ooo`0?0?ooo`030007003oool0oooo03H0oooo00<000L00?ooo`3oool0
303oool01@001`00oooo0?ooo`3oool000L000D0oooo00<000L00?ooo`3oool02P3oool00`001`00
oooo0?ooo`0U0?ooo`<000L0B@3oool00`001`00oooo0?ooo`1K0?ooo`009P3oool00`001`00oooo
000700060?ooo`040007003oool0oooo000700@0oooo00D000L00?ooo`3oool0oooo0007000G0?oo
o`030007003oool0oooo00h0oooo00<000L00?ooo`3oool0=03oool200070100oooo00<000L00?oo
o`001`001P3oool00`001`00oooo0?ooo`0:0?ooo`030007003oool0oooo02P0oooo10001`140?oo
o`030007003oool0oooo05`0oooo000V0?ooo`030007003oool000L000@0oooo0`001`020?ooo`<0
00L00P3oool6000701H0oooo00<000L00?ooo`3oool03P3oool00`001`00oooo0?ooo`0b0?ooo`80
00L04P3oool00`001`00oooo000700060?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3o
ool0;03oool300070400oooo00<000L00?ooo`3oool0G@3oool002L0oooo00<000L00?ooo`3oool0
:P3oool00`001`00oooo0?ooo`0=0?ooo`030007003oool0oooo0340oooo00<000L00?ooo`3oool0
4`3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo00T0oooo00<000L00?ooo`3oool0
;`3oool2000703d0oooo00<000L00?ooo`3oool0GP3oool002H0oooo0P001`0/0?ooo`030007003o
ool0oooo00d0oooo00<000L00?ooo`3oool0;`3oool2000701D0oooo0P001`080?ooo`030007003o
ool0oooo00T0oooo00<000L00?ooo`3oool0<@3oool3000703X0oooo00<000L00?ooo`3oool0GP3o
ool005D0oooo00<000L00?ooo`3oool0303oool00`001`00oooo0?ooo`0]0?ooo`8000L08P3oool0
0`001`00oooo0?ooo`080?ooo`030007003oool0oooo03@0oooo0P001`0g0?ooo`030007003oool0
oooo05l0oooo001E0?ooo`030007003oool0oooo00`0oooo00<000L00?ooo`3oool0;03oool00`00
1`00oooo0?ooo`0R0?ooo`030007003oool0oooo00P0oooo00<000L00?ooo`3oool0=P3oool30007
03<0oooo00<000L00?ooo`3oool0H03oool005H0oooo00<000L00?ooo`3oool02`3oool00`001`00
oooo0?ooo`0Z0?ooo`8000L09@3oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo03T0
oooo0P001`0a0?ooo`030007003oool0oooo0600oooo001G0?ooo`030007003oool0oooo00X0oooo
00<000L00?ooo`3oool0:03oool2000702P0oooo00<000L00?ooo`3oool01`3oool00`001`00oooo
0?ooo`0k0?ooo`8000L0;P3oool00`001`00oooo0?ooo`1Q0?ooo`00E`3oool00`001`00oooo0?oo
o`0:0?ooo`030007003oool0oooo02L0oooo00<000L00?ooo`3oool0:03oool00`001`00oooo0?oo
o`070?ooo`030007003oool0oooo03d0oooo0P001`0[0?ooo`030007003oool0oooo0680oooo001H
0?ooo`030007003oool0oooo00T0oooo00<000L00?ooo`3oool09@3oool2000702`0oooo00<000L0
0?ooo`3oool01P3oool00`001`00oooo0?ooo`0o0?ooo`8000L0:03oool00`001`00oooo0?ooo`1S
0?ooo`00F03oool00`001`00oooo0?ooo`090?ooo`030007003oool0oooo02<0oooo0P001`0^0?oo
o`030007003oool0oooo00H0oooo00<000L00?ooo`3oool0@@3oool2000702D0oooo00<000L00?oo
o`3oool0I03oool005T0oooo00<000L00?ooo`3oool0203oool00`001`00oooo0?ooo`0Q0?ooo`80
00L0<03oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo04<0oooo00<000L00?ooo`3o
ool08P3oool00`001`00oooo0?ooo`1T0?ooo`00F@3oool00`001`00oooo0?ooo`080?ooo`030007
003oool0oooo0200oooo00<000L00?ooo`3oool0<@3oool00`001`00oooo0?ooo`050?ooo`030007
003oool0oooo04@0oooo0P001`0Q0?ooo`030007003oool0oooo06D0oooo001J0?ooo`030007003o
ool0oooo00L0oooo00<000L00?ooo`3oool07P3oool2000703@0oooo00<000L00?ooo`3oool01@3o
ool00`001`00oooo0?ooo`160?ooo`8000L07P3oool00`001`00oooo0?ooo`1V0?ooo`00FP3oool0
0`001`00oooo0?ooo`070?ooo`030007003oool0oooo01`0oooo0P001`0g0?ooo`030007003oool0
oooo00@0oooo00<000L00?ooo`3oool0B03oool00`001`00oooo0?ooo`0J0?ooo`030007003oool0
oooo06L0oooo001K0?ooo`030007003oool0oooo00H0oooo00<000L00?ooo`3oool06`3oool00`00
1`00oooo0?ooo`0g0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0B@3oool00`00
1`00oooo0?ooo`0H0?ooo`030007003oool0oooo06P0oooo001K0?ooo`030007003oool0oooo00H0
oooo00<000L00?ooo`3oool06@3oool2000703X0oooo00<000L00?ooo`3oool0103oool00`001`00
oooo0?ooo`1:0?ooo`030007003oool0oooo01L0oooo00<000L00?ooo`3oool0J03oool005`0oooo
00<000L00?ooo`3oool01@3oool00`001`00oooo0?ooo`0G0?ooo`8000L0?@3oool00`001`00oooo
0?ooo`030?ooo`030007003oool0oooo04/0oooo0P001`0F0?ooo`030007003oool0oooo06T0oooo
001L0?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool05P3oool00`001`00oooo0?oo
o`0m0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0C@3oool00`001`00oooo0?oo
o`0B0?ooo`030007003oool0oooo06X0oooo001M0?ooo`030007003oool0oooo00@0oooo00<000L0
0?ooo`3oool0503oool200070440oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`1>
0?ooo`030007003oool0oooo0100oooo00<000L00?ooo`3oool0J`3oool005d0oooo00<000L00?oo
o`3oool0103oool00`001`00oooo0?ooo`0B0?ooo`8000L0@`3oool00`001`00oooo0?ooo`020?oo
o`030007003oool0oooo04h0oooo00<000L00?ooo`3oool03`3oool00`001`00oooo0?ooo`1/0?oo
o`00GP3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo0140oooo00<000L00?ooo`3o
ool0@`3oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo04l0oooo0P001`0>0?ooo`03
0007003oool0oooo06d0oooo001N0?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0
3`3oool2000704L0oooo00D000L00?ooo`3oool0oooo0007001C0?ooo`030007003oool0oooo00X0
oooo00<000L00?ooo`3oool0KP3oool005l0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo
0?ooo`0=0?ooo`8000L0B@3oool01@001`00oooo0?ooo`3oool000L005@0oooo00<000L00?ooo`3o
ool0203oool00`001`00oooo0?ooo`1_0?ooo`00G`3oool00`001`00oooo0?ooo`020?ooo`030007
003oool0oooo00`0oooo00<000L00?ooo`3oool0B@3oool01@001`00oooo0?ooo`3oool000L005@0
oooo00<000L00?ooo`3oool01`3oool00`001`00oooo0?ooo`1`0?ooo`00H03oool01@001`00oooo
0?ooo`3oool000L000`0oooo0P001`1=0?ooo`040007003oool0oooo000705D0oooo00<000L00?oo
o`3oool01@3oool00`001`00oooo0?ooo`1a0?ooo`00H03oool01@001`00oooo0?ooo`3oool000L0
00X0oooo0P001`1?0?ooo`040007003oool0oooo000705D0oooo00<000L00?ooo`3oool01@3oool0
0`001`00oooo0?ooo`1a0?ooo`00H@3oool010001`00oooo0?ooo`001`090?ooo`030007003oool0
oooo0500oooo00<000L00?ooo`001`00EP3oool00`001`00oooo0?ooo`030?ooo`030007003oool0
oooo0780oooo001Q0?ooo`040007003oool0oooo000700L0oooo0P001`1C0?ooo`030007003oool0
00L005H0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`1c0?ooo`00HP3oool00`00
1`00oooo000700050?ooo`8000L0E@3oool00`001`00oooo0007001F0?ooo`050007003oool0oooo
0?ooo`001`00MP3oool00680oooo00<000L00?ooo`001`00103oool00`001`00oooo0?ooo`1F0?oo
o`8000L0E`3oool3000707L0oooo001S0?ooo`8000L00P3oool2000705T0oooo0P001`1G0?ooo`03
0007003oool0oooo07L0oooo001S0?ooo`@000L0G03oool00`001`00oooo0?ooo`1D0?ooo`8000L0
N@3oool005L0ooooa@001`1i0?ooo`00I03oool200070;<0oooo00<000L00?ooo`001`00N@3oool0
06@0oooo0P001`2b0?ooo`040007003oool0oooo000707T0oooo001T0?ooo`030007003oool000L0
0;00oooo00@000L00?ooo`3oool000L0NP3oool006@0oooo00<000L00?ooo`001`00[P3oool20007
00<0oooo00<000L00?ooo`3oool0N03oool006@0oooo00@000L00?ooo`3oool000L0[03oool00`00
1`00oooo0?ooo`030?ooo`030007003oool0oooo07P0oooo001T0?ooo`040007003oool0oooo0007
0:/0oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`1i0?ooo`00I03oool01@001`00
oooo0?ooo`3oool000L00:T0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`1i0?oo
o`00I03oool01@001`00oooo0?ooo`3oool000L00:P0oooo00<000L00?ooo`3oool01@3oool00`00
1`00oooo0?ooo`1i0?ooo`00I03oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo0500
oooo0`001`1B0?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool0NP3oool006@0oooo
00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`1B0?ooo`030007003oool0oooo04l0oooo
00<000L00?ooo`3oool01@3oool00`001`00oooo0?ooo`1j0?ooo`00I03oool00`001`00oooo0?oo
o`030?ooo`030007003oool0oooo0540oooo00<000L00?ooo`3oool0C@3oool2000700L0oooo00<0
00L00?ooo`3oool0N`3oool004@0oooo0`001`030?ooo`<000L00P3oool6000700l0oooo00<000L0
0?ooo`3oool00`3oool00`001`00oooo0?ooo`140?ooo`<000L00`3oool3000700@0oooo0P001`05
0?ooo`H000L0@P3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo07/0oooo00150?oo
o`030007003oool0oooo00<0oooo00<000L00?ooo`3oool00P3oool01@001`00oooo0?ooo`3oool0
00L000l0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`140?ooo`030007003oool0
oooo00<0oooo00<000L00?ooo`3oool00`3oool2000700H0oooo00D000L00?ooo`3oool0oooo0007
00110?ooo`030007003oool0oooo00L0oooo00<000L00?ooo`3oool0O03oool004H0oooo1@001`06
0?ooo`030007003oool0oooo0100oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`15
0?ooo`D000L01@3oool010001`00oooo0?ooo`001`060?ooo`030007003oool0oooo0440oooo00<0
00L00?ooo`3oool01P3oool2000707l0oooo00160?ooo`050007003oool0oooo0?ooo`001`001`3o
ool00`001`00oooo0?ooo`0?0?ooo`030007003oool0oooo00D0oooo00<000L00?ooo`3oool0A03o
ool01@001`00oooo0?ooo`3oool000L000D0oooo00@000L00?ooo`3oool000L01`3oool00`001`00
oooo0?ooo`0n0?ooo`8000L0203oool00`001`00oooo0?ooo`1o0?ooo`00A`3oool00`001`00oooo
000700050?ooo`050007003oool0oooo0?ooo`001`00403oool00`001`00oooo0?ooo`050?ooo`03
0007003oool0oooo04D0oooo00<000L00?ooo`001`001@3oool00`001`00oooo0?ooo`020?ooo`05
0007003oool0oooo0?ooo`001`000`3oool00`001`00oooo0?ooo`0l0?ooo`030007003oool0oooo
00L0oooo00<000L00?ooo`3oool0P03oool004L0oooo00<000L00?ooo`001`001@3oool6000700l0
oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`140?ooo`030007003oool000L000@0
oooo0`001`020?ooo`<000L00P3oool6000703/0oooo0P001`080?ooo`8000L0P`3oool004P0oooo
00<000L00?ooo`3oool06@3oool00`001`00oooo0?ooo`060?ooo`030007003oool0oooo04D0oooo
00<000L00?ooo`3oool0C@3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo08<0oooo
00170?ooo`8000L06`3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo04<0oooo0P00
1`1>0?ooo`030007003oool0oooo00P0oooo00<000L00?ooo`3oool0P`3oool006@0oooo00<000L0
0?ooo`3oool01`3oool00`001`00oooo0?ooo`2B0?ooo`030007003oool0oooo00L0oooo0P001`26
0?ooo`00I03oool00`001`00oooo0?ooo`080?ooo`030007003oool0oooo08l0oooo0P001`080?oo
o`8000L0R03oool006@0oooo00<000L00?ooo`3oool0203oool00`001`00oooo0?ooo`2>0?ooo`03
0007003oool0oooo00H0oooo0P001`2:0?ooo`00I03oool00`001`00oooo0?ooo`090?ooo`030007
003oool0oooo08`0oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`2:0?ooo`00I03o
ool00`001`00oooo0?ooo`090?ooo`030007003oool0oooo08/0oooo00<000L00?ooo`3oool01@3o
ool2000708d0oooo001T0?ooo`030007003oool0oooo00X0oooo00<000L00?ooo`3oool0R03oool2
000700H0oooo0P001`2?0?ooo`00I03oool00`001`00oooo0?ooo`0:0?ooo`030007003oool0oooo
08L0oooo00<000L00?ooo`3oool00`3oool300070940oooo001T0?ooo`030007003oool0oooo00/0
oooo00<000L00?ooo`3oool0Q03oool2000700@0oooo0P001`2D0?ooo`00I03oool00`001`00oooo
0?ooo`0<0?ooo`030007003oool0oooo0880oooo00<000L00?ooo`3oool00`3oool00`001`00oooo
0?ooo`2D0?ooo`00I03oool00`001`00oooo0?ooo`0<0?ooo`030007003oool0oooo0840oooo00<0
00L00?ooo`3oool00P3oool2000709L0oooo001T0?ooo`030007003oool0oooo00d0oooo00<000L0
0?ooo`3oool0O`3oool00`001`00oooo0?ooo`03000709T0oooo001T0?ooo`030007003oool0oooo
00d0oooo00<000L00?ooo`3oool0O@3oool5000709`0oooo001T0?ooo`030007003oool0oooo00h0
oooo00<000L00?ooo`3oool0N`3oool3000709l0oooo001T0?ooo`030007003oool0oooo00h0oooo
00<000L00?ooo`3oool0N03oool300070:80oooo001T0?ooo`030007003oool0oooo00l0oooo00<0
00L00?ooo`3oool0M@3oool300070:@0oooo001T0?ooo`030007003oool0oooo00l0oooo00<000L0
0?ooo`3oool0L@3oool500070:H0oooo001T0?ooo`030007003oool0oooo0100oooo00<000L00?oo
o`3oool0K@3oool300070080oooo00<000L00?ooo`3oool0YP3oool006@0oooo00<000L00?ooo`3o
ool0403oool00`001`00oooo0?ooo`1Y0?ooo`@000L0103oool00`001`00oooo0?ooo`2W0?ooo`00
I03oool00`001`00oooo0?ooo`0A0?ooo`030007003oool0oooo06@0oooo10001`060?ooo`8000L0
ZP3oool006@0oooo00<000L00?ooo`3oool04@3oool00`001`00oooo0?ooo`1P0?ooo`@000L0203o
ool200070:`0oooo001T0?ooo`030007003oool0oooo0180oooo00<000L00?ooo`3oool0F`3oool4
000700X0oooo0P001`2^0?ooo`00I03oool00`001`00oooo0?ooo`0B0?ooo`030007003oool0oooo
05D0oooo1P001`0<0?ooo`8000L0/03oool006@0oooo00<000L00?ooo`3oool04`3oool00`001`00
oooo0?ooo`1@0?ooo`@000L04@3oool00`001`00oooo0?ooo`2`0?ooo`00I03oool00`001`00oooo
0?ooo`0C0?ooo`030007003oool0oooo04`0oooo10001`0C0?ooo`8000L0/`3oool006@0oooo00<0
00L00?ooo`3oool0503oool00`001`00oooo0?ooo`140?ooo`L000L05@3oool200070;D0oooo001T
0?ooo`030007003oool0oooo01@0oooo00<000L00?ooo`3oool0?@3oool7000701X0oooo0P001`2g
0?ooo`00I03oool00`001`00oooo0?ooo`0E0?ooo`030007003oool0oooo03D0oooo1`001`0O0?oo
o`8000L0^@3oool006@0oooo00<000L00?ooo`3oool05@3oool00`001`00oooo0?ooo`0^0?ooo`L0
00L0903oool200070;/0oooo001T0?ooo`030007003oool0oooo01H0oooo00<000L00?ooo`3oool0
9P3oool7000702T0oooo0P001`2m0?ooo`00I03oool00`001`00oooo0?ooo`0F0?ooo`030007003o
ool0oooo01`0oooo2P001`0_0?ooo`030007003oool0oooo0;d0oooo001T0?ooo`030007003oool0
oooo01L0oooo00<000L00?ooo`3oool0303oool?000703L0oooo0P001`300?ooo`00I03oool00`00
1`00oooo0?ooo`0D0?oooa8000L0@`3oool300070<80oooo001C0?ooobP000L0103oool00`001`00
oooo0?ooo`1<0?ooo`8000L0a@3oool006@0oooo00<000L00?ooo`3oool0603oool00`001`00oooo
0?ooo`1:0?ooo`8000L0a`3oool006@0oooo00<000L00?ooo`3oool06@3oool00`001`00oooo0?oo
o`170?ooo`8000L0b@3oool006@0oooo00<000L00?ooo`3oool0H03oool300070</0oooo001T0?oo
o`030007003oool0oooo05d0oooo0`001`3>0?ooo`00I03oool00`001`00oooo0?ooo`1K0?ooo`80
00L0d@3oool006@0oooo00<000L00?ooo`3oool0F03oool300070=<0oooo001T0?ooo`030007003o
ool0oooo05D0oooo0`001`3F0?ooo`00I03oool00`001`00oooo0?ooo`1B0?ooo`<000L0f@3oool0
06@0oooo00<000L00?ooo`3oool0C`3oool300070=`0oooo001T0?ooo`030007003oool0oooo04`0
oooo0`001`3O0?ooo`00I03oool00`001`00oooo0?ooo`190?ooo`<000L0hP3oool006@0oooo00<0
00L00?ooo`3oool0AP3oool300070>D0oooo001T0?ooo`030007003oool0oooo0480oooo10001`3X
0?ooo`00I03oool00`001`00oooo0?ooo`0o0?ooo`<000L0k03oool006@0oooo00<000L00?ooo`3o
ool0>P3oool500070>l0oooo001T0?ooo`030007003oool0oooo03L0oooo0`001`3d0?ooo`00I03o
ool00`001`00oooo0?ooo`0b0?ooo`D000L0m`3oool006@0oooo00<000L00?ooo`3oool0;P3oool4
00070?`0oooo001T0?ooo`030007003oool0oooo02L0oooo1`001`3o0?ooo`40oooo001T0?ooo`03
0007003oool0oooo0240oooo1P001`3o0?ooo`P0oooo001T0?ooo`030007003oool0oooo01X0oooo
1`001`3o0?ooo`h0oooo001T0?ooo`030007003oool0oooo00l0oooo2`001`3o0?oooaD0oooo001D
0?ooob8000L0o`3ooolP0?ooo`00I03oool00`001`00oooo0?ooo`3o0?ooobl0oooo001T0?ooo`03
0007003oool0oooo0?l0oooo;`3oool006@0oooo00<000L00?ooo`3oool0o`3oool_0?ooo`00I03o
ool00`001`00oooo0?ooo`3o0?ooobl0oooo001T0?ooo`030007003oool0oooo0?l0oooo;`3oool0
06@0oooo00<000L00?ooo`3oool0o`3oool_0?ooo`00I03oool00`001`00oooo0?ooo`3o0?ooobl0
oooo001T0?ooo`030007003oool0oooo0?l0oooo;`3oool006@0oooo00<000L00?ooo`3oool0o`3o
ool_0?ooo`00I03oool00`001`00oooo0?ooo`3o0?ooobl0oooo001T0?ooo`030007003oool0oooo
0?l0oooo;`3oool006@0oooo00<000L00?ooo`3oool0o`3oool_0?ooo`00I03oool00`001`00oooo
0?ooo`3o0?ooobl0oooo003o0?oooiH0oooo003o0?oooiH0oooo003o0?oooiH0oooo003o0?oooiH0
oooo003o0?oooiH0oooo003o0?oooiH0oooo003o0?oooiH0oooo003o0?oooiH0oooo001O0?ooo`P0
00L0o`3oool_0?ooo`00H03oool00`001`00oooo0007003o0?oooc<0oooo001P0?ooo`8000L000<0
oooo0007003oool0o`3ooola0?ooo`00H@3oool010001`00oooo000700001`3o0?oooc40oooo001R
0?ooo`030007003oool000L00?l0oooo<@3oool00680oooo0P001`000`3oool000L00?ooo`3o0?oo
obl0oooo001P0?ooo`040007003oool0oooo00070080oooo00<000L00?ooo`3oool0o`3oool]0?oo
o`00H03oool800070?l0oooo;P3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool0
0?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool0
0?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool00?l0ooooUP3oool0
0?l0ooooUP3oool00400oooo10001`0o0?ooo`030007003oool0oooo00/0oooo0`001`050?ooo`<0
00L06@3oool00`001`00oooo0?ooo`0>0?ooo`<000L0SP3oool3000703/0oooo00140?ooo`030007
003oool0oooo03/0oooo00<000L00?ooo`3oool03P3oool00`001`00oooo0?ooo`040?ooo`030007
003oool0oooo01T0oooo00<000L00?ooo`3oool03P3oool00`001`00oooo0?ooo`2?0?ooo`030007
003oool0oooo03T0oooo00140?ooo`030007003oool0oooo03/0oooo00<000L00?ooo`3oool03P3o
ool00`001`00oooo0?ooo`040?ooo`030007003oool0oooo01T0oooo00<000L00?ooo`3oool03P3o
ool00`001`00oooo0?ooo`2?0?ooo`030007003oool0oooo03T0oooo000]0?ooo`@000L01@3oool7
000700<0oooo0`001`000`3oool000L00?ooo`040?ooo`8000L01@3oool6000700D0oooo0P001`0>
0?ooo`H000L00`3oool5000700L0oooo00<000L00?ooo`3oool00`3oool300070080oooo0`001`04
0?ooo`8000L01@3oool00`001`00oooo00070002000700D0oooo10001`040?ooo`D000L01P3oool0
0`001`00oooo0?ooo`040?ooo`030007003oool000L0008000L0103oool00`001`00oooo00070002
000700<0oooo0`001`020?ooo`<000L00`3oool4000700@0oooo1@001`030?ooo`L000L0103oool4
000700D0oooo1@001`020?ooo`L000L03@3oool4000700D0oooo10001`050?ooo`@000L00P3oool3
000700040?ooo`001`0000L00?ooo`8000L00`3oool4000700H0oooo10001`030?ooo`D000L01P3o
ool2000700H0oooo0P001`0b0?ooo`00;P3oool00`001`00oooo0?ooo`080?ooo`030007003oool0
oooo00<0oooo00@000L00?ooo`3oool0oooo0P001`050?ooo`8000L01@3oool00`001`00oooo0?oo
o`020?ooo`030007003oool0oooo00<0oooo0P001`0>0?ooo`030007003oool0oooo0080oooo00<0
00L00?ooo`3oool00P3oool01@001`00oooo0?ooo`3oool000L000H0oooo00<000L00?ooo`3oool0
103oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00<0oooo0P001`050?ooo`8000L0
0`3oool01@001`00oooo0?ooo`3oool000L000@0oooo00<000L00?ooo`3oool00P3oool00`001`00
oooo0?ooo`070?ooo`030007003oool0oooo00@0oooo0P001`030?ooo`040007003oool0oooo0?oo
o`8000L00`3oool01@001`00oooo0?ooo`3oool000L000@0oooo00D000L00?ooo`3oool0oooo0007
00040?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3oool01`3oool00`001`00oooo0?oo
o`040?ooo`030007003oool0oooo0080oooo00D000L00?ooo`3oool0oooo000700030?ooo`030007
003oool0oooo00@0oooo00<000L00?ooo`3oool03@3oool00`001`00oooo0?ooo`020?ooo`050007
003oool0oooo0?ooo`001`00103oool01@001`00oooo0?ooo`3oool000L000@0oooo00@000L00?oo
o`3oool000L00P3oool010001`00oooo0?ooo`001`030?ooo`030007003oool0oooo0080oooo00<0
00L00?ooo`3oool00P3oool00`001`00oooo0?ooo`020?ooo`050007003oool0oooo0?ooo`001`00
2@3oool2000700H0oooo0P001`0b0?ooo`00;P3oool00`001`00oooo0?ooo`080?ooo`030007003o
ool0oooo00<0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`0;0?ooo`030007003o
ool0oooo01P0oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`020?ooo`030007003o
ool0oooo00<0oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`020?ooo`030007003o
ool0oooo0080oooo00@000L00?ooo`3oool000L0103oool00`001`00oooo0?ooo`020?ooo`050007
003oool0oooo0?ooo`001`002@3oool00`001`00oooo0?ooo`070?ooo`030007003oool0oooo00@0
oooo00<000L00?ooo`3oool00P3oool01@001`00oooo0?ooo`3oool000L000@0oooo00D000L00?oo
o`3oool0oooo000700040?ooo`050007003oool0oooo0?ooo`001`002@3oool00`001`00oooo0?oo
o`070?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool01`3oool01@001`00oooo0?oo
o`3oool000L000H0oooo00<000L00?ooo`3oool0303oool00`001`00oooo0?ooo`030?ooo`050007
003oool0oooo0?ooo`001`00203oool00`001`00oooo0?ooo`020?ooo`040007003oool0oooo0007
0080oooo00@000L00?ooo`3oool000L00`3oool00`001`00oooo0?ooo`070?ooo`030007003oool0
oooo00H0oooo00<000L00?ooo`3oool01P3oool010001`00oooo0?ooo`001`0i0?ooo`00;P3oool0
10001`00oooo0?ooo`001`070?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool00P3o
ool00`001`00oooo0?ooo`0<0?ooo`030007003oool0oooo01P0oooo00<000L00?ooo`3oool01@3o
ool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00<0oooo00<000L00?ooo`3oool0103o
ool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo0080oooo00@000L00?ooo`3oool000L0
103oool00`001`00oooo0?ooo`020?ooo`040007003oool0oooo0?ooo`H000L0103oool00`001`00
oooo0?ooo`070?ooo`030007003oool0oooo00T0oooo00D000L00?ooo`3oool0oooo000700040?oo
o`050007003oool0oooo0?ooo`001`00103oool010001`00oooo0?ooo`3oool6000700@0oooo00<0
00L00?ooo`3oool01`3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo00P0oooo1000
1`060?ooo`030007003oool0oooo00`0oooo00<000L00?ooo`3oool01@001`020?ooo`H000L00`3o
ool00`001`00oooo0?ooo`020?ooo`040007003oool0oooo00070080oooo00@000L00?ooo`3oool0
00L00`3oool6000700@0oooo00<000L00?ooo`3oool01P3oool00`001`00oooo0?ooo`060?ooo`04
0007003oool0oooo000703T0oooo000^0?ooo`@000L01`3oool00`001`00oooo0?ooo`030?ooo`04
0007003oool0oooo0?ooo`8000L03`3oool00`001`00oooo0?ooo`0H0?ooo`030007003oool0oooo
00@0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`030?ooo`030007003oool0oooo
00@0oooo1P001`030?ooo`030007003oool0oooo0080oooo00@000L00?ooo`3oool0oooo0P001`03
0?ooo`050007003oool0oooo0?ooo`001`00103oool00`001`00oooo0?ooo`020?ooo`8000L0203o
ool00`001`00oooo0?ooo`050?ooo`@000L0103oool2000700<0oooo00@000L00?ooo`3oool0oooo
0P001`030?ooo`050007003oool0oooo0?ooo`001`00103oool00`001`00oooo0?ooo`020?ooo`80
00L0203oool00`001`00oooo0?ooo`040?ooo`040007003oool0oooo0?ooo`8000L00`3oool01@00
1`00oooo0?ooo`3oool000L000H0oooo00<000L00?ooo`3oool0303oool00`001`00oooo0?ooo`07
0?ooo`030007003oool0oooo0080oooo00D000L00?ooo`3oool0oooo000700040?ooo`030007003o
ool0oooo008000L000D0oooo000700001`00oooo000700030?ooo`030007003oool0oooo0080oooo
00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`060?ooo`8000L01P3oool00`001`00oooo
0?ooo`020?ooo`030007003oool0oooo03H0oooo000^0?ooo`060007003oool0oooo0007003oool0
00L00`3oool3000700H0oooo0`001`000`3oool000L00007000?0?ooo`030007003oool0oooo01P0
oooo00<000L00?ooo`3oool00`3oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00<0
oooo00<000L00?ooo`3oool0103oool00`001`00oooo0?ooo`020?ooo`030007003oool0oooo00<0
00L00P3oool3000700040?ooo`001`0000L00?ooo`<000L01@3oool4000700@0oooo0P001`00103o
ool000L0000700001`050?ooo`030007003oool0oooo00@0oooo00<000L00?ooo`3oool00P3oool0
0`001`00oooo0?ooo`02000700040?ooo`001`0000L0000700@0oooo00<000L00?ooo`001`000P00
1`050?ooo`@000L0103oool2000700040?ooo`001`0000L0000700<0oooo0`001`070?ooo`<000L0
00<0oooo0007003oool00`3oool3000700L0oooo00<000L00?ooo`3oool0303oool00`001`00oooo
0?ooo`080?ooo`@000L01@3oool400070080oooo0P001`001@3oool000L00?ooo`3oool000L000D0
oooo10001`030?ooo`L000L00`3oool2000700040?ooo`001`0000L000070080oooo0`001`020?oo
o`<000L0=`3oool002h0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`0K0?ooo`03
0007003oool0oooo0080oooo00<000L00?ooo`3oool04`3oool00`001`00oooo0?ooo`020?ooo`03
0007003oool0oooo0080oooo00D000L00?ooo`3oool0oooo000700070?ooo`030007003oool0oooo
00<0oooo00<000L00?ooo`3oool00P3oool00`001`00oooo0?ooo`0V0?ooo`030007003oool0oooo
00D0oooo00@000L00?ooo`3oool0oooo0P001`0<0?ooo`030007003oool0oooo03D0oooo00<000L0
0?ooo`3oool03@3oool010001`00oooo0?ooo`3oool2000702P0oooo00<000L00?ooo`3oool0C03o
ool002d0oooo1`001`0M0?ooo`030007003oool0oooo0080oooo00<000L00?ooo`3oool04`3oool0
0`001`00oooo0?ooo`020?ooo`040007003oool0oooo0?ooo`D000L0203oool00`001`00oooo0?oo
o`020?ooo`<000L00P3oool3000702L0oooo00<000L00?ooo`3oool01P3oool3000700030?ooo`00
1`00oooo00/0oooo00<000L00?ooo`3oool0=@3oool00`001`00oooo0?ooo`0>0?ooo`<000L000<0
oooo0007003oool09`3oool00`001`00oooo0?ooo`1<0?ooo`00>@3oool00`001`00oooo0?ooo`0F
0?ooo`@000L05`3oool400070180oooo00<000L00?ooo`3oool0;`3oool00`001`00oooo0?ooo`0G
0?ooo`8000L0703oool00`001`00oooo0?ooo`0F0?ooo`<000L0S03oool003T0oooo00<000L00?oo
o`3oool0/@3oool00`001`00oooo0?ooo`2U0?ooo`00o`3ooonF0?ooo`00o`3ooonF0?ooo`00o`3o
oonF0?ooo`00o`3ooonF0?ooo`00\
\>"],
  ImageRangeCache->{{{92.625, 362.125}, {318.5, 31.625}} -> {-0.92988, \
-0.253165, 0.00582901, 0.00582901}}],

Cell[TextData[{
  "the ",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  " function gives City-block geometry, Fig 3. Mixed geometries, such as \
cylindrical geometry, use different ",
  StyleBox["f",
    FontSlant->"Italic"],
  "'s for different directions."
}], "Text",
  PageWidth->WindowWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25039 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.299384 0.626673 0.543816 0.626673 [
[.5 1.26289 -83 0 ]
[.5 1.26289 83 13.5 ]
[ 0 0 0 0 ]
[ 1 1.25039 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.26289 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 13.750 moveto
(.3) show
93.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(City) show
129.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Block) show
171.000 13.750 moveto
(Geometry) show
219.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
225.000 13.750 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.25039 L
0 1.25039 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.26805 .54382 m
.95739 .54382 L
s
.29938 .54382 m
.29938 1.20182 L
s
.29938 .54382 m
.03634 .05314 L
s
.29938 1.17049 m
.92606 .54382 L
.04886 .0765 L
.29938 1.17049 L
s
.67539 .54382 m
.67539 .79448 L
.14907 .5141 L
.14907 .26343 L
.67539 .54382 L
s
.29938 .79448 m
.55005 .79448 L
.55005 .54382 L
.49995 .45035 L
.24928 .45035 L
.24928 .70102 L
.29938 .79448 L
s
.29938 .54382 m
.24928 .70102 L
.49995 .70102 L
.49995 .45035 L
.29938 .54382 L
s
.29938 .54382 m
.49995 .70102 L
.49995 .45035 L
.29938 .54382 L
s
.29938 .54382 m
.55005 .79448 L
.49995 .70102 L
s
gsave
.48742 .71982 -66 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.21168 .45035 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ax) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58139 .56888 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ay) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26178 .81328 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Az) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49995 .42529 -72 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Axy) show
81.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73805 .86969 -78 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Plane) show
93.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73805 .81955 -78 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
81.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
87.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
93.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73805 .76942 -69 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
69.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.67539 .51875 -72 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
75.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
81.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26178 .57515 -66 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .02977 -66.7813 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\327) show
70.563 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .54382 -66.1875 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\330) show
69.375 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29938 1.22062 -65.7813 -10.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.750 moveto
%%IncludeResource: font Math5Mono
%%IncludeFont: Math5Mono
/Math5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\331) show
68.563 13.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{230.25, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005I0001[b000`400?l00000o`00003oo`3ooomJ
0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ
0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ
0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ0?ooo`00o`3ooomJ
0?ooo`00o`3ooomJ0?ooo`005@3oool00`000000oooo0?ooo`3o0?oood80oooo000F0?ooo`030000
003oool0oooo0?l0oooo@@3oool001H0oooo00<000000?ooo`3oool0o`3ooom10?ooo`005`3oool0
0`000000oooo0?ooo`3o0?oood00oooo000G0?ooo`030000003oool0oooo0?l0oooo@03oool001P0
oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00603oool00`000000oooo0?ooo`3o0?ooocl0oooo
000I0?ooo`030000003oool0oooo0?l0oooo?P3oool001T0oooo00<000000?ooo`3oool0o`3oooln
0?ooo`006@3oool300000?l0oooo?P3oool001T0oooo0P0000000`3oool000000000003o0?oooc`0
oooo000J0?ooo`8000000P3oool200000?l0oooo>P3oool001X0oooo0P0000040?ooo`800000o`3o
oolh0?ooo`006P3oool00`000000oooo000000050?ooo`800000o`3ooolf0?ooo`006P3oool00`00
0000oooo000000070?ooo`800000o`3ooold0?ooo`006`3oool00`000000oooo000000080?ooo`80
0000o`3ooolb0?ooo`006`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0?l0oooo
;`3oool001/0oooo00@000000?ooo`3oool000002P3oool200000?l0oooo;`3oool001/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`800000o`3oool]0?ooo`00703oool010000000oooo0?oo
o`00000=0?ooo`800000o`3oool[0?ooo`00703oool01@000000oooo0?ooo`3oool0000000h0oooo
0P00003o0?ooobT0oooo000L0?ooo`050000003oool0oooo0?ooo`000000403oool200000?l0oooo
9`3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`800000o`3o
oolU0?ooo`00703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo0P00003o
0?ooob<0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?ooob00oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04`3oool200000?l0oooo803oool001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`800000o`3ooolN0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01H0oooo0P00003o0?oooa`0oooo000N0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool200000?l0oooo6P3oool001h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0I0?ooo`800000o`3ooolH0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01X0oooo0P00003o0?oooaH0oooo000N0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0703oool200000?l0oooo503oool001h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo4@3oool001l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`800000o`3ooolA0?ooo`007`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo0P00003o0?ooo`l0oooo000O0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0803oool200000?l0oooo3@3oool001l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`800000o`3oool;0?ooo`00803o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo0P00003o0?ooo`T0oooo000P
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool200000?l0oooo1`3oool0
0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`800000o`3oool50?oo
o`00803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0o`3oool20?ooo`008@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo
0P00003o0?ooo`80oooo000Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3o
ool200000?l0oooo000Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool2
00000?d0oooo000Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;@3oool20000
0?/0oooo000Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;P3oool200000?T0
oooo000R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<03oool200000?L0oooo
000R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<@3oool200000?D0oooo000R
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3b
0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo0P00003b0?oo
o`008`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo0P00003`0?ooo`00
8`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo0P00003^0?ooo`008`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03L0oooo0P00003/0?ooo`008`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo0P00003Z0?ooo`008`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo03X0oooo0P00003X0?ooo`00903oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo03`0oooo0P00003V0?ooo`00903oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0h`3oool002@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0n0?ooo`800000h`3oool002@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0o0?ooo`800000h@3oool002D0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`110?ooo`800000g`3oool002D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`120?ooo`800000g@3oool002D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`140?ooo`800000f`3oool002D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`150?ooo`800000f@3oool002H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`170?ooo`800000e`3oool002H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo0=@0oooo000V0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0B03oool200000=@0oooo000V0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0BP3oool200000=80oooo000V0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0B`3oool200000=00oooo000W0?ooo`030000003oool0oooo00l0oooo0P00001>
0?ooo`800000cP3oool002L0oooo00<000000?ooo`3oool0403oool3000004h0oooo0P00003<0?oo
o`009`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00800000CP3oool200000<X0
oooo000W0?ooo`030000003oool0oooo0100oooo0P0000030?ooo`800000CP3oool200000<P0oooo
000X0?ooo`030000003oool0oooo00l0oooo0P0000050?ooo`800000CP3oool00`000000oooo0?oo
o`350?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000H0oooo0P00001=
0?ooo`800000a@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo000000080?oo
o`800000C@3oool200000<<0oooo000X0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`1<0?ooo`800000`@3oool002T0oooo00<000000?ooo`3o
ool03P3oool010000000oooo0?ooo`00000:0?ooo`800000CP3oool200000;l0oooo000Y0?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`800000CP3oool20000
0;d0oooo000Y0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`800000CP3oool200000;/0oooo000Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`800000CP3oool200000;T0oooo000Y0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`800000
CP3oool00`000000oooo0?ooo`2f0?ooo`00:P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03`3oool2000004d0oooo0P00002f0?ooo`00:P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1<0?ooo`800000]03oool002X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo0P00001>0?ooo`800000/P3oool002X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180
oooo0P00001>0?ooo`800000/03oool002/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01@0oooo0P00001>0?ooo`800000[P3oool002/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo0P00
001>0?ooo`800000[03oool002/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01L0oooo0P00001>0?ooo`800000ZP3oool002/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo0P00001>0?oo
o`030000003oool0oooo0:L0oooo000[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04`0oooo0P00002W0?ooo`00
;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
6P3oool2000004h0oooo0P00002U0?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0703oool2000004h0oooo0P00002S0?ooo`00;03oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool2
000004h0oooo0P00002Q0?ooo`00;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool07`3oool2000004h0oooo0P00002O0?ooo`00;@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool2000004h0
oooo0P00002M0?ooo`00;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool08P3oool2000004h0oooo0P00002K0?ooo`00;@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo09P0oooo000]0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`800000CP3oool2000009P0oooo000^0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?oo
o`800000CP3oool2000009H0oooo000^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0V0?ooo`800000CP3oool2000009@0oooo000^0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`800000
CP3oool200000980oooo000^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0Y0?ooo`800000CP3oool200000900oooo000^0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0[0?ooo`800000CP3oool2
000008h0oooo000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo04d0oooo0P00002<0?ooo`00;`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool2000004l0
oooo00<000000?ooo`3oool0R@3oool002l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02h0oooo0P00001>0?ooo`800000R@3oool002l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0300oooo0P00
001>0?ooo`800000Q`3oool00300oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0340oooo0P00001>0?ooo`800000Q@3oool00300oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03<0oooo0P00001>0?oo
o`800000P`3oool00300oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03@0oooo0P00001>0?ooo`800000P@3oool00300oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
C@3oool2000007l0oooo000a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0f0?ooo`800000C`3oool2000007d0oooo000a0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`800000C`3oool0
0`000000oooo0?ooo`1j0?ooo`00<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0>@3oool2000004h0oooo0P00001j0?ooo`00<@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>P3oool2000004h0
oooo0P00001h0?ooo`00<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0?03oool2000001l0oooo0`00000/0?ooo`800000MP3oool00380oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03d0oooo0P00
000O0?ooo`030000003oool0oooo02`0oooo0P00001d0?ooo`00<P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?`3oool2000001d0oooo00<00000
0?ooo`3oool0;P3oool200000780oooo000b0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo0`0000030?oo
o`<0000000@0oooo00000000000000000P3oool3000000@0oooo0P00000a0?ooo`800000L03oool0
0380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0440oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000060?ooo`800000<`3oool2000006h0oooo000c0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`120?ooo`800000103oool50000
00H0oooo0P0000060?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`3oool0J`3oool0
03<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
04@0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000H0oooo00@00000
0?ooo`3oool00000=@3oool2000006/0oooo000c0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`150?ooo`80000000@0oooo0000003oool000001P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
=03oool2000006T0oooo000c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`170?ooo`80000000<0oooo0000003oool00`3oool300000080oooo0`00
0000103oool000000000000000020?ooo`<00000=`3oool2000006L0oooo000c0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`180?ooo`800000CP3o
ool2000006D0oooo000d0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`170?ooo`80000000<0oooo0000003oool0CP3oool2000006<0oooo000d0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool3000000<0oooo0`000000103o
ool000000000000000020?ooo`<0000000<0oooo0000003oool0B`3oool2000004l0oooo0P00001Q
0?ooo`00=03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0C03oool2000004l0oooo0P00001O0?ooo`00=03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo1@0000060?ooo`8000001@3oool00`000000oooo0?ooo`1=0?oo
o`800000C`3oool00`000000oooo0?ooo`1L0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000060?ooo`8000001P3ooomC0000
04h0oooo0P00001L0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
04`0oooo0P000000103oool0000000000000001>0?ooo`800000FP3oool003D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000@0oooo0`0000020?oo
o`<000000`3oool2000004/0oooo0P0000030?ooo`80000000<0oooo000000000000CP3oool20000
05P0oooo000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0>0?ooo`800000B@3oool2000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`1=0?ooo`800000EP3oool003H0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`80
0000403oool00`000000oooo000000160?ooo`8000001`3oool00`000000oooo000000030?ooo`80
0000C`3oool2000005@0oooo000f0?ooo`050000003oool0oooo0?ooo`0000007`3oool00`000000
oooo000000140?ooo`8000002@3oool010000000oooo0?ooo`0000040?ooo`800000C`3oool20000
0580oooo000f0?ooo`050000003oool0oooo0?ooo`0000007`3oool010000000oooo0?ooo`000011
0?ooo`8000002`3oool010000000oooo0?ooo`0000060?ooo`800000C`3oool200000500oooo000f
0?ooo`050000003oool0oooo0?ooo`0000007`3oool010000000oooo0?ooo`00000o0?ooo`800000
3@3oool01@000000oooo0?ooo`3oool0000000L0oooo0P00001?0?ooo`030000003oool0oooo04d0
oooo000f0?ooo`050000003oool0oooo0?ooo`0000007`3oool01@000000oooo0?ooo`3oool00000
03/0oooo0`00000?0?ooo`050000003oool0oooo0?ooo`0000002@3oool2000004h0oooo0P00001=
0?ooo`00=`3oool010000000oooo0?ooo`00000O0?ooo`050000003oool0oooo0?ooo`000000>@3o
ool200000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`800000CP3o
ool2000004/0oooo000g0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0d0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0C@3oool2000004T0oooo000g0?ooo`040000003oool0
oooo000001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`8000005P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P00001?0?ooo`800000A`3o
ool003L0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02l0oooo0P00000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool2000004l0oooo0P0000150?ooo`00>03oool00`000000oooo0000000O0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0;@3oool2000001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0=0?ooo`800000C`3oool2000004<0oooo000h0?ooo`030000003oool00000
01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`800000703oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo0P00001?0?ooo`800000@@3oool003P0
oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0
oooo0P00000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool2000004l0
oooo00<000000?ooo`3oool0?P3oool003P0oooo00<000000?ooo`0000007`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02@0oooo0`00000P0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04P3oool200000200oooo0`00000[0?ooo`800000?P3oool003P0oooo00<0
00000?ooo`0000007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo0P00
000S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02/0oooo0P00000l0?ooo`00>@3oool2000001l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`8000009@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01@0oooo0P00000O0?ooo`030000003oool0oooo02d0oooo0P00000j
0?ooo`00>@3oool2000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?oo
o`8000009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo0P0000080?oo
o`<000000P3oool3000000@0oooo00<000000?ooo`3oool01P3oool200000300oooo0P00000h0?oo
o`00>@3oool2000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`80
0000:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo0P0000080?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool01P3oool200000380oooo0P00000f0?oo
o`00>@3oool2000001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`80
0000:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo0P0000070?ooo`80
00001`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000003<0oooo0P00000d0?oo
o`00>P3oool3000001d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`80
0000;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo0P0000050?ooo`80
0000103oool7000000@0oooo00@000000?ooo`3oool00000=@3oool200000380oooo000j0?ooo`03
0000003oool0oooo008000006`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140
oooo0`00000_0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06`3oool200000080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0_0?ooo`00>P3oool00`000000
oooo0?ooo`020?ooo`8000006@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0
oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool300000080
oooo0`0000040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`<00000=P3oool2000002l0
oooo000j0?ooo`030000003oool0oooo00@0oooo0P00000G0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool2000003@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0M0?ooo`8000002@3oool00`000000oooo0?ooo`130?ooo`800000;@3oool003/0oooo00<0
00000?ooo`3oool01@3oool2000001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`800000=P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo0P00
001?0?ooo`800000:`3oool003/0oooo00<000000?ooo`3oool01`3oool2000001<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`800000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0200oooo0P00001?0?ooo`800000:@3oool003/0oooo00<000000?oo
o`3oool02@3oool200000140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`800000>P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0280oooo0P00001?0?oo
o`8000009`3oool003/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool2000003`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0S0?ooo`800000C`3oool2000002D0oooo000k0?ooo`030000
003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P00000n0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09@3oool2000004l0oooo
0P00000S0?ooo`00?03oool00`000000oooo0?ooo`0=0?ooo`800000303oool00`000000oooo0?oo
o`030?ooon400000603oool003`0oooo00<000000?ooo`3oool03`3oool2000000X0oooo00<00000
0?ooo`3oool03@3oool200000400oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`09
0?ooo`<000006P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0240oooo000l0?oo
o`030000003oool0oooo0140oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P0000000`3o
ool000000000000n0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool08P3oool003`0
oooo00<000000?ooo`3oool04`3oool2000000H0oooo00<000000?ooo`3oool0303oool200000080
oooo0P00000m0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool08`3oool003d0oooo
00<000000?ooo`3oool0503oool2000000@0oooo00<000000?ooo`3oool0303oool2000000<0oooo
0P00000l0?ooo`030000003oool0oooo00d0oooo100000030?ooo`<00000103oool2000001T0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0T0?ooo`00?@3oool00`000000oooo0?oo
o`0F0?ooo`8000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000@0oooo0`00
000j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02D0oooo000m
0?ooo`030000003oool0oooo01P0oooo0`0000020?ooo`@000001`3oool00`000000oooo00000005
0?ooo`030000003oool0000003T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`05
000000D0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo02H0oooo000m0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000H0oooo00<000000?ooo`000000>03oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
9`3oool003h0oooo00<000000?ooo`3oool06@3oool3000000D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0000003L0oooo00<000000?ooo`3oool0
3@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0X0?oo
o`00?P3oool00`000000oooo0?ooo`0I0?ooo`80000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`0000000000=@3oool0
0`000000oooo0?ooo`0=0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`<00000
0P3oool3000001H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0Y0?ooo`00?P3o
ool00`000000oooo0?ooo`0I0?ooo`8000000`3oool2000000030?ooo`000000oooo00<0oooo00@0
00000?ooo`3oool000002@3oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0:P3oool003h0oooo00<000000?ooo`3oool06@3oool2000000D0oooo
0P0000040?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000<`3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`8000008`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo02/0oooo000n0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`000000103oool01P000000oooo000000000000oooo000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0200000340oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0;03oool003l0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`04000000@0oooo0P0000030?ooo`030000003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo0000000`0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02d0oooo000o
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool3000000030?ooo`000000
oooo00`0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02h0oooo000o
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3o
ool2000000h0oooo00@000000?ooo`3oool0oooo0P00000]0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02l0oooo
000o0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0<03oool00400oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000003@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0<@3oool00400oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0b0?ooo`00@03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000002`3oool0
0`000000oooo0?ooo`020?ooo`800000:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0c0?ooo`00@03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0=03oool00400oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03D0
oooo00110?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo00<0oooo
0P00000T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo03H0oooo00110?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0=`3oool00440oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool2000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo00110?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0i0?ooo`00@P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`80
00001@3oool00`000000oooo0?ooo`040?ooo`8000007`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0j0?ooo`00
@P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0B0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0>`3oool00480oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503o
ool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo03`0oooo00120?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo0P0000020?ooo`030000003oool0
oooo00D0oooo0P00000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03d0oooo00130?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01P0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0?P3oool004<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000080?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0?`3oool004<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6`3oool3000000P0oooo0P00000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0400oooo00130?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01d0oooo0P0000090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0@@3o
ool004<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07`3oool2000000P0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`<000001`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo04<0oooo00140?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0240
oooo00@000000?ooo`00000000001P3oool200000180oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0A03oool004@0
oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`150?ooo`00A03oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?oo
o`0000002`3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04H0oooo00150?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P00000>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04L0oooo00150?oo
o`030000003oool0oooo0180oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo04P0oooo00150?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`0V0?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`190?ooo`00A@3oool00`000000oooo0?ooo`0B0?oo
o`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04X0oooo00150?oo
o`030000003oool0oooo0180oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`8000002@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;
0?ooo`00AP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000d0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo04`0oooo00160?ooo`030000003oool0oooo0140oooo00<000000?ooo`00
00003@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool0
00000?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo04d0oooo00160?ooo`030000003oool0oooo0140oooo
00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00L0oooo
100000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo04h0oooo00160?ooo`030000003oool0oooo0140oooo0P00
000>0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool3000000@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0C`3oool004L0oooo00<000000?ooo`3oool0403oool2000000h0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`8000000`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1@
0?ooo`00A`3oool00`000000oooo0?ooo`0@0?ooo`8000003P3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00T0oooo0`0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1A0?ooo`00A`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0:0?ooo`<000003`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0DP3oool004L0oooo00<000000?ooo`3oool0403ooomD000000h0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05<0oooo
00180?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00/0oooo0`00000<0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1D0?ooo`00B03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`03
000000<0oooo0`000000103oool000000?ooo`3oool2000000X0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05D0oooo00180?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000203oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0EP3oool004P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool01@0000040?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1G0?ooo`00B03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1H0?ooo`00B@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0=`3oool01@000000oooo0000003oool0000000H0oooo00<00000
0?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo05T0oooo00190?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0h0?ooo`80000000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`060?ooo`80000000<0oooo0000003oool09`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo05X0oooo00190?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0i0?ooo`800000203oool00`000000oooo0?ooo`080?ooo`80
0000:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05/0oooo00190?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0i0?ooo`800000
2@3oool00`000000oooo0?ooo`080?ooo`<000009P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo05`0oooo001:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`02000002@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1M0?ooo`00BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool200000280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1N
0?ooo`00BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool200000200oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1O0?oo
o`00BP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0H03oool004/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo0P00000M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
H@3oool004/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo0P00000K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0HP3o
ool004/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo0P00000I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0H`3oool0
04/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00d0oooo0P00000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0I03oool004/0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo0P00000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool7000005P0
oooo001<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0A0?ooo`8000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000D00000
1@3oool00`000000oooo0?ooo`1I0?ooo`00C03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04`3oool200000140oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05T0oooo001<0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`160?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0E0?ooo`8000003`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0F@3oool004`0oooo00<00000
0?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000004T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo1P0000050?ooo`030000003oool0oooo05T0oooo
001=0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0603oool2000000`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05T0oooo001=0?ooo`030000
003oool0oooo01L0oooo00@000000?ooo`3oool00000B`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01X0oooo0P00000:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1I0?ooo`00C@3oool00`000000oooo0?ooo`0G0?ooo`04
0000003oool0oooo000004`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?oo
o`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0`00001K0?oo
o`00C@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0000004d0oooo00D000000?ooo`00
0000oooo0000000P0?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000001<0oooo00<00000
0?ooo`3oool0F@3oool004d0oooo00<000000?ooo`3oool0603oool00`000000oooo0000001>0?oo
o`80000000<0oooo0000003oool08@3oool2000000@0oooo00@000000?ooo`3oool00000L03oool0
04h0oooo00<000000?ooo`3oool0603oool2000004l0oooo0`00000T0?ooo`8000000P3oool00`00
0000oooo0000001a0?ooo`00CP3oool00`000000oooo0?ooo`0H0?ooo`800000D03oool2000002H0
oooo1000001b0?ooo`00CP3oool00`000000oooo0?ooo`0I0?oooe<00000:03oool00`000000oooo
0?ooo`1a0?ooo`00CP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0LP3oool004l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0140oooo0`00001O0?ooo`00C`3oool00`000000oooo0?ooo`030?oo
o`<000000`3oool300000080oooo1P0000040?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1M0?ooo`00C`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
05d0oooo001?0?ooo`030000003oool0oooo00D0oooo1@0000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0L`3oool010000000oooo0?ooo`3oool300000080oooo0`0000040?oo
o`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo00@0oooo1P00001:0?oo
o`00D03oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`00D03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool01P3oool2000000L0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
B`3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?ooo`H00000103o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`L00000103o
ool010000000oooo0?ooo`0000030?ooo`L000001P3oool00`000000oooo0?ooo`1:0?ooo`00D03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000004/0oooo001@0?ooo`030000003oool0oooo00D0oooo
0P00000@0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool01P3oool300000080oooo
0`0000040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`<00000103oool00`000000oooo
0?ooo`040?ooo`H00000BP3oool00540oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`1D0?ooo`00D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0O@3oool00540oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo07h0oooo001A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`1o0?ooo`00DP3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0P03oool00580oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0840oooo001B0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`220?ooo`00DP3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0P`3oool00580
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo08@0
oooo001C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`250?ooo`00D`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo0P00
000C0?ooo`D00000103oool7000000@0oooo1@0000020?ooo`<000000P3oool3000000<0oooo1000
001;0?ooo`00D`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo04P0oooo001C0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000004l0oooo001D0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0F0?ooo`D000001P3oool00`000000oooo
0?ooo`050?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`H0
0000BP3oool005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0B03oool005@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000040?ooo`80
000000@0oooo00000000000000001@3oool4000004/0oooo001D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1V0?ooo`00E@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool06@3oool6000000H0oooo
00<000000?ooo`3oool0IP3oool005D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02@0oooo0`00001X0?ooo`00E@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0T03oool005D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0940oooo001E0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`2B0?ooo`00
EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
T`3oool005H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo09@0oooo001F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`2E0?ooo`00EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0UP3oool005L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo09L0oooo001G0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2H0?ooo`00E`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0V@3oool005L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09X0oooo001H0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2K0?oo
o`00F03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0W03oool005P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo09d0oooo001H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`2N0?ooo`00F03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0W`3oool005T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0:00oooo001I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Q0?ooo`00F@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0XP3oool005T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:<0oooo001J
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2T
0?ooo`00FP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0Y@3oool005X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo0:H0oooo001J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`2W0?ooo`00FP3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0Z03oool005/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0:T0oooo001K0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2Z0?ooo`00F`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0Z`3oool005/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:`0oooo
001L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`2]0?ooo`00G03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0[P3oool005`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0:l0oooo001L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`2`0?ooo`00G@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0/@3oool005d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0;80oooo001M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2c0?ooo`00G@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0]03oool005d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0;D0
oooo001N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`2f0?ooo`00GP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0]`3oool005h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0;P0oooo001N0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`2i0?ooo`00G`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0^P3oool005l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0;/0oooo001O0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2l0?ooo`00G`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0_@3oool0
0600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0;h0oooo001P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`2o0?ooo`00H03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0`03oool00600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0<40oooo001P0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`320?ooo`00H@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0``3oool00640oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0<@0oooo001Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`350?ooo`00H@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0aP3o
ool00680oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0<L0oooo001R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`380?ooo`00HP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0b@3oool00680oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0<X0oooo001R0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3;0?ooo`00H`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0c03oool006<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0<d0oooo001S0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3>0?ooo`00
H`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
c`3oool006@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0=00oooo001T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3A0?ooo`00I03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0dP3oool006@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0=<0oooo001U0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3D0?ooo`00I@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0e@3oool006D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0=H0oooo001U0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3G0?oo
o`00I@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0f03oool006H0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0=T0
oooo001V0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`3J0?ooo`00
IP3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0f`3oool006H0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0=`0oooo001W0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0g@3oool006L0oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0?ooo`3N0?ooo`00I`3oool010000000oooo0?ooo`00000<0?ooo`03
0000003oool0oooo0=l0oooo001W0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool0h03oool006L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3Q0?ooo`00
J03oool00`000000oooo000000090?ooo`030000003oool0oooo0>80oooo001X0?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool0h`3oool006P0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`3T0?ooo`00J03oool00`000000oooo000000060?ooo`030000003oool0oooo
0>D0oooo001Y0?ooo`8000001@3oool00`000000oooo0?ooo`3V0?ooo`00J@3oool2000000@0oooo
00<000000?ooo`3oool0i`3oool006T0oooo0P0000030?ooo`030000003oool0oooo0>P0oooo001Y
0?ooo`8000000P3oool00`000000oooo0?ooo`3Y0?ooo`00JP3oool00`000000oooo0000003/0?oo
o`00JP3oool200000>d0oooo001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?ooo`030000003o
ool0oooo0>`0oooo001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?ooo`030000003oool0oooo
0>`0oooo001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?ooo`030000003oool0oooo0>`0oooo
001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?oo
o`030000003oool0oooo0>`0oooo001Z0?ooo`030000003oool0oooo0>`0oooo001Z0?ooo`030000
003oool0oooo0>`0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0
oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0
oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0
oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0
oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo003o0?oooeX0oooo00160?ooo`@0
0000A03oool3000008@0oooo0`0000110?ooo`00BP3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0?`3oool004X0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo03l0oooo000c0?ooo`@000001@3oool7
000000<0oooo0`0000000`3oool000000?ooo`040?ooo`8000001P3oool4000000H0oooo0P00000@
0?ooo`@000000`3oool7000000D0oooo100000050?ooo`8000003@3oool6000000<0oooo1`000004
0?ooo`@000001@3oool4000000<0oooo0P0000020?ooo`<000003@3oool4000000D0oooo10000005
0?ooo`@000000P3oool3000000040?ooo`00000000000?ooo`8000000`3oool4000000H0oooo1000
00030?ooo`D000001P3oool2000000H0oooo0P00000h0?ooo`00=03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo0P0000060?ooo`80
0000>03oool003@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool00000?`3oool003@0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo1P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool3000000h0oooo00<00000
0?ooo`3oool01@0000020?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool6000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000003l0oooo000d0?ooo`@00000
1`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000003`3oool2000001H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`D000001P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000000`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P00
00001@3oool000000000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?03oool003@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`<0
00001P3oool3000000030?ooo`00000000000100oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000001@3oool700000080oooo0`0000020?oo
o`<000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool4000000D0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool00000
00800000303oool00`000000oooo0?ooo`080?ooo`@000001@3oool400000080oooo0P0000001@3o
ool000000?ooo`3oool0000000D0oooo100000030?ooo`L000000`3oool2000000040?ooo`000000
000000000080oooo0`0000020?ooo`<00000?@3oool003@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0P00
000=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`3oool2000002P0oooo00<000000?ooo`3oool0DP3oool003<0oooo1`00000M0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05@3oool3000000030?ooo`000000oooo00`0oooo00<0
00000?ooo`3oool05P3oool6000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0@0?ooo`<0000000<0oooo0000003oool09`3oool00`000000oooo0?ooo`1B0?ooo`00?`3oool0
0`000000oooo0?ooo`0F0?ooo`@000008P3oool00`000000oooo0?ooo`0X0?ooo`<000005`3oool2
000009@0oooo000o0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0f03oool00?l0
ooooFP3oool00?l0ooooFP3oool00?l0ooooFP3oool00?l0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{92.625, 321.875}, {655, 368.25}} -> {-1.20836, 1.84809, \
0.00737511, 0.00737511}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Mixed Metrics.", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Conjecture! If Time is a direction rather than a dimension, it may not \
combine with space directions via a Pythagorean or Minkowski metric. An \
interval between two events {",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)]],
  "} and {",
  Cell[BoxData[
      \(TraditionalForm\`t\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\_2\)]],
  "} might have a pythagorean space metric combined by a city-blocks relation \
for the time interval, ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(1, 2\)\)]],
  "=(",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`t\_2\)]],
  ")-",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\((x\_1 - x\_2)\)\^2 + \((y\_1 - y\_2)\)\^2 + \
\((z\_1 - z\_2)\)\^2\)\)]],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["4.1 6-Vector Light Cone?", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "On 7/11/5 I realised that the quartic size \"L4\" of C3C4c (and possibly \
of various related algebras) might define a light cone because it conserved \
the sum of six squared terms, minus a (dependent) seventh squared term.This \
could be a \"local time\", unlike the 4-Vector light cone, which has an \
independent time coordinate. L4 is non-negative, and Robert Israel \
[\"6-Vector Light Cone?\", sci.math, 4/1/6.] expressed it as two factors, \
each the sum of two squared terms.These areincluded as \"l22a\" & \"l22b\" in \
the C3C4 shape and in ",
  StyleBox["sh12",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Seeking Particle Equations via Equation Synthesis.", "Section",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["5.1 Equation Synthesis, travelling pulse.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->14],

Cell[TextData[{
  "\tI developed Equation Synthesis in an attempt to find solitonic \
non-linear differential equations that describe particles. Conservative \
evolution equations are set up with free parameters, as are target functions \
(usually travelling pulses of fixed shape) with undetermined coefficients. \
Substituting the function derivatives into the equation gives long \
expressions. Simplifying relationships between the free parameters and the \
coefficients may then lead to simple equations that are solved by specific \
functions.\n\tThe technique is to define a pulse function - e.g. the rational \
pulse ",
  StyleBox["V",
    FontSlant->"Italic"],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\((a/\((1 + \[Sum]\_\(x, y,  .. \)\(jx(xi + x - kx\ \
t)\)^2)\))\)\^n\)]],
  ", the Radial Sech pulse ",
  Cell[BoxData[
      StyleBox[\(a\ Exp[1 - \@\(1 + \[Sum]\_\(x, y,  .. \)x\^2\)]\),
        FontSlant->"Italic"]]],
  ", the modulated Gaussian pulse ",
  StyleBox["Exp[go + \[ImaginaryI] \[Omega] T+ ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)],
    FontSlant->"Italic"],
  StyleBox["[\[ImaginaryI] kx X - jx\.b2(X+xi-vx T)\.b2]",
    FontSlant->"Italic"],
  ", the power-sinusoid pulse ",
  StyleBox["a ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`Sin[X + xi - vx\ T]\^p\)],
    FontSlant->"Italic"],
  ", repeating lattice pulses such as the ",
  StyleBox["JacobiCN",
    FontSlant->"Italic"],
  " pulse - and to find the differentials ",
  StyleBox["Vt(=dv/dt), Vx(=dv/dx), Vxx",
    FontSlant->"Italic"],
  ", etc. (This shorthand for derivatives is widely used in the non-linear \
equation literature.) Various combinations of differentials are now \
calculated, usually with ",
  StyleBox["Vt ",
    FontSlant->"Italic"],
  "in the denominator. This allows evolution equations ",
  StyleBox[" F( V, Vx,Vxx, etc)=M Vt ",
    FontSlant->"Italic"],
  "to be handled easily (necessary with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 2 or 3; ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5 has a greatly improved ",
  StyleBox["Simplify",
    FontSlant->"Italic"],
  " operation). The sum of several combinations is calculated; then \
constraints which simplify the result are sought between the parameters. The \
simplified results are RHS multiplying factors ",
  StyleBox["M",
    FontSlant->"Italic"],
  ". Each simplification gives an equation which has a specific case of ",
  StyleBox["V",
    FontSlant->"Italic"],
  " as a solution."
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
\tFig 4 shows the decay of various TX pulses with similar peaks. The choice \
of the Cos[x/3.6]^12 power-sinusoid is arbitrary; higher powers give closer \
approximations to the Gaussian pulse with longer repeat distances, just as \
JacobiCN pulses approach the Sech pulse.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(esr = 
        Plot[{1/\((1 + x\^2/2)\), Cos[x/3.6]^12, \ Exp[1 - \@\(1 + x\^2\)], 
            Sech[x], \[ExponentialE]\^\(\(-x\^2\)/2\)}, {x, \(-1\), 6}, 
          PlotRange \[Rule] {0, 1}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[esr, 
        Graphics[{Text[\ \*"\"\<\!\(Cos\^12\)     Sech    Rsech\>\"", {3.6,  \
.03}], Text[\ "\<Rational\>", {2.9,  .3}], Text[\ "\<Exp\>", {1.3,  .3}]}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.159864 0.136054 0 0.618034 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.29592 -0.0125 -3 -9 ]
[.29592 -0.0125 3 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -3 -9 ]
[.70408 -0.0125 3 0 ]
[.84014 -0.0125 -3 -9 ]
[.84014 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.14736 .12361 -18 -4.5 ]
[.14736 .12361 0 4.5 ]
[.14736 .24721 -18 -4.5 ]
[.14736 .24721 0 4.5 ]
[.14736 .37082 -18 -4.5 ]
[.14736 .37082 0 4.5 ]
[.14736 .49443 -18 -4.5 ]
[.14736 .49443 0 4.5 ]
[.14736 .61803 -6 -4.5 ]
[.14736 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(1)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(2)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(3)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(4)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(5)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(6)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.15986 .12361 m
.16611 .12361 L
s
[(0.2)] .14736 .12361 1 0 Mshowa
.15986 .24721 m
.16611 .24721 L
s
[(0.4)] .14736 .24721 1 0 Mshowa
.15986 .37082 m
.16611 .37082 L
s
[(0.6)] .14736 .37082 1 0 Mshowa
.15986 .49443 m
.16611 .49443 L
s
[(0.8)] .14736 .49443 1 0 Mshowa
.15986 .61803 m
.16611 .61803 L
s
[(1)] .14736 .61803 1 0 Mshowa
.125 Mabswid
.15986 .0309 m
.16361 .0309 L
s
.15986 .0618 m
.16361 .0618 L
s
.15986 .09271 m
.16361 .09271 L
s
.15986 .15451 m
.16361 .15451 L
s
.15986 .18541 m
.16361 .18541 L
s
.15986 .21631 m
.16361 .21631 L
s
.15986 .27812 m
.16361 .27812 L
s
.15986 .30902 m
.16361 .30902 L
s
.15986 .33992 m
.16361 .33992 L
s
.15986 .40172 m
.16361 .40172 L
s
.15986 .43262 m
.16361 .43262 L
s
.15986 .46353 m
.16361 .46353 L
s
.15986 .52533 m
.16361 .52533 L
s
.15986 .55623 m
.16361 .55623 L
s
.15986 .58713 m
.16361 .58713 L
s
.25 Mabswid
.15986 0 m
.15986 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41202 m
.06244 .49193 L
.08255 .53213 L
.10458 .5709 L
.11448 .58546 L
.12507 .59846 L
.1302 .60369 L
.13506 .60793 L
.13975 .61136 L
.14415 .61394 L
.14877 .61598 L
.15121 .61679 L
.15385 .61743 L
.15516 .61767 L
.15586 .61777 L
.1566 .61786 L
.15731 .61793 L
.15796 .61797 L
.15921 .61803 L
.16043 .61803 L
.16174 .61798 L
.16298 .61787 L
.16413 .61773 L
.16519 .61756 L
.16634 .61734 L
.1684 .61682 L
.17085 .61602 L
.17309 .61513 L
.17796 .61262 L
.18257 .60955 L
.19222 .60104 L
.20248 .58914 L
.2209 .56154 L
.25865 .48912 L
.29885 .40613 L
.33754 .33359 L
.37868 .2695 L
.4183 .22041 L
.45641 .1831 L
.49697 .15187 L
.53602 .12817 L
.57751 .10821 L
.61749 .09284 L
.65596 .08081 L
.69688 .07031 L
.73628 .06196 L
.77417 .05521 L
.81451 .04914 L
.85333 .04418 L
.89461 .03966 L
Mistroke
.93437 .03593 L
.97262 .0328 L
.97619 .03253 L
Mfstroke
.02381 .38664 m
.06244 .48668 L
.08255 .53189 L
.10458 .57246 L
.11448 .58696 L
.12507 .59958 L
.1302 .60458 L
.13506 .60859 L
.13975 .61181 L
.14415 .61423 L
.14877 .61613 L
.15121 .61688 L
.15385 .61747 L
.15516 .61769 L
.15586 .61779 L
.1566 .61787 L
.15731 .61793 L
.15796 .61798 L
.15921 .61803 L
.16043 .61803 L
.16174 .61798 L
.16298 .61788 L
.16413 .61775 L
.16519 .6176 L
.16634 .61739 L
.1684 .61691 L
.17085 .61617 L
.17309 .61533 L
.17796 .61299 L
.18257 .61012 L
.19222 .60205 L
.20248 .59056 L
.2209 .56292 L
.25865 .48339 L
.29885 .37872 L
.33754 .27564 L
.37868 .17893 L
.3992 .13879 L
.4183 .10694 L
.4379 .07979 L
.45641 .05903 L
.47687 .04107 L
.49545 .02871 L
.51547 .0189 L
.53392 .01246 L
.54361 .00988 L
.55268 .00789 L
.56327 .006 L
.57332 .00457 L
.58303 .00348 L
Mistroke
.59361 .00255 L
.60323 .0019 L
.61215 .00143 L
.62274 .00101 L
.63271 .00071 L
.64166 .00052 L
.65133 .00036 L
.66086 .00025 L
.66627 .0002 L
.67131 .00016 L
.68149 .0001 L
.68719 8e-005 L
.69238 6e-005 L
.69721 5e-005 L
.70232 4e-005 L
.71151 2e-005 L
.71661 2e-005 L
.72139 1e-005 L
.72664 1e-005 L
.73228 1e-005 L
.73726 1e-005 L
.74188 0 L
.74695 0 L
.75236 0 L
.75806 0 L
.76343 0 L
.76825 0 L
.77347 0 L
.77838 0 L
.78296 0 L
.78799 0 L
.79081 0 L
.79339 0 L
.79856 0 L
.80149 0 L
.8042 0 L
.80916 0 L
.81167 0 L
.81445 0 L
.81679 0 L
.81935 0 L
.82203 0 L
.82452 0 L
.82686 0 L
.82899 0 L
.83145 0 L
.83377 0 L
.83629 0 L
.83897 0 L
.84125 0 L
Mistroke
.84377 0 L
.84647 0 L
.84798 0 L
.84937 0 L
.85066 0 L
.85206 0 L
.85462 0 L
.85595 0 L
.85717 0 L
.85849 0 L
.85994 0 L
.86237 0 L
.8637 0 L
.86494 0 L
.86616 0 L
.86731 0 L
.86946 0 L
.87067 0 L
.87178 0 L
.873 0 L
.8743 0 L
.87561 0 L
.8768 0 L
.87794 0 L
.87914 0 L
.88046 0 L
.88169 0 L
.88304 0 L
.88448 0 L
.88588 0 L
.88666 0 L
.88739 0 L
.88873 0 L
.8894 0 L
.89014 0 L
.89142 0 L
.89214 0 L
.8928 0 L
.89407 0 L
.89528 0 L
.89653 0 L
.89724 0 L
.89788 0 L
.89908 0 L
.90033 0 L
.90146 0 L
.90251 0 L
.90367 0 L
.9049 0 L
.90622 0 L
Mistroke
.90697 0 L
.90766 0 L
.90892 0 L
.90956 0 L
.91026 0 L
.91148 0 L
.91278 0 L
.91401 0 L
.91514 0 L
.91627 0 L
.91748 0 L
.91862 0 L
.91965 0 L
.92087 0 L
.92219 0 L
.92343 0 L
.92458 0 L
.92565 0 L
.92666 0 L
.92776 0 L
.92894 0 L
.93018 0 L
.93135 0 L
.9324 0 L
.93355 0 L
.93476 0 L
.93588 0 L
.9371 0 L
.93839 0 L
.93952 0 L
.94056 0 L
.94171 0 L
.94294 0 L
.94364 0 L
.94428 0 L
.94499 0 L
.94573 0 L
.94699 0 L
.94771 0 L
.94837 0 L
.94962 0 L
.95075 0 L
.95207 0 L
.95331 0 L
.95399 0 L
.95464 0 L
.95584 0 L
.95713 0 L
.95786 0 L
.95853 0 L
Mistroke
.95965 0 L
.96088 0 L
.96216 0 L
.96336 0 L
.96404 0 L
.96478 0 L
.96544 0 L
.96613 0 L
.96744 0 L
.96865 0 L
.96932 0 L
.97004 0 L
.97135 0 L
.9721 0 L
.9729 0 L
.97432 0 L
.97529 0 L
.97619 0 L
Mfstroke
.02381 .40843 m
.06244 .49109 L
.08255 .53186 L
.10458 .57086 L
.11448 .58544 L
.12507 .59846 L
.1302 .60369 L
.13506 .60793 L
.13975 .61136 L
.14415 .61394 L
.14877 .61598 L
.15121 .61679 L
.15385 .61743 L
.15516 .61767 L
.15586 .61777 L
.1566 .61786 L
.15731 .61793 L
.15796 .61797 L
.15921 .61803 L
.16043 .61803 L
.16174 .61798 L
.16298 .61787 L
.16413 .61773 L
.16519 .61756 L
.16634 .61734 L
.1684 .61682 L
.17085 .61602 L
.17309 .61513 L
.17796 .61262 L
.18257 .60955 L
.19222 .60104 L
.20248 .58913 L
.2209 .56146 L
.25865 .48822 L
.29885 .40223 L
.33754 .32433 L
.37868 .25283 L
.4183 .19635 L
.45641 .1527 L
.49697 .11612 L
.53602 .08881 L
.57751 .06656 L
.61749 .05027 L
.65596 .03831 L
.69688 .02864 L
.73628 .02162 L
.77417 .01648 L
.81451 .01233 L
.85333 .00932 L
.89461 .00692 L
Mistroke
.93437 .00519 L
.97262 .00393 L
.97619 .00383 L
Mfstroke
.02381 .40052 m
.06244 .4876 L
.08255 .53012 L
.10458 .5703 L
.11448 .58517 L
.12507 .59836 L
.1302 .60363 L
.13506 .6079 L
.13975 .61134 L
.14415 .61394 L
.14877 .61598 L
.15121 .61679 L
.15385 .61743 L
.15516 .61767 L
.15586 .61777 L
.1566 .61786 L
.15731 .61793 L
.15796 .61797 L
.15921 .61803 L
.16043 .61803 L
.16174 .61798 L
.16298 .61787 L
.16413 .61773 L
.16519 .61756 L
.16634 .61734 L
.1684 .61682 L
.17085 .61602 L
.17309 .61512 L
.17796 .61261 L
.18257 .60953 L
.19222 .60096 L
.20248 .58891 L
.2209 .56067 L
.25865 .4846 L
.29885 .39396 L
.33754 .31199 L
.37868 .23796 L
.4183 .18092 L
.45641 .13802 L
.49697 .10302 L
.53602 .07756 L
.57751 .05727 L
.61749 .04273 L
.65596 .03222 L
.69688 .02386 L
.73628 .01786 L
.77417 .01352 L
.81451 .01005 L
.85333 .00756 L
.89461 .00558 L
Mistroke
.93437 .00417 L
.97262 .00315 L
.97619 .00306 L
Mfstroke
.02381 .37486 m
.06244 .47828 L
.08255 .52589 L
.10458 .56906 L
.11448 .58459 L
.12507 .59815 L
.1302 .60352 L
.13506 .60785 L
.13975 .61132 L
.14415 .61393 L
.14877 .61598 L
.15121 .61679 L
.15385 .61743 L
.15516 .61767 L
.15586 .61777 L
.1566 .61786 L
.15731 .61793 L
.15796 .61797 L
.15921 .61803 L
.16043 .61803 L
.16174 .61798 L
.16298 .61787 L
.16413 .61773 L
.16519 .61756 L
.16634 .61734 L
.1684 .61682 L
.17085 .61602 L
.17309 .61512 L
.17796 .61259 L
.18257 .60949 L
.19222 .6008 L
.20248 .58845 L
.2209 .55888 L
.25865 .47484 L
.29885 .36678 L
.33754 .26345 L
.37868 .16957 L
.3992 .13153 L
.4183 .10175 L
.4379 .07659 L
.45641 .05747 L
.47687 .04094 L
.49545 .0295 L
.51547 .0203 L
.53392 .01411 L
.55268 .00957 L
.56335 .00761 L
.57332 .0061 L
.58373 .00482 L
.59361 .00384 L
Mistroke
.61215 .00246 L
.62176 .00194 L
.63199 .0015 L
.64158 .00117 L
.65039 .00093 L
.6607 .00071 L
.67184 .00052 L
.68167 .0004 L
.69203 .00029 L
.70153 .00022 L
.7117 .00017 L
.72131 .00012 L
.73005 9e-005 L
.73999 7e-005 L
.74917 5e-005 L
.75925 4e-005 L
.76995 3e-005 L
.77934 2e-005 L
.78946 1e-005 L
.79901 1e-005 L
.80775 1e-005 L
.81758 1e-005 L
.82671 0 L
.83674 0 L
.84234 0 L
.84743 0 L
.85744 0 L
.86665 0 L
.87147 0 L
.87677 0 L
.88226 0 L
.88746 0 L
.89234 0 L
.89765 0 L
.90695 0 L
.91221 0 L
.9178 0 L
.92304 0 L
.92785 0 L
.93721 0 L
.94212 0 L
.9473 0 L
.95602 0 L
.96097 0 L
.96557 0 L
.97619 0 L
Mfstroke
gsave
.64966 .01854 -130.625 -10.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cos) show
81.000 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
120.250 13.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sech) show
168.250 13.313 moveto
(Rsech) show
198.250 13.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55442 .18541 -87 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Rational) show
111.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33673 .18541 -72 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Exp) show
81.000 12.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->WindowWidth,
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`007`3oool7000005h0oooo1`00000^0?ooo`H00000<03oool400000380oooo1000000`0?oo
o`@00000<P3oool4000001d0oooo000R0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06P3oool00280oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`008P3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0]0?ooo`H00000=03oool00`000000oooo0?ooo`0^0?ooo`8000000`3o
ool00`000000oooo0?ooo`0J0?ooo`005P3oool6000000H0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo0P00000a0?ooo`040000003oool0
oooo000003D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo00000002000001d0oooo000R
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000<@3oool400000340oooo00<0
00000?ooo`3oool07`3oool00280oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool000000340oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0N
0?ooo`00803oool300000680oooo0`00000a0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`000000<@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01d0oooo000R0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0<03oool400000340oooo1000000c0?ooo`80
0000<@3oool5000003<0oooo0`00000L0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00503ooooo000008P000005@3oool001h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo7000000:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000002000000O0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo4@0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooobL000007`3oool005<0oooo
00<000000?ooo`3oool0U@3oool8000006L0oooo7`00000g0?ooo`00D`3oool00`000000oooo0?oo
o`1I0?ooo`@000001@3oool4000000@0oooo1@00000R0?ooo`P000005@3oool00`000000oooo0000
0002000000D0oooo100000050?ooo`@000000`3oool300000080oooo0`00000T0?ooob8000000`3o
ool300000080oooo0`00000i0?ooo`00D`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0K0?ooo`P000006@3oool2000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0603ooolL000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo03P0oooo001C0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05`3o
ool8000001d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
4`0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03P0oooo001C0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1000000H0?ooo`H000009P3oool010000000
oooo0?ooo`3oool600000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo3`00000=0?ooo`@000001P3oool4000000@0oooo1P0000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?oo
o`00D`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool04`3oool40000
02H0oooo100000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo200000000`3oool000000000
0004000001D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00<0oooo0P0000030?ooo`030000003oool0oooo03P0oooo001C0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`@000001@3oool5000001<0
oooo1000000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool4000000D0
oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0000000H00000103oool5000001/0
oooo00D000000?ooo`3oool0oooo000000050?ooo`D00000103oool4000000D0oooo0`0000000`3o
ool000000?ooo`020?ooo`030000003oool0000000800000>`3oool005<0oooo00<000000?ooo`3o
ool0F03oool010000000oooo0?ooo`3oool2000001@0oooo1@0000020?ooo`D000000`3oool40000
02T0oooo00@000000?ooo`3oool0oooo0P00000E0?ooo`@00000103oool500000200oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo03d0oooo001C0?ooo`030000003oool0
oooo05T0oooo0`0000000`3oool000000?ooo`0E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool4000002`0oooo0`0000000`3oool000000?ooo`0@0?ooo`D000000`3oool4
000002@0oooo1@00000P0?ooo`030000003oool0oooo03d0oooo001C0?ooo`800000M@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@00000@03oool4000000<0oooo1@00001<0?oo
o`800000?`3oool005<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`040?ooo`@0
0000?P3oool4000000@0oooo1000001Y0?ooo`T000007`3oool005<0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`040?ooo`800000?03oool4000000@0oooo1000001R0?ooo`/00000
:03oool005<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool00`000000oooo0?ooo`0e0?ooo`@00000103oool4000005h0oooo2000000c0?ooo`00D`3oool0
0`000000oooo0?ooo`1c0?ooo`8000000`3oool00`000000oooo00000002000003@0oooo10000005
0?ooo`<00000E`3oool;000003/0oooo001C0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0=03oool3000000H0oooo0`00001>0?ooo``00000AP3oool005<0oooo00<000000?ooo`3o
ool0M@3oool2000003@0oooo0`0000060?ooo`<00000B@3oool800000580oooo001C0?ooo`030000
003oool0oooo07@0oooo0P00000b0?ooo`<000001P3oool3000004D0oooo1`00001J0?ooo`00D`3o
ool00`000000oooo0?ooo`1c0?ooo`800000;`3oool4000000H0oooo0`0000130?ooo`D00000H@3o
ool005<0oooo00<000000?ooo`3oool0L@3oool2000002h0oooo0`0000080?ooo`800000@@3oool5
000006H0oooo001C0?ooo`030000003oool0oooo0700oooo0P00000]0?ooo`800000203oool30000
03d0oooo1P00001[0?ooo`00D`3oool00`000000oooo0?ooo`1_0?ooo`800000;03oool2000000L0
oooo0`00000h0?ooo`P00000L@3oool005<0oooo0P00001_0?ooo`800000:`3oool2000000L0oooo
0P00000e0?ooo`H00000N@3oool005<0oooo00<000000?ooo`3oool0K@3oool2000002X0oooo0P00
00060?ooo`<00000<P3oool5000007l0oooo001C0?ooo`030000003oool0oooo06`0oooo0P00000Y
0?ooo`8000001P3oool200000300oooo1@0000240?ooo`00D`3oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo02H0oooo0P0000060?ooo`800000;P3oool4000008T0oooo001C0?ooo`03
0000003oool0oooo06/0oooo0P00000V0?ooo`8000001P3oool2000002d0oooo0`00002=0?ooo`00
D`3oool00`000000oooo0?ooo`1Z0?ooo`8000009@3oool2000000H0oooo0P00000/0?ooo`<00000
T03oool005<0oooo00<000000?ooo`3oool0J@3oool2000002@0oooo0P0000070?ooo`030000003o
ool0oooo02P0oooo1000002C0?ooo`00D`3oool00`000000oooo0?ooo`1X0?ooo`8000008`3oool2
000000L0oooo0P00000X0?ooo`<00000U`3oool005<0oooo00<000000?ooo`3oool0I`3oool20000
02<0oooo00<000000?ooo`3oool01@3oool2000002L0oooo0`00002J0?ooo`00D`3oool00`000000
oooo0?ooo`1W0?ooo`8000008@3oool2000000H0oooo0P00000U0?ooo`@00000W@3oool005<0oooo
00<000000?ooo`3oool0IP3oool200000240oooo00<000000?ooo`3oool0103oool2000002<0oooo
1000002Q0?ooo`00D`3oool00`000000oooo0?ooo`1U0?ooo`800000803oool2000000H0oooo00<0
00000?ooo`3oool07`3oool400000:D0oooo001C0?ooo`800000I@3oool200000200oooo00<00000
0?ooo`3oool0103oool2000001l0oooo0`00002Y0?ooo`00D`3oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0000001h0oooo0P0000060?ooo`030000003oool0oooo01d0oooo0P00002/0?oo
o`00D`3oool00`000000oooo0?ooo`1S0?ooo`8000007P3oool00`000000oooo0?ooo`040?ooo`80
00007@3oool300000:h0oooo001C0?ooo`030000003oool0oooo0680oooo0P00000M0?ooo`800000
1P3oool00`000000oooo0?ooo`0J0?ooo`<00000/@3oool005<0oooo00<000000?ooo`3oool0H@3o
ool2000001d0oooo00<000000?ooo`3oool0103oool2000001/0oooo0P00002d0?ooo`00D`3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0000001`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`<00000]P3oool005<0oooo00<000000?ooo`3oool0H03oool20000
01`0oooo00<000000?ooo`3oool00`3oool2000001T0oooo0P00002i0?ooo`00D`3oool00`000000
oooo0?ooo`1O0?ooo`800000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0
oooo0P00002k0?ooo`00D`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0000001X0oooo
0P0000040?ooo`800000603oool200000;d0oooo000e0?ooo`@000001P3oool2000000D0oooo1P00
00070?ooo`030000003oool0oooo05h0oooo0P00000J0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05P3oool200000;l0oooo000d0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo0P0000310?ooo`00=03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1M0?oo
o`8000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo0P0000330?oo
o`00=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool3000005`0oooo0P00000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04`3oool200000<D0oooo000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05/0oooo00<000000?ooo`000000
603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo0P0000370?ooo`00=03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1K0?ooo`800000603oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo0P0000390?ooo`00=03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`0000005P3oool2000000D0oooo00<000000?ooo`3oool0403oool2
00000</0oooo000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0000000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool20000
0<d0oooo000e0?ooo`@000003P3oool4000000P0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0000000E0?ooo`030000003oool0oooo00<0oooo0P00000A0?ooo`030000003oool0oooo0<d0
oooo001C0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`0000005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo0P00003@0?ooo`00D`3oool00`000000oooo0?oo
o`1H0?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P00
003B0?ooo`00D`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0000001@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=80oooo001C0?oo
o`030000003oool0oooo05L0oooo0P00000D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool200000=D0oooo001C0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`00
00004`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo0P00003G0?ooo`00
D`3oool00`000000oooo0?ooo`1F0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0e`3oool005<0oooo0P00001F0?ooo`030000003o
ool0000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0=P0oooo001C0?ooo`030000003oool0oooo05D0oooo0P00000C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool200000=/0oooo001C0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0f`3oool005<0oooo00<000000?ooo`3oool0E03oool200000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=`0
oooo001C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`0000004@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00003O0?ooo`00D`3oool00`000000oooo0?oo
o`1C0?ooo`8000004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0g`3oool005<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0000000@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3P
0?ooo`00D`3oool00`000000oooo0?ooo`170?ooo`<00000203oool200000140oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`800000h`3oool005<0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`060?ooo`030000003oool000000100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0><0oooo001C0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool01P3oool200000100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>@0oooo001C0?ooo`030000003o
ool0oooo03D0oooo1`0000020?ooo`<000000P3oool300000080oooo00<000000?ooo`0000000P00
00030?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`D000000`3oool2000000<0oooo1@0000050?ooo`@000000P3oool7000000@0oooo1000
00030?ooo`<000000P3oool3000000<0oooo1@0000020?ooo`L00000X@3oool005<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool2000000<0oooo00H000000?ooo`3oool000000?ooo`00000>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0XP3oool005<0oooo0P00
000g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0XP3oool005<0oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00
00070?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool4000000H0oooo100000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`@000001P3oool00`000000oooo0?ooo`2R0?ooo`00D`3oool00`000000oooo
0?ooo`0f0?ooo`@000001P3oool010000000oooo0?ooo`0000040?ooo`8000000`3oool010000000
oooo00000000000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:80oooo001C0?ooo`030000
003oool0oooo03H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool30000
00040?ooo`00000000000?ooo`<0000000@0oooo0000003oool000003@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000D0oooo0`0000040?ooo`L000000`3oool3000000L0oooo100000030?ooo`800000
00@0oooo00000000000000001@3oool3000000L0oooo00<000000?ooo`3oool0XP3oool005<0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
0P00000>0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0:80oooo001C0?ooo`030000003oool0oooo03D0oooo1`00000A0?ooo`030000003oool0000000d0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00H0oooo1@00000?0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0XP3oool005<0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0000000<0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01l0oooo0`00002T0?ooo`00D`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0000000d0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0aP3oool005<0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`3`0?ooo`00D`3oool00`000000oooo0?ooo`1<0?ooo`800000303oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0l@3oool005<0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3b0?ooo`00D`3oool00`000000oooo0?ooo`1;0?ooo`800000
303oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0l`3oool005<0oooo
0P00001;0?ooo`030000003oool0000000/0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo0?@0oooo001C0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
m@3oool005<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0000000;0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3f0?ooo`00D`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0000000X0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0?L0oooo001C0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`0000002P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0n03oool005<0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`3h0?ooo`00D`3oool00`000000oooo0?ooo`180?ooo`8000002P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0n@3oool005<0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo000000090?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`3j0?ooo`00D`3oool00`000000oooo0?ooo`170?ooo`8000002P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0n`3oool003D0oooo1000
00060?ooo`8000001`3oool4000000L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0000
00090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3l0?ooo`00=03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo000000080?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3l0?ooo`00=03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`150?ooo`030000003oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0?d0oooo000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool6000000L0oooo0`0000150?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0?h0oooo000d0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo04D0oooo
0P0000090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool003@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0A03oool00`000000oooo000000080?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`3o0?ooo`00=03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`140?ooo`80
00002@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0@3oool003@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo000000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0o`3oool20?ooo`00=@3oool400000100oooo0P0000080?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0?l0oooo0`3oool005<0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0o`3oool40?oo
o`00D`3oool00`000000oooo0?ooo`120?ooo`030000003oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0?l0oooo103oool005<0oooo00<000000?ooo`3o
ool0@P3oool2000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo001C0?ooo`030000003oool0oooo0440oooo00<000000?ooo`0000001`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0oooo1P3oool005<0oooo00<000000?ooo`3o
ool0@@3oool2000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001C0?ooo`030000003oool0oooo0400oooo00<000000?ooo`0000001`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0oooo1`3oool005<0oooo0P0000110?ooo`03
0000003oool0000000L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?oo
o`P0oooo001C0?ooo`030000003oool0oooo0400oooo0P0000070?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0o`3oool90?ooo`00D`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo001C0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`0000001P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo2P3oool005<0oooo00<000000?ooo`3oool0
?`3oool2000000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
001C0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0oooo2`3oool005<0oooo00<000000?ooo`3oool0?P3o
ool2000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3o0?ooo``0oooo
001C0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0oooo303oool005<0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
o`3oool=0?ooo`00D`3oool00`000000oooo0?ooo`0m0?ooo`8000001P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0?l0oooo3P3oool005<0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3o
ool>0?ooo`00D`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo001C0?ooo`800000?@3oool20000
00D0oooo00H000000?ooo`3oool000000?ooo`00003o0?oooa80oooo001C0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0
oooo0?l0oooo403oool005<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo000000040?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00D`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo0000003o0?oo
oa@0oooo001C0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`000000103oool00`000000
oooo000000020?ooo`030000003oool0oooo0?l0oooo4P3oool005<0oooo00<000000?ooo`3oool0
>P3oool2000000D0oooo00D000000?ooo`000000oooo0000003o0?oooaD0oooo001C0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`000000103oool00`000000oooo000000020?ooo`030000
003oool0oooo0?l0oooo4`3oool005<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0000
00040?ooo`050000003oool000000?ooo`000000o`3ooolF0?ooo`00D`3oool00`000000oooo0?oo
o`0i0?ooo`800000103oool01@000000oooo0000003oool000000?l0oooo5`3oool005<0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo000000040?ooo`050000003oool000000?ooo`000000
o`3ooolG0?ooo`00D`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0000000<0oooo00D0
00000?ooo`000000oooo0000003o0?oooaP0oooo001C0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`000000103oool010000000oooo00000000003o0?oooaT0oooo001C0?ooo`800000>03o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000o`3ooolI0?ooo`00D`3o
ool00`000000oooo0?ooo`0g0?ooo`800000103oool010000000oooo00000000003o0?oooaX0oooo
001C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`0000000`3oool01@000000oooo0000
003oool000000?l0oooo6P3oool005<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0000
00030?ooo`040000003oool0000000000?l0oooo6`3oool005<0oooo00<000000?ooo`3oool0=P3o
ool2000000<0oooo00D000000?ooo`000000oooo0000003o0?oooa/0oooo001C0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`0000000`3oool010000000oooo00000000003o0?oooa`0oooo
001C0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool000000?l0oooo703oool005<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000
00030?ooo`040000003oool0000000000?l0oooo7@3oool005<0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000o`3ooolM0?ooo`00=@3o
ool4000000H0oooo0P0000070?ooo`@000001`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool000000080oooo00@000000?ooo`0000000000o`3ooolN0?ooo`00=03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`030000003oool000000080oooo00D0
00000?ooo`000000oooo0000003o0?oooah0oooo000d0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo000000020?ooo`040000003oool0000000000?l0oooo
7`3oool003@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000000`3o
ool00`000000oooo0?ooo`040?ooo`<00000<`3oool200000080oooo00@000000?ooo`0000000000
o`3ooolP0?ooo`00=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`0000000P0000070?ooo`030000003oool0oooo0380oooo00<000000?ooo`0000000P3o
ool010000000oooo00000000003o0?ooob00oooo000N0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0<P3oool01P000000oooo0000003oool000000?ooo`800000o`3ooolQ0?ooo`00
7P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0340oooo00<000000?ooo`000000
0P3oool010000000oooo00000000003o0?ooob40oooo000O0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0<@3oool01P000000oooo0000003oool000000?ooo`800000o`3ooolR0?oo
o`007`3oool00`000000oooo0?ooo`0C0?ooo`@000004@3oool3000000H0oooo00<000000?ooo`3o
ool0<@3oool01P000000oooo0000003oool000000?ooo`800000o`3ooolR0?ooo`007`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo00H000000?ooo`000000oooo0000003o
ool200000?l0oooo8`3oool001h0oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0`
0?ooo`060000003oool000000?ooo`000000oooo0P00003o0?ooob<0oooo000N0?ooo`030000003o
ool000000380oooo00<000000?ooo`3oool0<03oool2000000030?ooo`000000oooo00800000o`3o
oolT0?ooo`007`3oool00`000000oooo0000000a0?ooo`030000003oool0oooo02l0oooo00H00000
0?ooo`000000oooo0000003oool200000?l0oooo903oool001l0oooo00<000000?ooo`000000<@3o
ool00`000000oooo0?ooo`0_0?ooo`040000003oool000000?ooo`<00000o`3ooolU0?ooo`00803o
ool200000340oooo00<000000?ooo`3oool0;P3oool01P000000oooo0000003oool000000?ooo`80
0000o`3ooolU0?ooo`007P3oool01@000000oooo0000003oool000000300oooo00<000000?ooo`3o
ool0;P3oool010000000oooo0000003oool300000?l0oooo9P3oool001h0oooo00D000000?ooo`00
0000oooo0000000`0?ooo`800000;`3oool2000000030?ooo`000000oooo00800000o`3ooolV0?oo
o`007`3oool010000000oooo00000000000`0?ooo`030000003oool0oooo02d0oooo00L000000?oo
o`000000oooo0000003oool000000?l0oooo9`3oool001h0oooo0P000000103oool000000?ooo`00
000_0?ooo`030000003oool0oooo02d0oooo00D000000?ooo`00000000000?ooo`0200000?l0oooo
9`3oool001h0oooo00H000000?ooo`00000000000?ooo`00000_0?ooo`030000003oool0oooo02d0
oooo0P000000103oool000000?ooo`00003o0?ooobP0oooo000N0?ooo`<0000000@0oooo0000003o
ool00000;P3oool00`000000oooo0?ooo`0/0?ooo`050000003oool000000000003oool00P00003o
0?ooobP0oooo000N0?ooo`80000000D0oooo000000000000oooo0000000^0?ooo`030000003oool0
oooo02`0oooo0P000000103oool000000?ooo`00003o0?ooobT0oooo000O0?ooo`<0000000<0oooo
000000000000;P3oool00`000000oooo0?ooo`0[0?ooo`040000003oool000000?ooo`<00000o`3o
oolY0?ooo`007`3oool2000000050?ooo`00000000000?ooo`000000;@3oool00`000000oooo0?oo
o`0[0?ooo`060000003oool000000000003oool00000o`3ooolZ0?ooo`00803oool4000000030?oo
o`000000oooo02`0oooo00<000000?ooo`3oool0:`3oool2000000040?ooo`000000000000000?l0
oooo:P3oool00200oooo0`0000000`3oool000000000000]0?ooo`030000003oool0oooo02X0oooo
00H000000?ooo`00000000000?ooo`00003o0?ooob/0oooo000Q0?ooo`@0000000<0oooo0000003o
ool0:`3oool00`000000oooo0?ooo`0Z0?ooo`80000000@0oooo0000000000000000o`3oool[0?oo
o`008@3oool3000000030?ooo`000000000002`0oooo00<000000?ooo`3oool0:@3oool01P000000
oooo000000000000oooo00000?l0oooo;03oool00280oooo100000000`3oool000000?ooo`0Z0?oo
o`800000:P3oool00`000000oooo0000000300000?l0oooo;03oool00280oooo100000000`3oool0
00000?ooo`0Z0?ooo`030000003oool0oooo02T0oooo0`0000000`3oool000000?ooo`3o0?ooob`0
oooo000S0?ooo`D00000:`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0000000<00000
o`3oool]0?ooo`008`3oool4000000030?ooo`000000oooo02T0oooo00<000000?ooo`3oool0:03o
ool2000000030?ooo`00000000000?l0oooo;P3oool002@0oooo0`0000000`3oool000000?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo1@00003o0?ooobh0oooo000T0?ooo`D00000:P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0000000800000o`3oool_0?ooo`009@3oool300000003
0?ooo`000000oooo02P0oooo00<000000?ooo`3oool09`3oool500000?l0oooo;`3oool002D0oooo
1@00000Y0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`0000000P00003o0?oooc00oooo
000V0?ooo`<0000000<0oooo0000003oool09`3oool00`000000oooo0?ooo`0V0?ooo`D00000o`3o
ool`0?ooo`009P3oool3000000030?ooo`000000oooo02L0oooo00<000000?ooo`3oool09P3oool4
00000?l0oooo<@3oool002L0oooo1000000X0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`0000000P00003o0?oooc40oooo000W0?ooo`<0000000<0oooo0000003oool09P3oool00`000000
oooo0?ooo`0U0?ooo`@00000o`3ooolb0?ooo`00:03oool4000002L0oooo0P00000V0?ooo`@00000
o`3ooolb0?ooo`00:03oool4000002L0oooo00<000000?ooo`3oool0903oool400000?l0oooo<`3o
ool002T0oooo0P0000000`3oool000000?ooo`0U0?ooo`030000003oool0oooo02@0oooo1000003o
0?oooc<0oooo000Y0?ooo`@000009P3oool00`000000oooo0?ooo`0S0?ooo`040000003oool00000
00000?l0oooo=03oool002X0oooo0P0000000`3oool000000?ooo`0T0?ooo`030000003oool0oooo
02<0oooo1000003o0?oooc@0oooo000Z0?ooo`80000000<0oooo0000003oool0903oool00`000000
oooo0?ooo`0S0?ooo`<00000o`3ooole0?ooo`00:`3oool3000002D0oooo00<000000?ooo`3oool0
8P3oool400000?l0oooo=@3oool002/0oooo0P0000000`3oool000000?ooo`0S0?ooo`030000003o
ool0oooo0280oooo0`00003o0?ooocH0oooo000/0?ooo`<000001P3oool4000000H0oooo0P000006
0?ooo`@00000203oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0000000000?l0oooo=P3o
ool002`0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0240oooo0`00003o0?ooocL0oooo000]0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0000000000?l0oooo=`3oool0
02d0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool30000
0?l0oooo>03oool002d0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool4000000P0oooo0`00000O0?ooo`040000003oool000000000
0?l0oooo>03oool002h0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool07`3oool300000?l0oooo>@3oool002h0oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool07P3oool010000000oooo00000000003o0?ooocT0oooo000_0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`<00000
o`3ooolj0?ooo`00;`3oool3000000<0oooo1000000>0?ooo`@00000203oool00`000000oooo0?oo
o`0N0?ooo`<00000o`3ooolj0?ooo`00<03oool200000240oooo00<000000?ooo`3oool07@3oool3
00000?l0oooo>`3oool00300oooo0`00000P0?ooo`030000003oool0oooo01d0oooo0`00003o0?oo
oc/0oooo000a0?ooo`800000803oool00`000000oooo0?ooo`0L0?ooo`<00000o`3oooll0?ooo`00
<@3oool3000001l0oooo00<000000?ooo`3oool0703oool300000?l0oooo?03oool00380oooo0P00
000O0?ooo`030000003oool0oooo01/0oooo0`00003o0?ooocd0oooo000b0?ooo`8000007`3oool0
0`000000oooo0?ooo`0K0?ooo`<00000o`3ooolm0?ooo`00<`3oool2000001h0oooo00<000000?oo
o`3oool06P3oool300000?l0oooo?P3oool003<0oooo0P00000N0?ooo`8000006`3oool200000?l0
oooo?`3oool003@0oooo0P00000M0?ooo`030000003oool0oooo01T0oooo0`00003o0?ooocl0oooo
000d0?ooo`8000007@3oool00`000000oooo0?ooo`0I0?ooo`800000o`3ooom00?ooo`00=@3oool2
000001`0oooo00<000000?ooo`3oool06@3oool200000?l0oooo@03oool003D0oooo0P00000L0?oo
o`030000003oool0oooo01P0oooo0P00003o0?oood40oooo000f0?ooo`8000006`3oool00`000000
oooo0?ooo`0H0?ooo`800000o`3ooom10?ooo`00=P3oool2000001/0oooo00<000000?ooo`3oool0
5`3oool200000?l0oooo@P3oool003L0oooo0P00000J0?ooo`030000003oool0oooo01L0oooo0P00
003o0?oood80oooo000g0?ooo`8000006P3oool00`000000oooo0?ooo`0F0?ooo`800000o`3ooom3
0?ooo`00>03oool2000001T0oooo00<000000?ooo`3oool05P3oool200000?l0oooo@`3oool003P0
oooo0P00000I0?ooo`030000003oool0oooo01D0oooo0P00003o0?oood@0oooo000i0?ooo`800000
603oool00`000000oooo0?ooo`0E0?ooo`800000o`3ooom40?ooo`00>P3oool00`000000oooo0?oo
o`0F0?ooo`8000005@3oool200000?l0ooooA@3oool003X0oooo0P00000G0?ooo`030000003oool0
oooo01@0oooo0P00003o0?ooodD0oooo000k0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool04`3oool200000?l0ooooAP3oool003/0oooo0P00000F0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0o`3ooom50?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0180oooo0P00003o0?ooodL0oooo000l0?ooo`8000005@3oool00`000000oooo0?oo
o`0A0?ooo`800000o`3ooom80?ooo`00?@3oool2000001@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3o0?ooodL0oooo000n0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0403oool200000?l0ooooB@3oool003h0oooo0P00000C0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0o`3ooom80?ooo`00?`3oool200000180oooo00<000000?ooo`3oool0
3`3oool200000?l0ooooBP3oool00400oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0>0?ooo`800000o`3ooom;0?ooo`00@03oool200000140oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?ooodX0oooo00110?ooo`800000403oool2000000h0oooo0P00003o0?oo
od`0oooo00120?ooo`8000003`3oool00`000000oooo0?ooo`0<0?ooo`800000o`3ooom=0?ooo`00
@`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo0P00003o0?ooodh0oooo
00130?ooo`8000003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooC@3o
ool004@0oooo0P00000=0?ooo`030000003oool0oooo00X0oooo0P00003o0?ooodl0oooo00150?oo
o`800000303oool00`000000oooo0?ooo`090?ooo`800000o`3ooom@0?ooo`00AP3oool2000000/0
oooo00<000000?ooo`3oool0203oool200000?l0ooooD@3oool004L0oooo0P00000:0?ooo`030000
003oool0oooo00H0oooo0`00003o0?oooe80oooo00160?ooo`L000001P3oool00`000000oooo0?oo
o`050?ooo`<00000o`3ooomC0?ooo`00B@3oool3000000L0oooo00<000000?ooo`3oool0103oool2
00000?l0ooooE@3oool004T0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooE03oool004T0oooo00@000000?ooo`3oool0oooo0`000003
0?ooo`030000003oool0000000@00000o`3ooomG0?ooo`00B@3oool00`000000oooo0?ooo`040?oo
o`H00000o`3ooomK0?ooo`00B@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00190?ooo`030000
003oool0oooo0?l0ooooI@3oool004L0oooo0`00003o0?ooofL0oooo00190?ooo`030000003oool0
oooo0?l0ooooI@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-1.56708, -0.0763185, \
0.0283092, 0.00623199}}]
}, Open  ]],

Cell[TextData[{
  "Fig. 4. Rational, Rsech, Sech, ",
  Cell[BoxData[
      \(TraditionalForm\`Cos\^12\)]],
  ", and Exp functions plotted as TX pulses.."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tFirstly the Limiting Velocity Equation is shown to describe disturbances \
travelling at a fixed speed in any number of space-like directions. Then a \
generalization of the Korteweg-deVries (KdV) equation is discussed. It has \
some multi-dimensional solutions. A modulated Gaussian pulse and a power \
sinusoid wave are investigated. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Limiting Velocity Wave Equation.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->14],

Cell[TextData[{
  "The general PDE for disturbances travelling at unit velocity in d+1 \
directions is the Limiting Velocity Wave Equation \n                          \
                          Gtt-\[Sum][Gxx]=0 .\n(with ",
  StyleBox["Gxx=",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)],
    FontSlant->"Italic"],
  StyleBox["G/d",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)],
    FontSlant->"Italic"],
  " etc. and summation is over",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  StyleBox["...",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_m\)]],
  "). It is valid for any unit velocity function ",
  StyleBox["G[t-\[CapitalSigma]x lx] ",
    FontSlant->"Italic"],
  "where the ",
  StyleBox["lx",
    FontSlant->"Italic"],
  " are direction sines (or cosines). The equation can be written in the \
conservative form ",
  Cell[BoxData[
      RowBox[{\(\[PartialD]\_{t, 2}\), 
        RowBox[{"g", "[", 
          RowBox[{"t", ",", 
            StyleBox["x",
              FontWeight->"Bold"]}], "]"}], " "}]],
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["= ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_x\)],
    FontSlant->"Italic"],
  Cell[BoxData[
      RowBox[{\(\[PartialD]\_{x, 2}\), 
        RowBox[{
          RowBox[{"g", "[", 
            RowBox[{"t", ",", 
              StyleBox["x",
                FontWeight->"Bold"]}], "]"}], " "}]}]],
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  ".The TXYZ case is shown:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\[PartialD]\_{t, 2}G[\(-t\) + x\ lx + y\ ly + 
              z\ lz] - \[IndentingNewLine]\[PartialD]\_{x, 2}G[\(-t\) + 
              x\ lx + y\ ly + 
              z\ lz] - \[IndentingNewLine]\ \[PartialD]\_{y, 2}G[\(-t\) + 
              x\ lx + y\ ly + z\ lz] - \[PartialD]\_{z, 2}G[\(-t\) + x\ lx + 
              y\ ly + z\ lz]]\)], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    RowBox[{\(-\((\(-1\) + lx\^2 + ly\^2 + lz\^2)\)\), " ", 
      RowBox[{
        SuperscriptBox["G", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", \(\(-t\) + lx\ x + ly\ y + lz\ z\), 
        "]"}]}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "In each case there is a factor 1-\[Sum]",
  Cell[BoxData[
      \(TraditionalForm\`lx\^2\)]],
  ", and so the function is zero if the ",
  StyleBox["lx",
    FontSlant->"Italic"],
  " are direction sines and sum to 1. (Direction sines are used because the \
angles are measured towards the x direction and the lx contribution \
disappears when this angle is zero). Each additional space dimension adds the \
square of its direction sine. The PDE is therefore satisfied by any unit \
velocity function moving forward in any number of directions. This gives a \
Light-like limiting velocity in two possible ways:-\n1. If pairs of \
directions fold to single dimensions, the disturbance travels at a speed that \
is less than unity unless there is a zero velocity in one of each of the \
folded pairs.\n2. If all but 3 space directions are curled-up (Kaluza-Klein) \
directions, KK velocities reduce the velocity in the spatial directions; \
light-like disturbances have no velocity in the KK directions. KK \"orbital\" \
velocities give mass to the disturbances."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tThe spherically symmetric case is developed in \
http://www.mathpages.com/home/kmath242/kmath242.htm\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 + \((\(n - 1\)\/r)\) \[PartialD]\
\[Psi]\/\[PartialD]r\  = \ \[PartialD]\^2 \[Psi]\/\[PartialD]t\^2\)], "Input",\

  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 KdVB Equation, Rational Pulse.", "Subsection",
  PageWidth->WindowWidth,
  FontSize->14],

Cell[TextData[{
  "\tThe non-linear conservative evolution KdVn (Korteweg-deVries-n) equation\
\n",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\([\(n\^2\) A\ ]\)\_\(\(\ \)\(t\)\)\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(+\(\([\ A\_\(x\ x\) + \(n(1 + n\ )\) \(A\^\(1 + \
2/n\)\) A\_x]\)\(\ \)\)\_x\)\)],
    FontSlant->"Italic"],
  " = 0 i.e.",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\^2\)],
    FontSlant->"Italic"],
  StyleBox["At+Axxx+(n+1)(n+2)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`A\^\(2/n\)\)],
    FontSlant->"Italic"],
  StyleBox["Ax=0",
    FontSlant->"Italic"],
  " (Zabulsky 1963 with  ",
  StyleBox["n\[Rule]1/n",
    FontSlant->"Italic"],
  " ) combines KdV",
  StyleBox[" (n=2)",
    FontSlant->"Italic"],
  " and MKdV ",
  StyleBox["(n=1). ",
    FontSlant->"Italic"],
  "It has well-known solitonic Sech solutions of the form ",
  StyleBox["u/uo",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[PlusMinus]2\)\ j\ Sech\ \((\(\[PlusMinus]j\)\ \
\((\(-j\^2\)\ t/to + xi + x/xo)\))\))\)\^n\)],
    FontSlant->"Italic"],
  " (any ",
  StyleBox["n",
    FontSlant->"Italic"],
  "), and ",
  Cell[BoxData[
      \(TraditionalForm\`\((Jacobi\ Cnoid)\)\^n\)]],
  " solutions for ",
  StyleBox["n",
    FontSlant->"Italic"],
  "=1 or 2. A search for rational and Gaussian pulse equations led to a \
broadened form conserving the additional property ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([A\_x\^2/A]\)\(\ \)\)\_x\)]],
  " , and including  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(\([A\^\(1 + m\)]\)\(\ \)\),
            "TraditionalForm"], "t"], TraditionalForm]]],
  ". Rational and Gaussian functions are solutions for the degenerate KdVn \
cases where n=-1 and n=-2 respectively. The final form proved to be\n         \
",
  Cell[BoxData[
      \(TraditionalForm\`\([\ \(n(1 + n\ r)\) \(A\^\(1 + 2/n\)\) A\_x + \((r \
- 1)\) A\_x\^2/A + A\_\(x\ x\)]\)\_x + \([\(A\^\(1 + m\)\) \(\(n\^2\)(r + \
m)\)]\)\_\(\(\ \)\(t\)\)\  = 0\)], "Input",
    FormatType->StandardForm,
    FontWeight->"Plain"],
  "   (KdVB)\nAdding a ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "direction and the term ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((1 + n)\), 
            RowBox[{
              FormBox[\(y\_0\^2\),
                "TraditionalForm"], "/", "j"}]}], " "}], TraditionalForm]],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"[", 
            RowBox[{
              SuperscriptBox[
                StyleBox["A",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False}], \(1 - j\)], \(Ay\^j\)}], "]"}], "y"], 
        TraditionalForm]],
    FontSlant->"Italic"],
  " , which differentiates to ",
  StyleBox["(1+n)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(y\_0\^2\)\)\)],
    FontSlant->"Italic"],
  StyleBox["Ayy/",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["A",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], "0"], TraditionalForm]],
    FontSlant->"Italic"],
  ", gives the Kadometsev-Petviashvili (KP) equations when ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=0,",
  StyleBox[" r",
    FontSlant->"Italic"],
  "=1, ",
  StyleBox["n",
    FontSlant->"Italic"],
  "=2. KP1 corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  "=\[ImaginaryI], KP2 to ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  "=1. Note that ",
  Cell[BoxData[
      \(TraditionalForm\`A\_xxx\)]],
  " is related to the KP term, being ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"[", 
            RowBox[{
              SubscriptBox[
                RowBox[{"[", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["A",
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontTracking->"Plain",
                        FontVariations->{"Underline"->False,
                        "Outline"->False,
                        "Shadow"->False}], \(1 - j\)], \(Ax\^j\)}], "]"}], 
                "x"], "/", "j"}], "]"}], "x"], TraditionalForm]],
    FontSlant->"Italic"],
  "; both ",
  Cell[BoxData[
      \(TraditionalForm\`A\_xxx\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\_yy\)]],
  " have infinite sets of conserved properties, characterised by ",
  StyleBox["j",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, y, A}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({x, y, {3.`, 1.`, 4.`, 2.`, 6.`, 9.`}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Off[General::"\<spell\>", 
      General::"\<spell1\>"] (*Allows\ similar\ names\ to\ be\ \
\(\(used\)\(.\)\)\ *) ; Unprotect[x, j]; U =. ; j =. ; A =. ; X =. ; 
    Y =. ; {Simplify[
        D[U[t, y]\^\(1 - j\)*D[U[t, y]\^j, y]/j, 
          y]], \[IndentingNewLine]Simplify[\ 
        D[D[A[t, x]\^\(1 - j\)*D[A[t, x]\^j, x]/j, x], x]]}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["U", 
            TagBox[\((0, 2)\),
              Derivative],
            MultilineFunction->None], "[", \(t, y\), "]"}], ",", 
        RowBox[{
          SuperscriptBox["A", 
            TagBox[\((0, 3)\),
              Derivative],
            MultilineFunction->None], "[", \(t, x\), "]"}]}], "}"}]], "Output",\

  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "Equation Synthesis for a TXY rational pulse is demonstrated:-\nDefine a \
pulse with peak amplitude ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", breadth parameter ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", exponent ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "velocities ",
  StyleBox["kx, ky. ",
    FontSlant->"Italic"],
  "Create a re-write rule to clarify expressions and aid simplification:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[" ",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      RowBox[{
        StyleBox[
          RowBox[{
            RowBox[{"v", "=", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"a", "/", 
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        RowBox[{"b", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"kx", 
                                StyleBox[\(\((x + xi - lx\ t)\)\^2\),
                                  ScreenRectangle->{{0, 1280}, {0, 887}},
                                  WindowToolbars->"EditBar",
                                  WindowSize->{922, 467},
                                  WindowMargins->{{148, Automatic}, {
                                  Automatic, 0}},
                                  PrintingCopies->1,
                                  PrintingPageRange->{Automatic, Automatic},
                                  PageHeaders->{{Cell[ 
                                        TextData[ {
                                        CounterBox[ "Page"]}], "PageNumber"], 
                                        Inherited, Cell[ 
                                        TextData[ {
                                        ValueBox[ "FileName"]}], "Header"]}, {
                                      None, Inherited, None}},
                                  
                                  PageFooters->{{
                                    Inherited, Inherited, Inherited}, {Cell[ 
                                        TextData[ {
                                        ValueBox[ "FileName"]}], "Header"], 
                                        Cell[ 
                                        TextData[ "8/1/00 from 7/5/99"]], 
                                        Cell[ 
                                        TextData[ {
                                        CounterBox[ "Page"]}], 
                                        "PageNumber"]}},
                                  PageHeaderLines->{Inherited, False},
                                  PrivateNotebookOptions->{"ColorPalette"->{
                                  RGBColor, -1}},
                                  ShowCellLabel->True,
                                  ShowCellTags->False,
                                  RenderingOptions->{"ObjectDithering"->True,
                                  "RasterDithering"->False}]}], "+", 
                              RowBox[{"ky", 
                                StyleBox[\(\((y + yi - ly\ t)\)\^2\),
                                  ScreenRectangle->{{0, 1280}, {0, 887}},
                                  WindowToolbars->"EditBar",
                                  WindowSize->{922, 467},
                                  WindowMargins->{{148, Automatic}, {
                                  Automatic, 0}},
                                  PrintingCopies->1,
                                  PrintingPageRange->{Automatic, Automatic},
                                  PageHeaders->{{Cell[ 
                                        TextData[ {
                                        CounterBox[ "Page"]}], "PageNumber"], 
                                        Inherited, Cell[ 
                                        TextData[ {
                                        ValueBox[ "FileName"]}], "Header"]}, {
                                      None, Inherited, None}},
                                  
                                  PageFooters->{{
                                    Inherited, Inherited, Inherited}, {Cell[ 
                                        TextData[ {
                                        ValueBox[ "FileName"]}], "Header"], 
                                        Cell[ 
                                        TextData[ "8/1/00 from 7/5/99"]], 
                                        Cell[ 
                                        TextData[ {
                                        CounterBox[ "Page"]}], 
                                        "PageNumber"]}},
                                  PageHeaderLines->{Inherited, False},
                                  PrivateNotebookOptions->{"ColorPalette"->{
                                  RGBColor, -1}},
                                  ShowCellLabel->True,
                                  ShowCellTags->False,
                                  RenderingOptions->{"ObjectDithering"->True,
                                  "RasterDithering"->False}]}]}], ")"}]}]}], 
                      ")"}]}], ")"}], "n"]}], ";"}],
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        StyleBox["\[IndentingNewLine]",
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        StyleBox[\(vs\  = {kx \((x + xi - lx*t)\)^2\  + \ 
                    ky \((y + yi - ly*t)\)^2 -> \ kXY, \n\ 
                x + xi - lx*t -> \ X, \ lx*t - x - xi -> \ \(-X\), \n\ 
                y + yi - ly*t -> \ Y, \ ly*t - y - yi -> \ \(-Y\)};\),
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], "\n", 
        StyleBox[\(V = Simplify[v /. vs]\),
          FormatType->StandardForm]}]}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((a\/\(1 + b\ kXY\))\)\^n\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["Find derivatives and clarify:-", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[{
    StyleBox[\(vx = D[v, x]; Vx = Simplify[vx /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(vy = D[v, y]; Vy = Simplify[vy /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(vt = D[v, t]; Vt = Simplify[vt /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(vxx = D[v, {x, 2}]; Vxx = Simplify[vxx /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(vyy = D[v, {y, 2}]; Vyy = Simplify[vyy /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(vxxx = D[v, {x, 3}]; vyyy = D[v, {y, 3}];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(VxxxT = Simplify[\((vxxx + vyyy)\)/Vt /. vs];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    StyleBox[\(Vxy3T = 
          Simplify[\(\((2 \((Vxx\ Vx + Vyy\ Vy)\) - \((Vx^3 + Vy^3)\)/V)\)/
                V\)/Vt];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}]}], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Substitute in the differential equation LHS with parameter ",
  StyleBox["p",
    FontSlant->"Italic"],
  ",",
  " giving an expression for the 2D rhs. kXY is reverted to the original, \
using the symbol Vo in place of V (necessary because V is an expression):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["rhs2d",
        FontFamily->"Times New Roman"], 
      StyleBox["=",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(Simplify[
            VxxxT + p\ Vxy3T] /. {kXY -> \((a\ Vo\^\(\(-1\)/n\) - 1)\)/b}\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}]}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(1\/\(a\^2\ \((kx\ lx\ X + 
                ky\ ly\ Y)\)\)\) \((2\ b\ Vo\^\(2/n\)\ \((a\ kx\^2\ \((3 + 
                    n\ \((3 + 2\ p)\))\)\ Vo\^\(\(-1\)/n\)\ X - 
              2\ b\ kx\^3\ \((2 + n)\)\ \((1 + n + n\ p)\)\ X\^3 + 
              ky\^2\ Y\ \((3 + n\ \((3 + 2\ p)\) + 
                    b\ \((\(\((3 + n\ \((3 + 2\ p)\))\)\ \((\(-1\) + a\ \
Vo\^\(\(-1\)/n\))\)\)\/b - 
                          2\ ky\ \((2 + n)\)\ \((1 + n + 
                                n\ p)\)\ Y\^2)\))\))\))\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
Essential simplifying relationships can be identified and applied, to give a \
simple RHS :-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Solve[1 + n + n\ p == 0, p]\)\(\ \ \)\( (*\ 
      to\ eliminate\ X\^3\ term\ *) \)\)\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{p \[Rule] \(\(-1\) - n\)\/n}}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[rhs2d /. {p \[Rule] \(-1\) - 1/n}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(2\ b\ \((1 + n)\)\ Vo\^\(1\/n\)\ \((kx\^2\ X + ky\^2\ Y)\)\)\/\(a\ \
\((kx\ lx\ X + ky\ ly\ Y)\)\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["Simplifications are lx=kx, ly=ky,b=a/2:-", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      rhs2d /. {p \[Rule] \(-1\) - 1/n, lx \[Rule] kx, ly \[Rule] ky, 
          b \[Rule] a/2}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((1 + n)\)\ Vo\^\(1\/n\)\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "Transfer this to the LHS and change the sign, to give the required \
differential equation\n(1+n)Vt ",
  Cell[BoxData[
      \(TraditionalForm\`V\^\(1/n\)\)]],
  " - Vxxx - Vyyy +(1+1/n)(2(Vxx Vx+Vyy Vy) - ((",
  Cell[BoxData[
      \(TraditionalForm\`Vx\^3\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`Vy\^3\)]],
  ")/V)/V) = 0"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
Confirm correctness by using the conditions to re-define V, calculating the \
derivatives, and then showing that the equation simplifies to zero:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    StyleBox[\(V = 
        a/\((1 + \((a*\((kx*\((x + xi - kx*t)\)^2 + 
                        ky*\((y + yi - ky*t)\)^2)\))\)/2)\); v = V^n;\),
      FontFamily->"Times New Roman"], "\n", 
    StyleBox[\(vx = D[v, x]; vy = D[v, y]; vt = D[v, t]; vxx = D[v, {x, 2}]; 
      vyy = D[v, {y, 2}];\),
      ScreenRectangle->{{0, 1280}, {0, 887}},
      WindowToolbars->"EditBar",
      WindowSize->{922, 467},
      WindowMargins->{{148, Automatic}, {Automatic, 0}},
      PrintingCopies->1,
      PrintingPageRange->{Automatic, Automatic},
      PageHeaders->{{Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
      
      PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
              TextData[ {
                ValueBox[ "FileName"]}], "Header"], Cell[ 
              TextData[ "8/1/00 from 7/5/99"]], Cell[ 
              TextData[ {
                CounterBox[ "Page"]}], "PageNumber"]}},
      PageHeaderLines->{Inherited, False},
      PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
      ShowCellLabel->True,
      ShowCellTags->False,
      RenderingOptions->{"ObjectDithering"->True,
      "RasterDithering"->False}], "\n", 
    RowBox[{
      StyleBox[\(vxxx = D[v, {x, 3}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vyyy = D[v, {y, 3}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      RowBox[{
        StyleBox["Simplify",
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        StyleBox["[",
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FormatType->StandardForm,
                  FontFamily->"   \.17\.17Courier New"], 
                StyleBox[\(1 + n\),
                  FormatType->StandardForm,
                  FontFamily->"Times New Roman"], 
                StyleBox[")",
                  FormatType->StandardForm,
                  FontFamily->"Times New Roman"]}], 
              StyleBox["vt",
                FormatType->StandardForm,
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FormatType->StandardForm,
                FontFamily->"Times New Roman"], 
              StyleBox["V",
                FormatType->StandardForm,
                FontFamily->"Times New Roman"]}], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["-",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["vxxx",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["-",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["vyyy",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["+",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            
            StyleBox[\(\((1 + 
                    1/n)\) \((2 \((vxx\ vx + vyy\ vy)\)\  - \((vx^3 + vy^3)\)/
                        v)\)/v\),
              FormatType->StandardForm,
              FontFamily->"Times New Roman"]}], 
          StyleBox["==",
            FormatType->StandardForm,
            FontFamily->"   \.17\.17Courier New"], "0"}], "]"}]}]}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(True\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The TXYZ case gives a related equation with summation over x,y,z ; the terms \
for each new dimension cancel. Putting ky and/or kz = 0 reduces to a lower \
dimensional case. The result is valid for any number, d, of space-like \
dimensions. I have failed to find either a stable integration or a modulated \
version.\
\>", "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  "Hence  (1+1/n)Vt ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["V",
            FontSlant->"Plain"], \(1/n\)], TraditionalForm]]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)]],
  "[-Vxxx+(1+1/n)(2Vx Vxx/V-Vx\.b3/V\.b2)] = 0 \nhas a solution      V=",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"a", "/", 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  RowBox[{"a", " ", 
                    RowBox[{
                      FormBox[\(\[Sum]\_\(x, y,  .. \)\),
                        "TraditionalForm"], 
                      RowBox[{
                        RowBox[{
                          RowBox[{"[", 
                            RowBox[{"kx", " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox["X",
                                    FontSlant->"Plain"], "+", "xi", "-", 
                                  RowBox[{"kx", " ", 
                                    StyleBox["T",
                                      FontSlant->"Plain"]}]}], ")"}], 
                              "\.b2"}], "]"}], "/", "2"}], "/", "n"}]}]}]}], 
                " ", ")"}]}], ")"}], "n"], TraditionalForm]]]
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 Modulated Gaussian Pulse - KdVG Equation.", "Subsection",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontSize->14,
  FontWeight->"Bold"],

Cell["A similar procedure shows that:-", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "                           2 Gt + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)]],
  "[ -Gxxx + 2Gx Gxx/G - Gx\.b3/G\.b2] = 0\nor                                \
   [2G]t +",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)]],
  "[ [-Gxx + Gx\.b2/G]x] = 0\nhas a solution    G = Exp[go+",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)]],
  "[\[ImaginaryI](ix (X-kxT)) - kx(X+xi-kx T)\.b2]]"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tThis is a stable travelling gaussian envelope with velocity components \
",
  Cell[BoxData[
      \(TraditionalForm\`jx\^2\)]],
  ", spread ",
  Cell[BoxData[
      \(TraditionalForm\`jx\^\(-2\)\)]],
  ", modulation wave numbers kx, and angular velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(x, y,  .. \)\)]],
  "[kx ",
  Cell[BoxData[
      \(TraditionalForm\`jx\^2\)]],
  "]. It becomes an unmodulated pulse if the wave numbers are all zero. The \
result is valid for any number, \"m\" of space-like directions. The pulse has \
4 balanced phases, Cos, Sin, -Cos, -Sin; plotting just the real and imaginary \
phases gives an unbalanced set of phases - the result of \"",
  "fold",
  "ing\" pairs of directions. Replacing \[ImaginaryI] by \[DoubleStruckS], \
with ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[DoubleStruckS]", 
          StyleBox["r",
            FontSlant->"Italic"]], TraditionalForm]]],
  "=1, gives modulation in ",
  StyleBox["r",
    FontSlant->"Italic"],
  " phases. \n\tThe amplitude depends on the free variable ",
  StyleBox["go",
    FontSlant->"Italic"],
  ". Attempts to raise the baseline did not lead to any useful \
simplifications (Some ",
  Cell[BoxData[
      \(TraditionalForm\`Sech\^2\)]],
  " pulses have velocities reduced by raised baselines.). The TXYZ \
relationship is confirmed; similar results are obtained for any number of \
spatial directions:-"
}], "Text",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(G = 
      Exp[go + \[ImaginaryI] \((ix\ \((x - jx\ t)\))\) - 
          kx \((x + xi - lx\ t)\)\^2 + \[ImaginaryI] \((iy\ \((y - 
                    jy\ t)\))\) - 
          ky \((y + yi - ly\ t)\)\^2 + \[ImaginaryI] \((iz\ \((z - 
                    jz\ t)\))\) - kz \((z + zi - jz\ t)\)\^2]; Gt = D[G, t]; 
    Gx = D[G, x]; Gxx = D[Gx, x]; Gxxx = D[Gxx, x]; Gy = D[G, y]; 
    Gyy = D[Gy, y]; Gyyy = D[Gyy, y]; Gz = D[G, z]; Gzz = D[Gz, z]; 
    Gzzz = D[Gzz, z];\), "\[IndentingNewLine]", 
    \(rhsxyz = 
      Simplify[{2  Gt - Gxxx + 2  Gx\ Gxx/G - Gx\^3/G\^2 - Gyyy + 
            2  Gy\ Gyy/G - Gy\^3/G\^2 - Gzzz + 2  Gz\ Gzz/G - 
            Gz\^3/G\^2}]\)}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({2\ \[ExponentialE]\^\(go - kx\ \((\(-lx\)\ t + x + xi)\)\^2 - ky\ \
\((\(-ly\)\ t + y + yi)\)\^2 - \[ImaginaryI]\ \((ix\ jx\ t + iy\ jy\ t + iz\ \
jz\ t - ix\ x - iy\ y - iz\ z)\) - kz\ \((\(-jz\)\ t + z + zi)\)\^2\)\ \((\(-\
\[ImaginaryI]\)\ iz\ jz - \[ImaginaryI]\ ix\ \((jx - 
                  kx)\) - \[ImaginaryI]\ iy\ \((jy - 
                  ky)\) + \[ImaginaryI]\ iz\ kz - 2\ jz\^2\ kz\ t + 
            2\ jz\ kz\^2\ t + 2\ kx\^2\ lx\ t - 2\ kx\ lx\^2\ t + 
            2\ ky\^2\ ly\ t - 2\ ky\ ly\^2\ t - 2\ kx\^2\ x + 2\ kx\ lx\ x - 
            2\ kx\^2\ xi + 2\ kx\ lx\ xi - 2\ ky\^2\ y + 2\ ky\ ly\ y - 
            2\ ky\^2\ yi + 2\ ky\ ly\ yi + 2\ jz\ kz\ z - 2\ kz\^2\ z + 
            2\ jz\ kz\ zi - 2\ kz\^2\ zi)\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell["\<\
The imaginary component becomes zero if jx=kx etc; the real part becomes zero \
when lx=kx etc; ix, iy, & iz are unconstrained:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[{rhsxyz, "\<G = \>", G} /. {\ jx\  -> kx, jy\  -> ky, 
          jz -> kz, lx -> kx, ly -> ky, lz -> kz}]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({{0}, 
      "G = ", \[ExponentialE]\^\(go + \[ImaginaryI]\ ix\ \((\(-kx\)\ t + x)\) \
- kx\ \((\(-kx\)\ t + x + xi)\)\^2 + \[ImaginaryI]\ iy\ \((\(-ky\)\ t + y)\) \
- ky\ \((\(-ky\)\ t + y + yi)\)\^2 + \[ImaginaryI]\ iz\ \((\(-kz\)\ t + z)\) \
- kz\ \((\(-kz\)\ t + z + zi)\)\^2\)}\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.5 Power Sinusoid, TXY.. travelling pulse.",
  FontSize->14]], "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "The Power Sinusoid differential equation is",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(v\&\[DoubleDot]\), " ", "+", 
            RowBox[{\((1/p - 1)\), 
              RowBox[{
                FormBox[
                  RowBox[{" ", 
                    SuperscriptBox[
                      RowBox[{
                        FormBox[\(v\& . \),
                          "TraditionalForm"], " "}], "2"]}],
                  "TraditionalForm"], "/", "v"}]}], "+", 
            RowBox[{"p", " ", 
              FormBox[\(\[Omega]\^2\),
                "TraditionalForm"], "v"}]}], "=", "0"}], TraditionalForm]], 
    "Input",
    Evaluatable->False,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  " and is solved by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", 
          RowBox[{"a", 
            FormBox[\(Sin[\[Omega]t + \[Phi]]\^p\),
              "TraditionalForm"]}]}], TraditionalForm]],
    FontSlant->"Italic"],
  "; it reduces to the sinusoid equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(v\&\[DoubleDot]\), "+", " ", 
            RowBox[{
              FormBox[\(\[Omega]\^2\),
                "TraditionalForm"], "v"}]}], "=", "0"}], TraditionalForm]], 
    "Input",
    Evaluatable->False,
    FontWeight->"Plain"],
  " when ",
  StyleBox["p",
    FontSlant->"Italic"],
  "=1. It generalises to the travelling wave power sinusoid, ",
  StyleBox["V = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(\((a\ Sin[t\ \[Omega] - \(\[CapitalSigma]\_\(x, y,  .. \)\) kx\ \((x \
+ xi)\)])\)\^p\)],
    FontSlant->"Italic"],
  " in any number of space directions XY.. as a solution of ",
  Cell[BoxData[
      RowBox[{"Vtt", "+", \(\((1/p - 1)\) Vt^2/V\), "+", 
        RowBox[{"p", 
          FormBox[\(\[Omega]\^2\),
            "TraditionalForm"], "V"}]}]]],
  ". This is an expanding ripple of constant height. volume is not conserved \
because the DE is not a conservative form."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{"a", " ", 
          FormBox[
            StyleBox[
              SuperscriptBox[
                
                StyleBox[\(Sin[\[Phi] + t\ \[Omega] - kx*\((x + xi)\) - 
                      ky*\((y + yi)\) - kz*\((z + zi)\)]\),
                  FontFamily->"Times New Roman"], "p"],
              FontFamily->"Courier New"],
            "TraditionalForm"]}]}], 
      ";", \(Simplify[
        D[V, {t, 2}] + \((1/p - 1)\) D[V, t]^2/V + 
          p\ \(\[Omega]\^2\) V]\)}]], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(0\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "The p\[RightArrow]\[Infinity] limit is the Gaussian pulse. The travelling \
wave power sinusoid is also a solution to the (conservative) KdVG equation, \
as shown below for the TXYZ case, but the simplifying constraints are ",
  Cell[BoxData[
      \({lx \[ShortRightArrow] kx\^2, ly \[ShortRightArrow] ky\^2, 
        lz \[ShortRightArrow] kz\^2}\)]],
  " etc.:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    StyleBox[\(V = 
        a\ Sin[\[Phi] + kx*\((x + xi - jx*t)\) + ky*\((y + yi - jy*t)\) + 
              kz*\((z + zi - jz*t)\)]; v = V^p;\),
      FontFamily->"Times New Roman"], "\n", 
    RowBox[{
      StyleBox[\(vx = D[v, x]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vy = D[v, y]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vz = D[v, z]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vt = D[v, t]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vxx = D[v, {x, 2}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vyy = D[v, {y, 2}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], \(vzz = D[v, {z, 2}]\), ";"}], "\n", 
    RowBox[{
      StyleBox[\(vxxx = D[v, {x, 3}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[\(vyyy = D[v, {y, 3}]\),
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], 
      StyleBox[";",
        ScreenRectangle->{{0, 1280}, {0, 887}},
        WindowToolbars->"EditBar",
        WindowSize->{922, 467},
        WindowMargins->{{148, Automatic}, {Automatic, 0}},
        PrintingCopies->1,
        PrintingPageRange->{Automatic, Automatic},
        PageHeaders->{{Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"]}, {
            None, Inherited, None}},
        PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                TextData[ {
                  ValueBox[ "FileName"]}], "Header"], Cell[ 
                TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                TextData[ {
                  CounterBox[ "Page"]}], "PageNumber"]}},
        PageHeaderLines->{Inherited, False},
        PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
        ShowCellLabel->True,
        ShowCellTags->False,
        RenderingOptions->{"ObjectDithering"->True,
        "RasterDithering"->False}], \(vzzz = D[v, {z, 3}]\), ";", 
      RowBox[{
        StyleBox["rhs",
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        StyleBox["=",
          ScreenRectangle->{{0, 1280}, {0, 887}},
          WindowToolbars->"EditBar",
          WindowSize->{922, 467},
          WindowMargins->{{148, Automatic}, {Automatic, 0}},
          PrintingCopies->1,
          PrintingPageRange->{Automatic, Automatic},
          PageHeaders->{{Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"]}, {
              None, Inherited, None}},
          PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                  TextData[ {
                    ValueBox[ "FileName"]}], "Header"], Cell[ 
                  TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                  TextData[ {
                    CounterBox[ "Page"]}], "PageNumber"]}},
          PageHeaderLines->{Inherited, False},
          PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
          ShowCellLabel->True,
          ShowCellTags->False,
          RenderingOptions->{"ObjectDithering"->True,
          "RasterDithering"->False}], 
        RowBox[{
          StyleBox["Simplify",
            ScreenRectangle->{{0, 1280}, {0, 887}},
            WindowToolbars->"EditBar",
            WindowSize->{922, 467},
            WindowMargins->{{148, Automatic}, {Automatic, 0}},
            PrintingCopies->1,
            PrintingPageRange->{Automatic, Automatic},
            PageHeaders->{{Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"]}, {
                None, Inherited, None}},
            PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"], Cell[ 
                    TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"]}},
            PageHeaderLines->{Inherited, False},
            PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
            ShowCellLabel->True,
            ShowCellTags->False,
            RenderingOptions->{"ObjectDithering"->True,
            "RasterDithering"->False}], 
          StyleBox["[",
            ScreenRectangle->{{0, 1280}, {0, 887}},
            WindowToolbars->"EditBar",
            WindowSize->{922, 467},
            WindowMargins->{{148, Automatic}, {Automatic, 0}},
            PrintingCopies->1,
            PrintingPageRange->{Automatic, Automatic},
            PageHeaders->{{Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"]}, {
                None, Inherited, None}},
            PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"], Cell[ 
                    TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"]}},
            PageHeaderLines->{Inherited, False},
            PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
            ShowCellLabel->True,
            ShowCellTags->False,
            RenderingOptions->{"ObjectDithering"->True,
            "RasterDithering"->False}], 
          RowBox[{
            RowBox[{
              StyleBox["p",
                ScreenRectangle->{{0, 1280}, {0, 887}},
                WindowToolbars->"EditBar",
                WindowSize->{922, 467},
                WindowMargins->{{148, Automatic}, {Automatic, 0}},
                PrintingCopies->1,
                PrintingPageRange->{Automatic, Automatic},
                PageHeaders->{{Cell[ 
                        TextData[ {
                          CounterBox[ "Page"]}], "PageNumber"], Inherited, 
                      Cell[ 
                        TextData[ {
                          ValueBox[ "FileName"]}], "Header"]}, {
                    None, Inherited, None}},
                PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                        TextData[ {
                          ValueBox[ "FileName"]}], "Header"], Cell[ 
                        TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                        TextData[ {
                          CounterBox[ "Page"]}], "PageNumber"]}},
                PageHeaderLines->{Inherited, False},
                PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
                ShowCellLabel->True,
                ShowCellTags->False,
                RenderingOptions->{"ObjectDithering"->True,
                "RasterDithering"->False}], 
              StyleBox[" ",
                ScreenRectangle->{{0, 1280}, {0, 887}},
                WindowToolbars->"EditBar",
                WindowSize->{922, 467},
                WindowMargins->{{148, Automatic}, {Automatic, 0}},
                PrintingCopies->1,
                PrintingPageRange->{Automatic, Automatic},
                PageHeaders->{{Cell[ 
                        TextData[ {
                          CounterBox[ "Page"]}], "PageNumber"], Inherited, 
                      Cell[ 
                        TextData[ {
                          ValueBox[ "FileName"]}], "Header"]}, {
                    None, Inherited, None}},
                PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
                        TextData[ {
                          ValueBox[ "FileName"]}], "Header"], Cell[ 
                        TextData[ "8/1/00 from 7/5/99"]], Cell[ 
                        TextData[ {
                          CounterBox[ "Page"]}], "PageNumber"]}},
                PageHeaderLines->{Inherited, False},
                PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
                ShowCellLabel->True,
                ShowCellTags->False,
                RenderingOptions->{"ObjectDithering"->True,
                "RasterDithering"->False}], 
              StyleBox["vt",
                FormatType->StandardForm,
                FontFamily->"Times New Roman"]}], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], "-", 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[\((vxxx\  + \ vyyy + vzzz)\),
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            StyleBox["+",
              FormatType->StandardForm,
              FontFamily->"Times New Roman"], 
            
            StyleBox[\(\((1 - 
                    1/p)\) \((2 \((vxx\ vx + vyy\ vy + 
                            vzz\ vz)\)\  - \((vx^3 + vy^3 + vz^3)\)/v)\)/v\),
              FormatType->StandardForm,
              FontFamily->"Times New Roman"]}], "]"}]}]}]}], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\((\(-jx\)\ kx + kx\^3 - jy\ ky + ky\^3 - jz\ kz + kz\^3)\)\ p\^2\ Cot[
        kx\ \((\(-jx\)\ t + x + xi)\) + ky\ \((\(-jy\)\ t + y + yi)\) + 
          kz\ \((\(-jz\)\ t + z + 
                zi)\) + \[Phi]]\ \((a\ Sin[kx\ \((\(-jx\)\ t + x + xi)\) + ky\
\ \((\(-jy\)\ t + y + yi)\) + kz\ \((\(-jz\)\ t + z + zi)\) + \
\[Phi]])\)\^p\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rhs /. {jx -> kx\^2, jy -> ky\^2, jz -> kz\^2}\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(0\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[{\(Hence\ \ v = 
      a\ Sin[\[Phi] + \(\[CapitalSigma]\_\(x, y,  .. \)\) kx\ \((x + xi - \
kx\^2\ t)\)]\^p\ solves\), "\[IndentingNewLine]", 
    RowBox[{
      "  ", \(p\ v\^2\ vt + \(\[CapitalSigma]\_\(x, 
                y,  .. \)\) \((\(-v\^2\)\ vxxx + \((1 - 
                      1/p)\) \((2  v\ vxx\ vx - v\ vx\^3)\))\) = 
        0\)}], "\[IndentingNewLine]", 
    StyleBox[\(giving\ a\ plane\ wave\ train\ in\ any\ direction\ in\ any\ \
number\ of\ \(\(dimensions\)\(.\)\)\),
      FontWeight->"Plain"]}], "Text",
  PageWidth->WindowWidth,
  FontWeight->"Bold"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{854, 591},
WindowMargins->{{33, Automatic}, {Automatic, 78}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Footer"], Cell[ 
        TextData[ {
          ValueBox[ "Date"]}], "Date"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Footer"], Cell[ 
        TextData[ {" 11/10/06"}]], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 36}, {54, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times New Roman",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman",
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontFamily->"Times New Roman",
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Times New Roman",
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times New Roman",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Times New Roman",
    FontSize->18,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times New Roman",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman",
    FontSize->18],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontFamily->"Times New Roman",
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontFamily->"Times New Roman",
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times New Roman",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman",
    FontSize->16],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontFamily->"Times New Roman",
    FontSize->16],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontFamily->"Times New Roman",
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontFamily->"Times New Roman"]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    FontFamily->"Times New Roman"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Times New Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times New Roman",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontFamily->"Times New Roman",
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontFamily->"Times New Roman",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontFamily->"Times New Roman",
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"Times New Roman"]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontFamily->"Times New Roman",
    FontSize->12],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontFamily->"Times New Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontSize->12],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times New Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    FontFamily->"Times New Roman"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontFamily->"Times New Roman"]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontFamily->"Times New Roman"]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    FontFamily->"Times New Roman"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text",
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 99, 1, 123, "Subtitle"],
Cell[1878, 56, 164, 4, 123, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2067, 64, 93, 2, 81, "Section"],
Cell[2163, 68, 1678, 38, 307, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3878, 111, 91, 2, 81, "Section"],
Cell[3972, 115, 56000, 1731, 5361, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60009, 1851, 71, 1, 81, "Section"],
Cell[60083, 1854, 337, 7, 99, "Text",
  Evaluatable->False],
Cell[60423, 1863, 3128, 83, 296, "Text"],
Cell[63554, 1948, 2539, 70, 411, "Text",
  Evaluatable->False],
Cell[66096, 2020, 80696, 1512, 444, 15745, 705, "GraphicsData", "PostScript", \
"Graphics"],
Cell[146795, 3534, 305, 10, 72, "Text"],
Cell[147103, 3546, 75288, 1490, 444, 17271, 769, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222428, 5041, 62, 1, 81, "Section"],
Cell[222493, 5044, 1120, 43, 99, "Text"],

Cell[CellGroupData[{
Cell[223638, 5091, 72, 1, 69, "Subsection"],
Cell[223713, 5094, 662, 13, 150, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[224424, 5113, 98, 1, 81, "Section"],

Cell[CellGroupData[{
Cell[224547, 5118, 105, 2, 67, "Subsection"],
Cell[224655, 5122, 2830, 76, 391, "Text",
  Evaluatable->False],
Cell[227488, 5200, 323, 6, 99, "Text"],

Cell[CellGroupData[{
Cell[227836, 5210, 560, 11, 28, "Input",
  CellOpen->False],
Cell[228399, 5223, 51510, 1375, 279, 14976, 919, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[279924, 6601, 191, 6, 46, "Text"],
Cell[280118, 6609, 388, 7, 124, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280543, 6621, 100, 2, 67, "Subsection"],
Cell[280646, 6625, 1715, 56, 177, "Text"],

Cell[CellGroupData[{
Cell[282386, 6685, 631, 16, 99, "Input"],
Cell[283020, 6703, 269, 6, 42, "Output"]
}, Open  ]],
Cell[283304, 6712, 1118, 20, 280, "Text"],
Cell[284425, 6734, 152, 4, 72, "Text"],
Cell[284580, 6740, 199, 4, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284816, 6749, 98, 2, 67, "Subsection"],
Cell[284917, 6753, 5136, 169, 333, "Text"],

Cell[CellGroupData[{
Cell[290078, 6926, 68, 2, 40, "Input"],
Cell[290149, 6930, 98, 2, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[290284, 6937, 415, 8, 100, "Input"],
Cell[290702, 6947, 432, 14, 42, "Output"]
}, Open  ]],
Cell[291149, 6964, 471, 16, 99, "Text"],

Cell[CellGroupData[{
Cell[291645, 6984, 9468, 187, 147, "Input"],
Cell[301116, 7173, 86, 2, 55, "Output"]
}, Open  ]],
Cell[301217, 7178, 72, 1, 46, "Text"],
Cell[301292, 7181, 8717, 203, 216, "Input"],
Cell[310012, 7386, 319, 8, 72, "Text"],

Cell[CellGroupData[{
Cell[310356, 7398, 2374, 55, 45, "Input"],
Cell[312733, 7455, 567, 10, 121, "Output"]
}, Open  ]],
Cell[313315, 7468, 142, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[313482, 7476, 148, 3, 42, "Input"],
Cell[313633, 7481, 91, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[313761, 7488, 102, 2, 40, "Input"],
Cell[313866, 7492, 160, 3, 78, "Output"]
}, Open  ]],
Cell[314041, 7498, 82, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[314148, 7503, 165, 4, 39, "Input"],
Cell[314316, 7509, 85, 2, 48, "Output"]
}, Open  ]],
Cell[314416, 7514, 394, 13, 72, "Text"],
Cell[314813, 7529, 196, 4, 72, "Text"],

Cell[CellGroupData[{
Cell[315034, 7537, 10367, 244, 115, "Input"],
Cell[325404, 7783, 64, 2, 40, "Output"]
}, Open  ]],
Cell[325483, 7788, 586, 16, 99, "Text",
  Evaluatable->False],
Cell[326072, 7806, 1477, 40, 75, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[327586, 7851, 153, 4, 67, "Subsection",
  Evaluatable->False],
Cell[327742, 7857, 74, 1, 46, "Text"],
Cell[327819, 7860, 601, 17, 102, "Text",
  Evaluatable->False],
Cell[328423, 7879, 1505, 41, 229, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[329953, 7924, 728, 14, 211, "Input"],
Cell[330684, 7940, 799, 12, 147, "Output"]
}, Open  ]],
Cell[331498, 7955, 178, 4, 72, "Text"],

Cell[CellGroupData[{
Cell[331701, 7963, 173, 3, 40, "Input"],
Cell[331877, 7968, 342, 6, 54, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[332268, 7980, 127, 2, 67, "Subsection"],
Cell[332398, 7984, 2069, 62, 69, "Text"],

Cell[CellGroupData[{
Cell[334492, 8050, 582, 16, 69, "Input"],
Cell[335077, 8068, 61, 2, 39, "Output"]
}, Open  ]],
Cell[335153, 8073, 421, 9, 99, "Text"],

Cell[CellGroupData[{
Cell[335599, 8086, 26068, 587, 189, "Input"],
Cell[361670, 8675, 396, 7, 93, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362103, 8687, 105, 2, 45, "Input"],
Cell[362211, 8691, 61, 2, 39, "Output"]
}, Open  ]],
Cell[362287, 8696, 586, 12, 105, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

